@@ -110,7 +110,7 @@ int MLI_Solver_SeqSuperLU::setup( MLI_Matrix *Amat )
    int      nrows, iP, startRow, nnz, *csrIA, *csrJA, *cscJA, *cscIA;
    int      irow, icol, *rowArray, *countArray, colNum, index, nSubRows;
    int      *etree, permcSpec, lwork, panelSize, relax, info, rowCnt;
-   double   *csrAA, *cscAA, diagPivotThresh, dropTol;
+   double   *csrAA, *cscAA, dropTol;
    hypre_ParCSRMatrix  *hypreA;
    hypre_CSRMatrix     *ADiag;
    SuperMatrix         AC, superLU_Amat;
@@ -281,7 +281,6 @@ fclose(fp);
          slu_options.Fact = DOFACT;
          slu_options.SymmetricMode = NO;
          sp_preorder(&slu_options, &superLU_Amat, permCs_[iP], etree, &AC);
-         diagPivotThresh = 1.0;
          dropTol = 0.0;
          panelSize = sp_ienv(1);
          relax = sp_ienv(2);
@@ -352,7 +351,6 @@ fclose(fp);
          slu_options.Fact = DOFACT;
          slu_options.SymmetricMode = NO;
          sp_preorder(&slu_options, &superLU_Amat, permCs_[iP], etree, &AC);
-         diagPivotThresh = 1.0;
          dropTol = 0.0;
          panelSize = sp_ienv(1);
          relax = sp_ienv(2);
