@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.7 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 #ifndef THREADED_BLAS_DH
@@ -25,12 +25,12 @@
 #define MatVec       matvec_euclid_seq
 #endif
 
-extern void matvec_euclid_seq(HYPRE_Int n, HYPRE_Int *rp, HYPRE_Int *cval, double *aval, double *x, double *y);
-extern double InnerProd(HYPRE_Int local_n, double *x, double *y);
-extern double Norm2(HYPRE_Int local_n, double *x);
-extern void Axpy(HYPRE_Int n, double alpha, double *x, double *y);
-extern double Norm2(HYPRE_Int n, double *x);
-extern void CopyVec(HYPRE_Int n, double *xIN, double *yOUT);
-extern void ScaleVec(HYPRE_Int n, double alpha, double *x);
+extern void matvec_euclid_seq(HYPRE_Int n, HYPRE_Int *rp, HYPRE_Int *cval, HYPRE_Real *aval, HYPRE_Real *x, HYPRE_Real *y);
+extern HYPRE_Real InnerProd(HYPRE_Int local_n, HYPRE_Real *x, HYPRE_Real *y);
+extern HYPRE_Real Norm2(HYPRE_Int local_n, HYPRE_Real *x);
+extern void Axpy(HYPRE_Int n, HYPRE_Real alpha, HYPRE_Real *x, HYPRE_Real *y);
+extern HYPRE_Real Norm2(HYPRE_Int n, HYPRE_Real *x);
+extern void CopyVec(HYPRE_Int n, HYPRE_Real *xIN, HYPRE_Real *yOUT);
+extern void ScaleVec(HYPRE_Int n, HYPRE_Real alpha, HYPRE_Real *x);
 
 #endif
