@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.7 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 #ifndef SUPPORT_DH
@@ -16,12 +16,12 @@
 /* #include "euclid_common.h" */
 
 extern void shellSort_int(const HYPRE_Int n, HYPRE_Int *x);
-extern void shellSort_float(HYPRE_Int n, double *v);
+extern void shellSort_float(HYPRE_Int n, HYPRE_Real *v);
 
 /*
 extern void shellSort_int_int(const HYPRE_Int n, HYPRE_Int *x, HYPRE_Int *y);
-extern void shellSort_int_float(HYPRE_Int n, HYPRE_Int *x, double *v);
-extern void shellSort_int_int_float(HYPRE_Int n, HYPRE_Int *x, HYPRE_Int *y, double *v);
+extern void shellSort_int_float(HYPRE_Int n, HYPRE_Int *x, HYPRE_Real *v);
+extern void shellSort_int_int_float(HYPRE_Int n, HYPRE_Int *x, HYPRE_Int *y, HYPRE_Real *v);
 */
 
 #endif
