@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.4 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -29,14 +29,14 @@
 
 typedef struct
 {
-    int     offset;      /* number of on-processor entries */
-    double *local_diags; /* on-processor entries */
-    double *ext_diags;   /* off-processor entries */
+    HYPRE_Int     offset;      /* number of on-processor entries */
+    HYPRE_Real *local_diags; /* on-processor entries */
+    HYPRE_Real *ext_diags;   /* off-processor entries */
 }
 DiagScale;
 
 DiagScale *DiagScaleCreate(Matrix *A, Numbering *numb);
 void DiagScaleDestroy(DiagScale *p);
-double DiagScaleGet(DiagScale *p, int index);
+HYPRE_Real DiagScaleGet(DiagScale *p, HYPRE_Int index);
 
 #endif /* _DIAGSCALE_H */
