@@ -175,7 +175,7 @@ int main (int argc, char *argv[])
       /* Indicate that the matrix coefficients are ready to be set */
       HYPRE_StructMatrixInitialize(A);
 
-      values = calloc(nvalues, sizeof(double));
+      values = (double*) calloc(nvalues, sizeof(double));
 
       for (j = 0; j < nentries; j++)
       {
@@ -209,7 +209,7 @@ int main (int argc, char *argv[])
       double *values;
       int stencil_indices[1];
 
-      values = calloc(nvalues, sizeof(double));
+      values = (double*) calloc(nvalues, sizeof(double));
       for (j = 0; j < nvalues; j++)
       {
          values[j] = 0.0;
@@ -256,7 +256,7 @@ int main (int argc, char *argv[])
       int     nvalues = nvol;
       double *values;
 
-      values = calloc(nvalues, sizeof(double));
+      values = (double*) calloc(nvalues, sizeof(double));
 
       /* Create an empty vector object */
       HYPRE_StructVectorCreate(MPI_COMM_WORLD, grid, &b);
