@@ -7,16 +7,14 @@
 
    Sample run:   mpirun -np 4 ex5
 
-   Description:  This example solves the 2-D
-                 Laplacian problem with zero boundary conditions
-                 on an nxn grid.  The number of unknowns is N=n^2.
-                 The standard 5-point stencil is used, and we solve
-                 for the interior nodes only.
+   Description:  This example solves the 2-D Laplacian problem with zero boundary
+                 conditions on an n x n grid.  The number of unknowns is N=n^2.
+                 The standard 5-point stencil is used, and we solve for the
+                 interior nodes only.
 
-                 This example solves the same problem as Example 3.
-                 Available solvers are AMG, PCG, and PCG with AMG or
-                 Parasails preconditioners.
-*/
+                 This example solves the same problem as Example 3.  Available
+                 solvers are AMG, PCG, and PCG with AMG or Parasails
+                 preconditioners.  */
 
 #include <math.h>
 #include "_hypre_utilities.h"
@@ -24,6 +22,12 @@
 #include "HYPRE.h"
 #include "HYPRE_parcsr_ls.h"
 
+#include "vis.c"
+
+int hypre_FlexGMRESModifyPCAMGExample(void *precond_data, int iterations,
+                                      double rel_residual_norm);
+
+
 int main (int argc, char *argv[])
 {
    int i;
@@ -34,7 +38,7 @@ int main (int argc, char *argv[])
    int local_size, extra;
 
    int solver_id;
-   int print_solution, print_system;
+   int vis, print_system;
 
    double h, h2;
 
@@ -55,9 +59,9 @@ int main (int argc, char *argv[])
    /* Default problem parameters */
    n = 33;
    solver_id = 0;
-   print_solution  = 0;
+   vis = 0;
    print_system = 0;
-   
+
 
    /* Parse command line */
    {
@@ -76,18 +80,16 @@ int main (int argc, char *argv[])
             arg_index++;
             solver_id = atoi(argv[arg_index++]);
          }
-         else if ( strcmp(argv[arg_index], "-print_solution") == 0 )
+         else if ( strcmp(argv[arg_index], "-vis") == 0 )
          {
             arg_index++;
-            print_solution = 1;
+            vis = 1;
          }
          else if ( strcmp(argv[arg_index], "-print_system") == 0 )
          {
             arg_index++;
             print_system = 1;
          }
-
-
          else if ( strcmp(argv[arg_index], "-help") == 0 )
          {
             print_usage = 1;
@@ -110,7 +112,8 @@ int main (int argc, char *argv[])
          printf("                        1  - AMG-PCG\n");
          printf("                        8  - ParaSails-PCG\n");
          printf("                        50 - PCG\n");
-         printf("  -print_solution     : print the solution vector\n");
+         printf("                        61 - AMG-FlexGMRES\n");
+         printf("  -vis                : save the solution for GLVis visualization\n");
          printf("  -print_system       : print the matrix and rhs\n");
          printf("\n");
       }
@@ -176,9 +179,9 @@ int main (int argc, char *argv[])
          /* The left identity block:position i-n */
          if ((i-n)>=0)
          {
-	    cols[nnz] = i-n;
-	    values[nnz] = -1.0;
-	    nnz++;
+            cols[nnz] = i-n;
+            values[nnz] = -1.0;
+            nnz++;
          }
 
          /* The left -1: position i-1 */
@@ -219,17 +222,17 @@ int main (int argc, char *argv[])
    HYPRE_IJMatrixAssemble(A);
 
    /* Note: for the testing of small problems, one may wish to read
-      in a matrix in IJ format (for the format, see the output files 
+      in a matrix in IJ format (for the format, see the output files
       from the -print_system option).
-      In this case, one would use the following routine:  
+      In this case, one would use the following routine:
       HYPRE_IJMatrixRead( <filename>, MPI_COMM_WORLD,
                           HYPRE_PARCSR, &A );
       <filename>  = IJ.A.out to read in what has been printed out
       by -print_system (processor numbers are omitted).
-      A call to HYPRE_IJMatrixRead is an *alternative* to the 
-      following sequence of HYPRE_IJMatrix calls: 
+      A call to HYPRE_IJMatrixRead is an *alternative* to the
+      following sequence of HYPRE_IJMatrix calls:
       Create, SetObjectType, Initialize, SetValues, and Assemble
-   */                     
+   */
 
 
    /* Get the parcsr matrix object to use */
@@ -250,9 +253,9 @@ int main (int argc, char *argv[])
       double *rhs_values, *x_values;
       int    *rows;
 
-      rhs_values = calloc(local_size, sizeof(double));
-      x_values = calloc(local_size, sizeof(double));
-      rows = calloc(local_size, sizeof(int));
+      rhs_values =  (double*) calloc(local_size, sizeof(double));
+      x_values =  (double*) calloc(local_size, sizeof(double));
+      rows = (int*) calloc(local_size, sizeof(int));
 
       for (i=0; i<local_size; i++)
       {
@@ -272,10 +275,10 @@ int main (int argc, char *argv[])
 
    HYPRE_IJVectorAssemble(b);
    /*  As with the matrix, for testing purposes, one may wish to read in a rhs:
-       HYPRE_IJVectorRead( <filename>, MPI_COMM_WORLD, 
-                                 HYPRE_PARCSR, &b ); 
-       as an alternative to the 
-       following sequence of HYPRE_IJVectors calls: 
+       HYPRE_IJVectorRead( <filename>, MPI_COMM_WORLD,
+                                 HYPRE_PARCSR, &b );
+       as an alternative to the
+       following sequence of HYPRE_IJVectors calls:
        Create, SetObjectType, Initialize, SetValues, and Assemble
    */
    HYPRE_IJVectorGetObject(b, (void **) &par_b);
@@ -283,7 +286,7 @@ int main (int argc, char *argv[])
    HYPRE_IJVectorAssemble(x);
    HYPRE_IJVectorGetObject(x, (void **) &par_x);
 
- 
+
   /*  Print out the system  - files names will be IJ.out.A.XXXXX
        and IJ.out.b.XXXXX, where XXXXX = processor id */
    if (print_system)
@@ -384,7 +387,7 @@ int main (int argc, char *argv[])
       HYPRE_BoomerAMGCreate(&precond);
       HYPRE_BoomerAMGSetPrintLevel(precond, 1); /* print amg solution info */
       HYPRE_BoomerAMGSetCoarsenType(precond, 6);
-      HYPRE_BoomerAMGSetRelaxType(precond, 6); /* Sym G.S./Jacobi hybrid */ 
+      HYPRE_BoomerAMGSetRelaxType(precond, 6); /* Sym G.S./Jacobi hybrid */
       HYPRE_BoomerAMGSetNumSweeps(precond, 1);
       HYPRE_BoomerAMGSetTol(precond, 0.0); /* conv. tolerance zero */
       HYPRE_BoomerAMGSetMaxIter(precond, 1); /* do only one iteration! */
@@ -466,14 +469,111 @@ int main (int argc, char *argv[])
       HYPRE_ParCSRPCGDestroy(solver);
       HYPRE_ParaSailsDestroy(precond);
    }
+   /* Flexible GMRES with  AMG Preconditioner */
+   else if (solver_id == 61)
+   {
+      int    num_iterations;
+      double final_res_norm;
+      int    restart = 30;
+      int    modify = 1;
+
+
+      /* Create solver */
+      HYPRE_ParCSRFlexGMRESCreate(MPI_COMM_WORLD, &solver);
+
+      /* Set some parameters (See Reference Manual for more parameters) */
+      HYPRE_FlexGMRESSetKDim(solver, restart);
+      HYPRE_FlexGMRESSetMaxIter(solver, 1000); /* max iterations */
+      HYPRE_FlexGMRESSetTol(solver, 1e-7); /* conv. tolerance */
+      HYPRE_FlexGMRESSetPrintLevel(solver, 2); /* print solve info */
+      HYPRE_FlexGMRESSetLogging(solver, 1); /* needed to get run info later */
+
+
+      /* Now set up the AMG preconditioner and specify any parameters */
+      HYPRE_BoomerAMGCreate(&precond);
+      HYPRE_BoomerAMGSetPrintLevel(precond, 1); /* print amg solution info */
+      HYPRE_BoomerAMGSetCoarsenType(precond, 6);
+      HYPRE_BoomerAMGSetRelaxType(precond, 6); /* Sym G.S./Jacobi hybrid */
+      HYPRE_BoomerAMGSetNumSweeps(precond, 1);
+      HYPRE_BoomerAMGSetTol(precond, 0.0); /* conv. tolerance zero */
+      HYPRE_BoomerAMGSetMaxIter(precond, 1); /* do only one iteration! */
+
+      /* Set the FlexGMRES preconditioner */
+      HYPRE_FlexGMRESSetPrecond(solver, (HYPRE_PtrToSolverFcn) HYPRE_BoomerAMGSolve,
+                          (HYPRE_PtrToSolverFcn) HYPRE_BoomerAMGSetup, precond);
+
+
+      if (modify)
+      /* this is an optional call  - if you don't call it, hypre_FlexGMRESModifyPCDefault
+         is used - which does nothing.  Otherwise, you can define your own, similar to
+         the one used here */
+         HYPRE_FlexGMRESSetModifyPC( solver,
+                                     (HYPRE_PtrToModifyPCFcn) hypre_FlexGMRESModifyPCAMGExample);
+
+
+      /* Now setup and solve! */
+      HYPRE_ParCSRFlexGMRESSetup(solver, parcsr_A, par_b, par_x);
+      HYPRE_ParCSRFlexGMRESSolve(solver, parcsr_A, par_b, par_x);
+
+      /* Run info - needed logging turned on */
+      HYPRE_FlexGMRESGetNumIterations(solver, &num_iterations);
+      HYPRE_FlexGMRESGetFinalRelativeResidualNorm(solver, &final_res_norm);
+      if (myid == 0)
+      {
+         printf("\n");
+         printf("Iterations = %d\n", num_iterations);
+         printf("Final Relative Residual Norm = %e\n", final_res_norm);
+         printf("\n");
+      }
+
+      /* Destory solver and preconditioner */
+      HYPRE_ParCSRFlexGMRESDestroy(solver);
+      HYPRE_BoomerAMGDestroy(precond);
+
+   }
    else
    {
       if (myid ==0) printf("Invalid solver id specified.\n");
    }
 
-   /* Print the solution */
-   if (print_solution)
-      HYPRE_IJVectorPrint(x, "ij.out.x");
+   /* Save the solution for GLVis visualization, see vis/glvis-ex5.sh */
+   if (vis)
+   {
+      FILE *file;
+      char filename[255];
+
+      int nvalues = local_size;
+      int *rows = (int*) calloc(nvalues, sizeof(int));
+      double *values =  (double*) calloc(nvalues, sizeof(double));
+
+      for (i = 0; i < nvalues; i++)
+         rows[i] = ilower + i;
+
+      /* get the local solution */
+      HYPRE_IJVectorGetValues(x, nvalues, rows, values);
+
+      sprintf(filename, "%s.%06d", "vis/ex5.sol", myid);
+      if ((file = fopen(filename, "w")) == NULL)
+      {
+         printf("Error: can't open output file %s\n", filename);
+         MPI_Finalize();
+         exit(1);
+      }
+
+      /* save solution */
+      for (i = 0; i < nvalues; i++)
+         fprintf(file, "%.14e\n", values[i]);
+
+      fflush(file);
+      fclose(file);
+
+      free(rows);
+      free(values);
+
+      /* save global finite element mesh */
+      if (myid == 0)
+         GLVis_PrintGlobalSquareMesh("vis/ex5.mesh", n-1);
+   }
 
    /* Clean up */
    HYPRE_IJMatrixDestroy(A);
@@ -485,3 +585,31 @@ int main (int argc, char *argv[])
 
    return(0);
 }
+
+/*--------------------------------------------------------------------------
+   hypre_FlexGMRESModifyPCAMGExample -
+
+    This is an example (not recommended)
+   of how we can modify things about AMG that
+   affect the solve phase based on how FlexGMRES is doing...For
+   another preconditioner it may make sense to modify the tolerance..
+
+ *--------------------------------------------------------------------------*/
+
+int hypre_FlexGMRESModifyPCAMGExample(void *precond_data, int iterations,
+                                   double rel_residual_norm)
+{
+
+
+   if (rel_residual_norm > .1)
+   {
+	   HYPRE_BoomerAMGSetNumSweeps((HYPRE_Solver)precond_data, 10);
+   }
+   else
+   {
+      HYPRE_BoomerAMGSetNumSweeps((HYPRE_Solver)precond_data, 1);
+   }
+
+
+   return 0;
+}
