@@ -7,7 +7,7 @@
 
 #include "f2c.h"
 
-/* Subroutine */ int dlasq6_(integer *i0, integer *n0, doublereal *z__, 
+/* Subroutine */ HYPRE_Int dlasq6_(integer *i0, integer *n0, doublereal *z__, 
 	integer *pp, doublereal *dmin__, doublereal *dmin1, doublereal *dmin2,
 	 doublereal *dn, doublereal *dnm1, doublereal *dnm2)
 {
@@ -18,7 +18,7 @@
     /* Local variables */
     static doublereal emin, temp, d__;
     static integer j4;
-    extern doublereal dlamch_(char *);
+    extern doublereal dlamch_(const char *);
     static doublereal safmin;
     static integer j4p2;
 
