@@ -2,7 +2,7 @@
 #include "hypre_lapack.h"
 #include "f2c.h"
 
-/* Subroutine */ int dormbr_(char *vect, char *side, char *trans, integer *m, 
+/* Subroutine */ HYPRE_Int dormbr_(const char *vect,const char *side,const char *trans, integer *m, 
 	integer *n, integer *k, doublereal *a, integer *lda, doublereal *tau, 
 	doublereal *c__, integer *ldc, doublereal *work, integer *lwork, 
 	integer *info)
@@ -133,19 +133,19 @@
     integer a_dim1, a_offset, c_dim1, c_offset, i__1, i__2, i__3[2];
     char ch__1[2];
     /* Builtin functions   
-       Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
+       Subroutine */ HYPRE_Int s_cat(char *, char **, integer *, integer *, ftnlen);
     /* Local variables */
     static logical left;
-    extern logical lsame_(char *, char *);
+    extern logical lsame_(const char *,const char *);
     static integer iinfo, i1, i2, nb, mi, ni, nq, nw;
-    extern /* Subroutine */ int xerbla_(char *, integer *);
-    extern integer ilaenv_(integer *, char *, char *, integer *, integer *, 
+    extern /* Subroutine */ HYPRE_Int xerbla_(const char *, integer *);
+    extern integer ilaenv_(integer *,const char *,const char *, integer *, integer *, 
 	    integer *, integer *, ftnlen, ftnlen);
-    extern /* Subroutine */ int dormlq_(char *, char *, integer *, integer *, 
+    extern /* Subroutine */ HYPRE_Int dormlq_(const char *,const char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *);
     static logical notran;
-    extern /* Subroutine */ int dormqr_(char *, char *, integer *, integer *, 
+    extern /* Subroutine */ HYPRE_Int dormqr_(const char *,const char *, integer *, integer *, 
 	    integer *, doublereal *, integer *, doublereal *, doublereal *, 
 	    integer *, doublereal *, integer *, integer *);
     static logical applyq;
@@ -210,8 +210,8 @@
 	if (applyq) {
 	    if (left) {
 /* Writing concatenation */
-		i__3[0] = 1, a__1[0] = side;
-		i__3[1] = 1, a__1[1] = trans;
+			i__3[0] = 1, a__1[0] = (char*)side;
+			i__3[1] = 1, a__1[1] = (char*)trans;
 		s_cat(ch__1, a__1, i__3, &c__2, (ftnlen)2);
 		i__1 = *m - 1;
 		i__2 = *m - 1;
@@ -219,8 +219,8 @@
 			ftnlen)6, (ftnlen)2);
 	    } else {
 /* Writing concatenation */
-		i__3[0] = 1, a__1[0] = side;
-		i__3[1] = 1, a__1[1] = trans;
+			i__3[0] = 1, a__1[0] = (char*)side;
+			i__3[1] = 1, a__1[1] = (char*)trans;
 		s_cat(ch__1, a__1, i__3, &c__2, (ftnlen)2);
 		i__1 = *n - 1;
 		i__2 = *n - 1;
@@ -230,8 +230,8 @@
 	} else {
 	    if (left) {
 /* Writing concatenation */
-		i__3[0] = 1, a__1[0] = side;
-		i__3[1] = 1, a__1[1] = trans;
+			i__3[0] = 1, a__1[0] = (char*)side;
+			i__3[1] = 1, a__1[1] = (char*)trans;
 		s_cat(ch__1, a__1, i__3, &c__2, (ftnlen)2);
 		i__1 = *m - 1;
 		i__2 = *m - 1;
@@ -239,8 +239,8 @@
 			ftnlen)6, (ftnlen)2);
 	    } else {
 /* Writing concatenation */
-		i__3[0] = 1, a__1[0] = side;
-		i__3[1] = 1, a__1[1] = trans;
+			i__3[0] = 1, a__1[0] = (char*)side;
+			i__3[1] = 1, a__1[1] = (char*)trans;
 		s_cat(ch__1, a__1, i__3, &c__2, (ftnlen)2);
 		i__1 = *n - 1;
 		i__2 = *n - 1;
