@@ -19,6 +19,10 @@
 #include "_hypre_parcsr_ls.h"
 #include "fortran.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+    
 /*--------------------------------------------------------------------------
  * HYPRE_ParCSRBiCGSTABCreate
  *--------------------------------------------------------------------------*/
@@ -211,7 +215,7 @@ hypre_F90_IFACE(hypre_parcsrbicgstabsetprecond, HYPRE_PARCSRBICGSTABSETPRECOND)
               hypre_F90_PassObj (HYPRE_Solver, solver),
               HYPRE_BoomerAMGSolve,
               HYPRE_BoomerAMGSetup,
-              (void *)       *precond_solver ) );
+              (HYPRE_Solver)      *precond_solver ) );
    }
    else if (*precond_id == 3)
    {
@@ -220,7 +224,7 @@ hypre_F90_IFACE(hypre_parcsrbicgstabsetprecond, HYPRE_PARCSRBICGSTABSETPRECOND)
               hypre_F90_PassObj (HYPRE_Solver, solver),
               HYPRE_ParCSRPilutSolve,
               HYPRE_ParCSRPilutSetup,
-              (void *)       *precond_solver ) );
+              (HYPRE_Solver)       *precond_solver ) );
    }
    else if (*precond_id == 4)
    {
@@ -229,7 +233,7 @@ hypre_F90_IFACE(hypre_parcsrbicgstabsetprecond, HYPRE_PARCSRBICGSTABSETPRECOND)
               hypre_F90_PassObj (HYPRE_Solver, solver),
               HYPRE_ParCSRParaSailsSolve,
               HYPRE_ParCSRParaSailsSetup,
-              (void *)       *precond_solver ) );
+               (HYPRE_Solver)      *precond_solver ) );
    }
    else if (*precond_id == 5)
    {
@@ -238,7 +242,7 @@ hypre_F90_IFACE(hypre_parcsrbicgstabsetprecond, HYPRE_PARCSRBICGSTABSETPRECOND)
               hypre_F90_PassObj (HYPRE_Solver, solver),
               HYPRE_EuclidSolve,
               HYPRE_EuclidSetup,
-              (void *)       *precond_solver ) );
+			  (HYPRE_Solver)      *precond_solver ) );
    }
    else
    {
@@ -326,3 +330,7 @@ hypre_F90_IFACE(hypre_parcsrbicgstabgetfinalrel, HYPRE_PARCSRBICGSTABGETFINALREL
            hypre_F90_PassObj (HYPRE_Solver, solver),
            hypre_F90_PassRealRef (norm)    ) );
 }
+    
+#ifdef __cplusplus
+}
+#endif
