@@ -19,6 +19,10 @@
 #include "_hypre_parcsr_ls.h"
 #include "fortran.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+    
 /*--------------------------------------------------------------------------
  * HYPRE_ParCSRGMRESCreate
  *--------------------------------------------------------------------------*/
@@ -225,7 +229,7 @@ hypre_F90_IFACE(hypre_parcsrgmressetprecond, HYPRE_PARCSRGMRESSETPRECOND)
               hypre_F90_PassObj (HYPRE_Solver, solver),
               HYPRE_BoomerAMGSolve,
               HYPRE_BoomerAMGSetup,
-              (void *)       *precond_solver ) );
+              (HYPRE_Solver)       *precond_solver ) );
    }
    else if (*precond_id == 3)
    {
@@ -234,7 +238,7 @@ hypre_F90_IFACE(hypre_parcsrgmressetprecond, HYPRE_PARCSRGMRESSETPRECOND)
               hypre_F90_PassObj (HYPRE_Solver, solver),
               HYPRE_ParCSRPilutSolve,
               HYPRE_ParCSRPilutSetup,
-              (void *)       *precond_solver ) );
+              (HYPRE_Solver)       *precond_solver ) );
    }
    else if (*precond_id == 4)
    {
@@ -243,7 +247,7 @@ hypre_F90_IFACE(hypre_parcsrgmressetprecond, HYPRE_PARCSRGMRESSETPRECOND)
               hypre_F90_PassObj (HYPRE_Solver, solver),
               HYPRE_ParCSRParaSailsSolve,
               HYPRE_ParCSRParaSailsSetup,
-              (void *)       *precond_solver ) );
+              (HYPRE_Solver)       *precond_solver ) );
    } 
    else if (*precond_id == 5)
    {
@@ -252,7 +256,7 @@ hypre_F90_IFACE(hypre_parcsrgmressetprecond, HYPRE_PARCSRGMRESSETPRECOND)
               hypre_F90_PassObj (HYPRE_Solver, solver),
               HYPRE_EuclidSolve,
               HYPRE_EuclidSetup,
-              (void *)       *precond_solver ) );
+              (HYPRE_Solver)       *precond_solver ) );
    } 
    else
    {
@@ -340,3 +344,7 @@ hypre_F90_IFACE(hypre_parcsrgmresgetfinalrelati, HYPRE_PARCSRGMRESGETFINALRELATI
            hypre_F90_PassObj (HYPRE_Solver, solver),
            hypre_F90_PassRealRef (norm)    ) );
 }
+    
+#ifdef __cplusplus
+}
+#endif
