@@ -58,7 +58,7 @@ HYPRE_Int HYPRE_AMESolve (HYPRE_Solver esolver)
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int HYPRE_AMESetAMSSolver(HYPRE_Solver esolver,
-                          HYPRE_Solver ams_solver)
+                                HYPRE_Solver ams_solver)
 {
    return hypre_AMESetAMSSolver((void *) esolver,
                                 (void *) ams_solver);
@@ -69,7 +69,7 @@ HYPRE_Int HYPRE_AMESetAMSSolver(HYPRE_Solver esolver,
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int HYPRE_AMESetMassMatrix(HYPRE_Solver esolver,
-                           HYPRE_ParCSRMatrix M)
+                                 HYPRE_ParCSRMatrix M)
 {
    return hypre_AMESetMassMatrix((void *) esolver,
                                  (hypre_ParCSRMatrix *) M);
@@ -80,7 +80,7 @@ HYPRE_Int HYPRE_AMESetMassMatrix(HYPRE_Solver esolver,
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int HYPRE_AMESetBlockSize(HYPRE_Solver esolver,
-                          HYPRE_Int block_size)
+                                HYPRE_Int block_size)
 {
    return hypre_AMESetBlockSize((void *) esolver, block_size);
 }
@@ -90,7 +90,7 @@ HYPRE_Int HYPRE_AMESetBlockSize(HYPRE_Solver esolver,
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int HYPRE_AMESetMaxIter(HYPRE_Solver esolver,
-                        HYPRE_Int maxit)
+                              HYPRE_Int maxit)
 {
    return hypre_AMESetMaxIter((void *) esolver, maxit);
 }
@@ -100,17 +100,27 @@ HYPRE_Int HYPRE_AMESetMaxIter(HYPRE_Solver esolver,
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int HYPRE_AMESetTol(HYPRE_Solver esolver,
-                    HYPRE_Real tol)
+                          HYPRE_Real tol)
 {
    return hypre_AMESetTol((void *) esolver, tol);
 }
 
+/*--------------------------------------------------------------------------
+ * HYPRE_AMESetRTol
+ *--------------------------------------------------------------------------*/
+
+HYPRE_Int HYPRE_AMESetRTol(HYPRE_Solver esolver,
+			   HYPRE_Real tol)
+{
+   return hypre_AMESetRTol((void *) esolver, tol);
+}
+
 /*--------------------------------------------------------------------------
  * HYPRE_AMESetPrintLevel
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int HYPRE_AMESetPrintLevel(HYPRE_Solver esolver,
-                           HYPRE_Int print_level)
+                                 HYPRE_Int print_level)
 {
    return hypre_AMESetPrintLevel((void *) esolver, print_level);
 }
@@ -120,7 +130,7 @@ HYPRE_Int HYPRE_AMESetPrintLevel(HYPRE_Solver esolver,
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int HYPRE_AMEGetEigenvalues(HYPRE_Solver esolver,
-                            HYPRE_Real **eigenvalues)
+                                  HYPRE_Real **eigenvalues)
 {
    return hypre_AMEGetEigenvalues((void *) esolver, eigenvalues);
 }
@@ -130,7 +140,7 @@ HYPRE_Int HYPRE_AMEGetEigenvalues(HYPRE_Solver esolver,
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int HYPRE_AMEGetEigenvectors(HYPRE_Solver esolver,
-                             HYPRE_ParVector **eigenvectors)
+                                   HYPRE_ParVector **eigenvectors)
 {
    return hypre_AMEGetEigenvectors((void *) esolver,
                                    eigenvectors);
