@@ -1216,7 +1216,18 @@ HYPRE_Int
 HYPRE_BoomerAMGSetAddTruncFactor( HYPRE_Solver  solver,
                                   HYPRE_Real        add_trunc_factor  )
 {
-   return( hypre_BoomerAMGSetAddTruncFactor( (void *) solver, add_trunc_factor ) );
+   return( hypre_BoomerAMGSetMultAddTruncFactor( (void *) solver, add_trunc_factor ) );
+}
+
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetMultAddTruncFactor
+ *--------------------------------------------------------------------------*/
+
+HYPRE_Int
+HYPRE_BoomerAMGSetMultAddTruncFactor( HYPRE_Solver  solver,
+                                  HYPRE_Real        add_trunc_factor  )
+{
+   return( hypre_BoomerAMGSetMultAddTruncFactor( (void *) solver, add_trunc_factor ) );
 }
 
 /*--------------------------------------------------------------------------
@@ -1249,7 +1260,18 @@ HYPRE_Int
 HYPRE_BoomerAMGSetAddPMaxElmts( HYPRE_Solver  solver,
                                 HYPRE_Int          add_P_max_elmts  )
 {
-   return( hypre_BoomerAMGSetAddPMaxElmts( (void *) solver, add_P_max_elmts ) );
+   return( hypre_BoomerAMGSetMultAddPMaxElmts( (void *) solver, add_P_max_elmts ) );
+}
+
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetMultAddPMaxElmts
+ *--------------------------------------------------------------------------*/
+
+HYPRE_Int
+HYPRE_BoomerAMGSetMultAddPMaxElmts( HYPRE_Solver  solver,
+                                HYPRE_Int          add_P_max_elmts  )
+{
+   return( hypre_BoomerAMGSetMultAddPMaxElmts( (void *) solver, add_P_max_elmts ) );
 }
 
 /*--------------------------------------------------------------------------
@@ -1547,6 +1569,29 @@ HYPRE_BoomerAMGGetSimple( HYPRE_Solver solver,
    return( hypre_BoomerAMGGetSimple( (void *) solver, simple ) );
 }
 
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetNonGalerkinTol
+ *--------------------------------------------------------------------------*/
+
+HYPRE_Int
+HYPRE_BoomerAMGSetNonGalerkinTol (HYPRE_Solver solver,
+                                HYPRE_Real  nongalerkin_tol)
+{
+   return (hypre_BoomerAMGSetNonGalerkinTol ( (void *) solver, nongalerkin_tol ) );
+}
+
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetLevelNonGalerkinTol
+ *--------------------------------------------------------------------------*/
+
+HYPRE_Int
+HYPRE_BoomerAMGSetLevelNonGalerkinTol (HYPRE_Solver solver,
+                                HYPRE_Real  nongalerkin_tol,
+                                HYPRE_Int   level)
+{
+   return (hypre_BoomerAMGSetLevelNonGalerkinTol ( (void *) solver, nongalerkin_tol , level ) );
+}
+
 /*--------------------------------------------------------------------------
  * HYPRE_BoomerAMGSetNonGalerkTol
  *--------------------------------------------------------------------------*/
@@ -1559,3 +1604,25 @@ HYPRE_BoomerAMGSetNonGalerkTol (HYPRE_Solver solver,
    return (hypre_BoomerAMGSetNonGalerkTol ( (void *) solver, nongalerk_num_tol , nongalerk_tol ) );
 }
 
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetRAP2
+ *--------------------------------------------------------------------------*/
+
+HYPRE_Int
+HYPRE_BoomerAMGSetRAP2 (HYPRE_Solver solver,
+                                HYPRE_Int    rap2)
+{
+   return (hypre_BoomerAMGSetRAP2 ( (void *) solver, rap2 ) );
+}
+
+/*--------------------------------------------------------------------------
+ * HYPRE_BoomerAMGSetKeepTranspose
+ *--------------------------------------------------------------------------*/
+
+HYPRE_Int
+HYPRE_BoomerAMGSetKeepTranspose (HYPRE_Solver solver,
+                                HYPRE_Int    keepTranspose)
+{
+   return (hypre_BoomerAMGSetKeepTranspose ( (void *) solver, keepTranspose ) );
+}
+
