@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.6 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -25,7 +25,7 @@
  * HYPRE_BlockTridiagCreate
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagCreate(HYPRE_Solver *solver)
+HYPRE_Int HYPRE_BlockTridiagCreate(HYPRE_Solver *solver)
 {
    *solver = (HYPRE_Solver) hypre_BlockTridiagCreate( ) ;
    return 0;
@@ -35,7 +35,7 @@ int HYPRE_BlockTridiagCreate(HYPRE_Solver *solver)
  * HYPRE_blockTridiagDestroy
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagDestroy(HYPRE_Solver solver)
+HYPRE_Int HYPRE_BlockTridiagDestroy(HYPRE_Solver solver)
 {
    return(hypre_BlockTridiagDestroy((void *) solver ));
 }
@@ -44,7 +44,7 @@ int HYPRE_BlockTridiagDestroy(HYPRE_Solver solver)
  * HYPRE_BlockTridiagSetup
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagSetup(HYPRE_Solver solver, HYPRE_ParCSRMatrix A,
+HYPRE_Int HYPRE_BlockTridiagSetup(HYPRE_Solver solver, HYPRE_ParCSRMatrix A,
                             HYPRE_ParVector b, HYPRE_ParVector x)
 {
    return(hypre_BlockTridiagSetup((void *) solver, (hypre_ParCSRMatrix *) A,
@@ -55,7 +55,7 @@ int HYPRE_BlockTridiagSetup(HYPRE_Solver solver, HYPRE_ParCSRMatrix A,
  * HYPRE_BlockTridiagSolve
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagSolve(HYPRE_Solver solver, HYPRE_ParCSRMatrix A,
+HYPRE_Int HYPRE_BlockTridiagSolve(HYPRE_Solver solver, HYPRE_ParCSRMatrix A,
                         HYPRE_ParVector b,   HYPRE_ParVector x)
 {
    return(hypre_BlockTridiagSolve((void *) solver, (hypre_ParCSRMatrix *) A,
@@ -66,7 +66,7 @@ int HYPRE_BlockTridiagSolve(HYPRE_Solver solver, HYPRE_ParCSRMatrix A,
  * HYPRE_BlockTridiagSetIndexSet
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagSetIndexSet(HYPRE_Solver solver,int n, int *inds)
+HYPRE_Int HYPRE_BlockTridiagSetIndexSet(HYPRE_Solver solver,HYPRE_Int n, HYPRE_Int *inds)
 {
    return(hypre_BlockTridiagSetIndexSet((void *) solver, n, inds));
 }
@@ -75,7 +75,7 @@ int HYPRE_BlockTridiagSetIndexSet(HYPRE_Solver solver,int n, int *inds)
  * HYPRE_BlockTridiagSetAMGStrengthThreshold
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagSetAMGStrengthThreshold(HYPRE_Solver solver,double thresh)
+HYPRE_Int HYPRE_BlockTridiagSetAMGStrengthThreshold(HYPRE_Solver solver,HYPRE_Real thresh)
 {
    return(hypre_BlockTridiagSetAMGStrengthThreshold((void *) solver, thresh));
 }
@@ -84,7 +84,7 @@ int HYPRE_BlockTridiagSetAMGStrengthThreshold(HYPRE_Solver solver,double thresh)
  * HYPRE_BlockTridiagSetAMGNumSweeps
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagSetAMGNumSweeps(HYPRE_Solver solver, int num_sweeps)
+HYPRE_Int HYPRE_BlockTridiagSetAMGNumSweeps(HYPRE_Solver solver, HYPRE_Int num_sweeps)
 {
    return(hypre_BlockTridiagSetAMGNumSweeps((void *) solver,num_sweeps));
 }
@@ -93,7 +93,7 @@ int HYPRE_BlockTridiagSetAMGNumSweeps(HYPRE_Solver solver, int num_sweeps)
  * HYPRE_BlockTridiagSetAMGRelaxType
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagSetAMGRelaxType(HYPRE_Solver solver, int relax_type)
+HYPRE_Int HYPRE_BlockTridiagSetAMGRelaxType(HYPRE_Solver solver, HYPRE_Int relax_type)
 {
    return(hypre_BlockTridiagSetAMGRelaxType( (void *) solver, relax_type));
 }
@@ -102,7 +102,7 @@ int HYPRE_BlockTridiagSetAMGRelaxType(HYPRE_Solver solver, int relax_type)
  * HYPRE_BlockTridiagSetPrintLevel
  *--------------------------------------------------------------------------*/
 
-int HYPRE_BlockTridiagSetPrintLevel(HYPRE_Solver solver, int print_level)
+HYPRE_Int HYPRE_BlockTridiagSetPrintLevel(HYPRE_Solver solver, HYPRE_Int print_level)
 {
    return(hypre_BlockTridiagSetPrintLevel( (void *) solver, print_level));
 }
