@@ -31,7 +31,6 @@ HYPRE_Int hypre_seqAMGSetup( hypre_ParAMGData *amg_data,
    HYPRE_Int               **dof_func_array;   
    HYPRE_Int                num_procs, my_id;
 
-   HYPRE_Int                not_finished_coarsening;
    HYPRE_Int                level;
    HYPRE_Int                redundant;
    HYPRE_Int                num_functions;
@@ -49,8 +48,6 @@ HYPRE_Int hypre_seqAMGSetup( hypre_ParAMGData *amg_data,
    /*initial */
    level = p_level;
    
-   not_finished_coarsening = 1;
-  
    /* convert A at this level to sequential */
    A = Par_A_array[level];
 
@@ -206,7 +203,11 @@ HYPRE_Int hypre_seqAMGSetup( hypre_ParAMGData *amg_data,
          }
          else
          {
-            hypre_MPI_Gatherv ( &A_tmp_i[1], num_rows, HYPRE_MPI_INT, &A_seq_i[1], info,
+            if (A_seq_i) 
+		hypre_MPI_Gatherv ( &A_tmp_i[1], num_rows, HYPRE_MPI_INT, &A_seq_i[1], info,
+                        displs, HYPRE_MPI_INT, 0, new_comm );
+            else
+		hypre_MPI_Gatherv ( &A_tmp_i[1], num_rows, HYPRE_MPI_INT, A_seq_i, info,
                         displs, HYPRE_MPI_INT, 0, new_comm );
             if (num_functions > 1)
             {
@@ -367,10 +368,9 @@ hypre_seqAMGCycle( hypre_ParAMGData *amg_data,
       
       HYPRE_Int nf;
       HYPRE_Int local_info;
-      HYPRE_Real *recv_buf;
+      HYPRE_Real *recv_buf = NULL;
       HYPRE_Int *displs = NULL;
       HYPRE_Int *info = NULL;
-      HYPRE_Int size;
       HYPRE_Int new_num_procs, my_id;
       
       hypre_MPI_Comm_size(new_comm, &new_num_procs);
@@ -394,10 +394,12 @@ hypre_seqAMGCycle( hypre_ParAMGData *amg_data,
          displs[0] = 0;
          for (i=1; i < new_num_procs+1; i++)
             displs[i] = displs[i-1]+info[i-1]; 
-         size = displs[new_num_procs];
       
-         tmp_vec =  hypre_ParVectorLocalVector(F_coarse);
-         recv_buf = hypre_VectorData(tmp_vec);
+         if (F_coarse) 
+         {
+            tmp_vec =  hypre_ParVectorLocalVector(F_coarse);
+            recv_buf = hypre_VectorData(tmp_vec);
+         }
       }
 
       if (redundant)
