@@ -30,7 +30,7 @@
 HYPRE_Int
 hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
 {
-   hypre_ParAMGData *amg_data = amg_vdata;
+   hypre_ParAMGData *amg_data = (hypre_ParAMGData*) amg_vdata;
 
    /* Data Structure variables */
 
@@ -52,21 +52,19 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
    HYPRE_Int       simple;
    HYPRE_Int       i, num_rows;
    HYPRE_Int       n_global;
+   HYPRE_Int       rlx_order;
 
  /* Local variables  */ 
    HYPRE_Int       Solve_err_flag = 0;
    HYPRE_Int       level;
    HYPRE_Int       coarse_grid;
    HYPRE_Int       fine_grid;
-   HYPRE_Int       relax_type;
    HYPRE_Int       rlx_down;
    HYPRE_Int       rlx_up;
    HYPRE_Int      *grid_relax_type;
    HYPRE_Real      **l1_norms;
    HYPRE_Real    alpha, beta;
-   HYPRE_Int       num_threads;
    HYPRE_Real *u_data;
-   HYPRE_Real *f_data;
    HYPRE_Real *v_data;
    HYPRE_Real *l1_norms_lvl;
    HYPRE_Real *D_inv;
@@ -82,8 +80,6 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
    
    /* Acquire data and allocate storage */
 
-   num_threads = hypre_NumThreads();
-
    A_array           = hypre_ParAMGDataAArray(amg_data);
    F_array           = hypre_ParAMGDataFArray(amg_data);
    U_array           = hypre_ParAMGDataUArray(amg_data);
@@ -102,9 +98,9 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
    Rtilde            = hypre_ParAMGDataRtilde(amg_data);
    l1_norms          = hypre_ParAMGDataL1Norms(amg_data);
    D_inv             = hypre_ParAMGDataDinv(amg_data);
-   grid_relax_type   = hypre_ParAMGDataGridRelaxType(amg_data);
    relax_weight      = hypre_ParAMGDataRelaxWeight(amg_data);
    omega             = hypre_ParAMGDataOmega(amg_data);
+   rlx_order         = hypre_ParAMGDataRelaxOrder(amg_data);
 
    /* Initialize */
 
@@ -117,7 +113,6 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
     *--------------------------------------------------------------------*/
 
    /* down cycle */
-   relax_type = grid_relax_type[1];
    rlx_down = grid_relax_type[1];
    rlx_up = grid_relax_type[2];
    for (level = 0; level < num_levels-1; level++)
@@ -126,7 +121,6 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
       coarse_grid = level + 1;
 
       u_data = hypre_VectorData(hypre_ParVectorLocalVector(U_array[fine_grid]));
-      f_data = hypre_VectorData(hypre_ParVectorLocalVector(F_array[fine_grid]));
       v_data = hypre_VectorData(hypre_ParVectorLocalVector(Vtemp));
       l1_norms_lvl = l1_norms[level];
 
@@ -151,7 +145,9 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
 
          else if (rlx_down != 18)
          {
-            hypre_BoomerAMGRelax(A_array[fine_grid],F_array[fine_grid],NULL,rlx_down,0,
+            /*hypre_BoomerAMGRelax(A_array[fine_grid],F_array[fine_grid],NULL,rlx_down,0,*/
+            hypre_BoomerAMGRelaxIF(A_array[fine_grid],F_array[fine_grid],
+	     CF_marker_array[fine_grid], rlx_down,rlx_order,1,
              relax_weight[fine_grid], omega[fine_grid],
              l1_norms_lvl, U_array[fine_grid], Vtemp, Ztemp);
             hypre_ParVectorCopy(F_array[fine_grid],Vtemp);
@@ -220,7 +216,6 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
    }
 
    /* up cycle */
-   relax_type = grid_relax_type[2];
    for (level = num_levels-1; level > 0; level--)
    {
       fine_grid = level - 1;
@@ -234,10 +229,25 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
                                      U_array[coarse_grid],
                                      beta, U_array[fine_grid]);            
          if (rlx_up != 18)
-            hypre_BoomerAMGRelax(A_array[fine_grid],F_array[fine_grid],NULL,rlx_up,0,
+            /*hypre_BoomerAMGRelax(A_array[fine_grid],F_array[fine_grid],NULL,rlx_up,0,*/
+            hypre_BoomerAMGRelaxIF(A_array[fine_grid],F_array[fine_grid],
+		CF_marker_array[fine_grid],
+		rlx_up,rlx_order,2,
                 relax_weight[fine_grid], omega[fine_grid],
                 l1_norms[fine_grid], U_array[fine_grid], Vtemp, Ztemp);
-         else
+         else if (rlx_order)
+         {
+            HYPRE_Int loc_relax_points[2];
+            loc_relax_points[0] = -1;
+            loc_relax_points[1] = 1;
+            for (i=0; i < 2; i++)
+                hypre_ParCSRRelax_L1_Jacobi(A_array[fine_grid],F_array[fine_grid],
+                                            CF_marker_array[fine_grid],
+                                            loc_relax_points[i],
+                                            1.0, l1_norms[fine_grid],
+                                            U_array[fine_grid], Vtemp);
+         }
+         else 
             hypre_ParCSRRelax(A_array[fine_grid], F_array[fine_grid],
                                  1, 1, l1_norms[fine_grid],
                                  1.0, 1.0 ,0,0,0,0,
@@ -259,7 +269,7 @@ hypre_BoomerAMGAdditiveCycle( void              *amg_vdata)
 
 HYPRE_Int hypre_CreateLambda(void *amg_vdata)
 {
-   hypre_ParAMGData *amg_data = amg_vdata;
+   hypre_ParAMGData *amg_data = (hypre_ParAMGData*) amg_vdata;
 
    /* Data Structure variables */
    MPI_Comm comm;
@@ -337,7 +347,6 @@ HYPRE_Int hypre_CreateLambda(void *amg_vdata)
 
  /* Local variables  */ 
    HYPRE_Int       Solve_err_flag = 0;
-   HYPRE_Int       num_threads;
    HYPRE_Int       num_nonzeros_diag;
    HYPRE_Int       num_nonzeros_offd;
 
@@ -347,8 +356,6 @@ HYPRE_Int hypre_CreateLambda(void *amg_vdata)
 
    /* Acquire data and allocate storage */
 
-   num_threads = hypre_NumThreads();
-
    A_array           = hypre_ParAMGDataAArray(amg_data);
    F_array           = hypre_ParAMGDataFArray(amg_data);
    U_array           = hypre_ParAMGDataUArray(amg_data);
@@ -433,7 +440,7 @@ HYPRE_Int hypre_CreateLambda(void *amg_vdata)
          }
          if (max_sends)
          {
-            qsort0(all_send_procs, 0, max_sends-1);
+            hypre_qsort0(all_send_procs, 0, max_sends-1);
             num_sends_L = 1;
             this_proc = all_send_procs[0];
             for (i=1; i < max_sends; i++)
@@ -451,7 +458,7 @@ HYPRE_Int hypre_CreateLambda(void *amg_vdata)
          }
          if (max_recvs)
          {
-            qsort0(all_recv_procs, 0, max_recvs-1);
+            hypre_qsort0(all_recv_procs, 0, max_recvs-1);
             num_recvs_L = 1;
             this_proc = all_recv_procs[0];
             for (i=1; i < max_recvs; i++)
@@ -573,6 +580,8 @@ HYPRE_Int hypre_CreateLambda(void *amg_vdata)
          }
       } 
    }
+   if (max_sends) hypre_TFree(all_send_procs);
+   if (max_recvs) hypre_TFree(all_recv_procs);
 
    L_diag = hypre_CSRMatrixCreate(num_rows_L, num_rows_L, num_nonzeros_diag);
    L_offd = hypre_CSRMatrixCreate(num_rows_L, num_cols_offd_L, num_nonzeros_offd);
@@ -812,7 +821,7 @@ HYPRE_Int hypre_CreateLambda(void *amg_vdata)
 
 HYPRE_Int hypre_CreateDinv(void *amg_vdata)
 {
-   hypre_ParAMGData *amg_data = amg_vdata;
+   hypre_ParAMGData *amg_data = (hypre_ParAMGData*) amg_vdata;
 
    /* Data Structure variables */
    hypre_ParCSRMatrix **A_array;
@@ -834,15 +843,12 @@ HYPRE_Int hypre_CreateDinv(void *amg_vdata)
 
    HYPRE_Int       addlvl;
    HYPRE_Int       num_levels;
-   HYPRE_Int       num_add_lvls;
    HYPRE_Int       num_rows_L;
-   HYPRE_Int       num_rows_A;
    HYPRE_Int       num_rows_tmp;
    HYPRE_Int       level, i;
 
  /* Local variables  */ 
    HYPRE_Int       Solve_err_flag = 0;
-   HYPRE_Int       num_threads;
 
    HYPRE_Real  **l1_norms_ptr = NULL;
    HYPRE_Real  *l1_norms;
@@ -850,8 +856,6 @@ HYPRE_Int hypre_CreateDinv(void *amg_vdata)
 
    /* Acquire data and allocate storage */
 
-   num_threads = hypre_NumThreads();
-
    A_array           = hypre_ParAMGDataAArray(amg_data);
    F_array           = hypre_ParAMGDataFArray(amg_data);
    U_array           = hypre_ParAMGDataUArray(amg_data);
@@ -859,13 +863,10 @@ HYPRE_Int hypre_CreateDinv(void *amg_vdata)
    num_levels        = hypre_ParAMGDataNumLevels(amg_data);
    relax_weight      = hypre_ParAMGDataRelaxWeight(amg_data);
    relax_type        = hypre_ParAMGDataGridRelaxType(amg_data)[1];
-   num_rows_A        = hypre_CSRMatrixNumRows(hypre_ParCSRMatrixDiag(A_array[0]));
 
    l1_norms_ptr      = hypre_ParAMGDataL1Norms(amg_data); 
    /* smooth_option       = hypre_ParAMGDataSmoothOption(amg_data); */
 
-   num_add_lvls = num_levels+1-addlvl;
-  
    num_rows_L  = 0;
    for (i=addlvl; i < num_levels; i++)
    {
