@@ -36,7 +36,7 @@ hypre_BoomerAMGSolve( void               *amg_vdata,
 
    MPI_Comm 	      comm = hypre_ParCSRMatrixComm(A);   
 
-   hypre_ParAMGData   *amg_data = amg_vdata;
+   hypre_ParAMGData   *amg_data = (hypre_ParAMGData*) amg_vdata;
 
    /* Data Structure variables */
 
@@ -79,7 +79,7 @@ hypre_BoomerAMGSolve( void               *amg_vdata,
    HYPRE_Real   operat_cmplxty;
    HYPRE_Real   grid_cmplxty;
    HYPRE_Real   conv_factor = 0.0;
-   HYPRE_Real   resid_nrm;
+   HYPRE_Real   resid_nrm = 1.0;
    HYPRE_Real   resid_nrm_init = 0.0;
    HYPRE_Real   relative_resid;
    HYPRE_Real   rhs_norm = 0.0;
@@ -247,13 +247,11 @@ hypre_BoomerAMGSolve( void               *amg_vdata,
         old_resid = resid_nrm;
 
         if ( amg_logging > 1 ) {
-           hypre_ParVectorCopy(F_array[0], Residual);
-           hypre_ParCSRMatrixMatvec(alpha, A_array[0], U_array[0], beta, Residual );
+           hypre_ParCSRMatrixMatvecOutOfPlace(alpha, A_array[0], U_array[0], beta, F_array[0], Residual );
            resid_nrm = sqrt(hypre_ParVectorInnerProd( Residual, Residual ));
         }
         else {
-           hypre_ParVectorCopy(F_array[0], Vtemp);
-           hypre_ParCSRMatrixMatvec(alpha, A_array[0], U_array[0], beta, Vtemp);
+           hypre_ParCSRMatrixMatvecOutOfPlace(alpha, A_array[0], U_array[0], beta, F_array[0], Vtemp);
            resid_nrm = sqrt(hypre_ParVectorInnerProd(Vtemp, Vtemp));
         }
 
