@@ -24,7 +24,6 @@
 #include "_hypre_parcsr_ls.h"
 
 
-
 /*==========================================================================*/
 /*==========================================================================*/
 /**
@@ -1115,7 +1114,7 @@ hypre_BoomerAMGCoarsenRuge( hypre_ParCSRMatrix    *S,
       {
          if (measure > 0)
          {
-            enter_on_lists(&LoL_head, &LoL_tail, measure, j, lists, where);
+            hypre_enter_on_lists(&LoL_head, &LoL_tail, measure, j, lists, where);
          }
          else
          {
@@ -1130,11 +1129,11 @@ hypre_BoomerAMGCoarsenRuge( hypre_ParCSRMatrix    *S,
                   {
                      new_meas = measure_array[nabor];
 	             if (new_meas > 0)
-                        remove_point(&LoL_head, &LoL_tail, new_meas, 
+                        hypre_remove_point(&LoL_head, &LoL_tail, new_meas, 
                                nabor, lists, where);
 
                      new_meas = ++(measure_array[nabor]);
-                     enter_on_lists(&LoL_head, &LoL_tail, new_meas,
+                     hypre_enter_on_lists(&LoL_head, &LoL_tail, new_meas,
                                  nabor, lists, where);
                   }
 	          else
@@ -1177,7 +1176,7 @@ hypre_BoomerAMGCoarsenRuge( hypre_ParCSRMatrix    *S,
       measure_array[index] = 0;
       --num_left;
       
-      remove_point(&LoL_head, &LoL_tail, measure, index, lists, where);
+      hypre_remove_point(&LoL_head, &LoL_tail, measure, index, lists, where);
   
       for (j = ST_i[index]; j < ST_i[index+1]; j++)
       {
@@ -1187,7 +1186,7 @@ hypre_BoomerAMGCoarsenRuge( hypre_ParCSRMatrix    *S,
             CF_marker[nabor] = F_PT;
             measure = measure_array[nabor];
 
-            remove_point(&LoL_head, &LoL_tail, measure, nabor, lists, where);
+            hypre_remove_point(&LoL_head, &LoL_tail, measure, nabor, lists, where);
             --num_left;
 
             for (k = S_i[nabor]; k < S_i[nabor+1]; k++)
@@ -1196,12 +1195,12 @@ hypre_BoomerAMGCoarsenRuge( hypre_ParCSRMatrix    *S,
                if (CF_marker[nabor_two] == UNDECIDED)
                {
                   measure = measure_array[nabor_two];
-                  remove_point(&LoL_head, &LoL_tail, measure, 
+                  hypre_remove_point(&LoL_head, &LoL_tail, measure, 
                                nabor_two, lists, where);
 
                   new_meas = ++(measure_array[nabor_two]);
                  
-                  enter_on_lists(&LoL_head, &LoL_tail, new_meas,
+                  hypre_enter_on_lists(&LoL_head, &LoL_tail, new_meas,
                                  nabor_two, lists, where);
                }
             }
@@ -1214,12 +1213,12 @@ hypre_BoomerAMGCoarsenRuge( hypre_ParCSRMatrix    *S,
          {
             measure = measure_array[nabor];
 
-            remove_point(&LoL_head, &LoL_tail, measure, nabor, lists, where);
+            hypre_remove_point(&LoL_head, &LoL_tail, measure, nabor, lists, where);
 
             measure_array[nabor] = --measure;
 	
 	    if (measure > 0)
-               enter_on_lists(&LoL_head, &LoL_tail, measure, nabor, 
+               hypre_enter_on_lists(&LoL_head, &LoL_tail, measure, nabor, 
 				lists, where);
 	    else
 	    {
@@ -1232,12 +1231,12 @@ hypre_BoomerAMGCoarsenRuge( hypre_ParCSRMatrix    *S,
                   if (CF_marker[nabor_two] == UNDECIDED)
                   {
                      new_meas = measure_array[nabor_two];
-                     remove_point(&LoL_head, &LoL_tail, new_meas, 
+                     hypre_remove_point(&LoL_head, &LoL_tail, new_meas, 
                                nabor_two, lists, where);
 
                      new_meas = ++(measure_array[nabor_two]);
                  
-                     enter_on_lists(&LoL_head, &LoL_tail, new_meas,
+                     hypre_enter_on_lists(&LoL_head, &LoL_tail, new_meas,
                                  nabor_two, lists, where);
                   }
                }
@@ -1974,6 +1973,10 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
                         HYPRE_Int                    debug_flag,
                         HYPRE_Int                  **CF_marker_ptr)
 {
+#ifdef HYPRE_PROFILE
+   hypre_profile_times[HYPRE_TIMER_ID_PMIS] -= hypre_MPI_Wtime();
+#endif
+
    MPI_Comm 	       comm            = hypre_ParCSRMatrixComm(S);
    hypre_ParCSRCommPkg      *comm_pkg        = hypre_ParCSRMatrixCommPkg(S);
    hypre_ParCSRCommHandle   *comm_handle;
@@ -2015,6 +2018,7 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
    HYPRE_Real	    wall_time;
    HYPRE_Int   iter = 0;
 
+   HYPRE_Int *prefix_sum_workspace;
 
 
 #if 0 /* debugging */
@@ -2091,10 +2095,27 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
    measure_array = hypre_CTAlloc(HYPRE_Real, num_variables+num_cols_offd);
 
    /* first calculate the local part of the sums for the external nodes */
+#ifdef HYPRE_USING_OPENMP
+   HYPRE_Int *measure_array_temp = hypre_CTAlloc(HYPRE_Int, num_variables+num_cols_offd);
+
+#pragma omp parallel for private(i) HYPRE_SMP_SCHEDULE
+   for (i=0; i < S_offd_i[num_variables]; i++)
+   {
+#pragma omp atomic
+      measure_array_temp[num_variables + S_offd_j[i]]++;
+   }
+
+#pragma omp parallel for private(i) HYPRE_SMP_SCHEDULE
+   for (i=0; i < num_cols_offd; i++)
+   {
+     measure_array[i + num_variables] = measure_array_temp[i + num_variables];
+   }
+#else
    for (i=0; i < S_offd_i[num_variables]; i++)
    { 
       measure_array[num_variables + S_offd_j[i]] += 1.0;
    }
+#endif // HYPRE_USING_OPENMP
 
    /* now send those locally calculated values for the external nodes to the neighboring processors */
    if (num_procs > 1)
@@ -2102,10 +2123,27 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
                         &measure_array[num_variables], buf_data);
 
    /* calculate the local part for the local nodes */
+#ifdef HYPRE_USING_OPENMP
+#pragma omp parallel for private(i) HYPRE_SMP_SCHEDULE
+   for (i=0; i < S_diag_i[num_variables]; i++)
+   {
+#pragma omp atomic
+      measure_array_temp[S_diag_j[i]]++;
+   }
+
+#pragma omp parallel for private(i) HYPRE_SMP_SCHEDULE
+   for (i=0; i < num_variables; i++)
+   {
+     measure_array[i] = measure_array_temp[i];
+   }
+
+   hypre_TFree(measure_array_temp);
+#else
    for (i=0; i < S_diag_i[num_variables]; i++)
    { 
       measure_array[S_diag_j[i]] += 1.0;
    }
+#endif // HYPRE_USING_OPENMP
 
    /* finish the communication */
    if (num_procs > 1)
@@ -2192,7 +2230,7 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
          if ( (S_diag_i[i+1]-S_diag_i[i]) == 0
                 && (S_offd_i[i+1]-S_offd_i[i]) == 0)
          {
-            CF_marker[i] = SF_PT;
+            CF_marker[i] = SF_PT; /* an isolated fine grid */
             if (CF_init == 3 || CF_init == 4) CF_marker[i] = C_PT; 
             measure_array[i] = 0;
          }
@@ -2242,6 +2280,11 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
                      my_id, wall_time); 
    }
 
+   HYPRE_Int                *graph_array2 = hypre_CTAlloc(HYPRE_Int, num_variables);
+   HYPRE_Int *graph_array_offd2 = NULL;
+   if (num_cols_offd)
+     graph_array_offd2 = hypre_CTAlloc(HYPRE_Int, num_cols_offd);
+
    /*******************************************************************************
     THE INDEPENDENT SET COARSENING LOOP:
    ******************************************************************************/      
@@ -2275,6 +2318,9 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
 				graph_size, 
 				graph_array_offd, graph_offd_size, 
 				CF_marker, CF_marker_offd);*/
+#ifdef HYPRE_USING_OPENMP
+#pragma omp parallel for private(ig, i) HYPRE_SMP_SCHEDULE
+#endif
         for (ig = 0; ig < graph_size; ig++)
         {
            i = graph_array[ig];
@@ -2283,6 +2329,9 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
               CF_marker[i] = 1;
            }
         }
+#ifdef HYPRE_USING_OPENMP
+#pragma omp parallel for private(ig, i) HYPRE_SMP_SCHEDULE
+#endif
         for (ig = 0; ig < graph_offd_size; ig++)
         {
            i = graph_array_offd[ig];
@@ -2314,7 +2363,7 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
                     else if (measure_array[j] > measure_array[i])
                        CF_marker[i] = 0;
                  }
-              }
+              } /* for each local neighbor j of i */
               for (jS = S_offd_i[i]; jS < S_offd_i[i+1]; jS++)
               {
                  jj = S_offd_j[jS];
@@ -2327,8 +2376,8 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
                        CF_marker[i] = 0;
                  }
               }
-           }
-        }
+           } /* for each node with measure > 1 */
+        } /* for each node i */
 
 
       /*------------------------------------------------
@@ -2377,12 +2426,15 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
       * Set C-pts and F-pts.
       *------------------------------------------------*/
 
+#ifdef HYPRE_USING_OPENMP
+#pragma omp parallel for private(ig, i, jS, j) HYPRE_SMP_SCHEDULE
+#endif
      for (ig = 0; ig < graph_size; ig++) {
        i = graph_array[ig];
 
        /*---------------------------------------------
 	* If the measure of i is smaller than 1, then
-        * make i an F point (because it does not influence
+        * make i and F point (because it does not influence
         * any other point)
 	*---------------------------------------------*/
 
@@ -2452,36 +2504,84 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
       * Update subgraph
       *------------------------------------------------*/
 
-     for (ig = 0; ig < graph_size; ig++) {
-       i = graph_array[ig];
-       
-       if (!CF_marker[i]==0) /* C or F point */
-	 {
-	   /* the independent set subroutine needs measure 0 for
-              removed nodes */
-	   measure_array[i] = 0;
-	   /* take point out of the subgraph */
-	   graph_size--;
-	   graph_array[ig] = graph_array[graph_size];
-	   graph_array[graph_size] = i;
-	   ig--;
-	 }
-     }
-     for (ig = 0; ig < graph_offd_size; ig++) {
-       i = graph_array_offd[ig];
-       
-       if (!CF_marker_offd[i]==0) /* C or F point */
-	 {
-	   /* the independent set subroutine needs measure 0 for
-              removed nodes */
-	   measure_array[i+num_variables] = 0;
-	   /* take point out of the subgraph */
-	   graph_offd_size--;
-	   graph_array_offd[ig] = graph_array_offd[graph_offd_size];
-	   graph_array_offd[graph_offd_size] = i;
-	   ig--;
-	 }
-     }
+    /*HYPRE_Int prefix_sum_workspace[2*(hypre_NumThreads() + 1)];*/
+    prefix_sum_workspace = hypre_TAlloc(HYPRE_Int, 2*(hypre_NumThreads() + 1));
+
+#ifdef HYPRE_USING_OPENMP
+#pragma omp parallel private(ig,i)
+#endif
+     {
+        HYPRE_Int private_graph_size_cnt = 0;
+        HYPRE_Int private_graph_offd_size_cnt = 0;
+
+        HYPRE_Int ig_begin, ig_end;
+        hypre_GetSimpleThreadPartition(&ig_begin, &ig_end, graph_size);
+
+        HYPRE_Int ig_offd_begin, ig_offd_end;
+        hypre_GetSimpleThreadPartition(&ig_offd_begin, &ig_offd_end, graph_offd_size);
+
+        for (ig = ig_begin; ig < ig_end; ig++)
+        {
+           i = graph_array[ig];
+
+           if (!CF_marker[i]==0) /* C or F point */
+           {
+              /* the independent set subroutine needs measure 0 for
+                 removed nodes */
+              measure_array[i] = 0;
+           }
+           else
+           {
+              private_graph_size_cnt++;
+           }
+        }
+
+        for (ig = ig_offd_begin; ig < ig_offd_end; ig++)
+        {
+           i = graph_array_offd[ig];
+
+           if (!CF_marker_offd[i]==0) /* C of F point */
+           {
+              /* the independent set subroutine needs measure 0 for
+                 removed nodes */
+              measure_array[i + num_variables] = 0;
+           }
+           else
+           {
+              private_graph_offd_size_cnt++;
+           }
+        }
+
+        hypre_prefix_sum_pair(&private_graph_size_cnt, &graph_size, &private_graph_offd_size_cnt, &graph_offd_size, prefix_sum_workspace);
+
+        for (ig = ig_begin; ig < ig_end; ig++)
+        {
+           i = graph_array[ig];
+           if (CF_marker[i]==0)
+           {
+              graph_array2[private_graph_size_cnt++] = i;
+           }
+        }
+
+        for (ig = ig_offd_begin; ig < ig_offd_end; ig++)
+        {
+           i = graph_array_offd[ig];
+           if (CF_marker_offd[i]==0)
+           {
+              graph_array_offd2[private_graph_offd_size_cnt++] = i;
+           }
+        }
+     } /* omp parallel */
+
+     HYPRE_Int *temp = graph_array;
+     graph_array = graph_array2;
+     graph_array2 = temp;
+
+     temp = graph_array_offd;
+     graph_array_offd = graph_array_offd2;
+     graph_array_offd2 = temp;
+
+     hypre_TFree(prefix_sum_workspace);
      
    } /* end while */
 
@@ -2502,6 +2602,8 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
 
    hypre_TFree(measure_array);
    hypre_TFree(graph_array);
+   hypre_TFree(graph_array2);
+   hypre_TFree(graph_array_offd2);
    if (num_cols_offd) hypre_TFree(graph_array_offd);
    hypre_TFree(buf_data);
    hypre_TFree(int_buf_data);
@@ -2510,5 +2612,9 @@ hypre_BoomerAMGCoarsenPMIS( hypre_ParCSRMatrix    *S,
 
    *CF_marker_ptr   = CF_marker;
 
+#ifdef HYPRE_PROFILE
+   hypre_profile_times[HYPRE_TIMER_ID_PMIS] += hypre_MPI_Wtime();
+#endif
+
    return (ierr);
 }
