@@ -33,9 +33,8 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
                    hypre_ParVector  **F_array,
                    hypre_ParVector  **U_array   )
 {
-   hypre_ParAMGData *amg_data = amg_vdata;
+   hypre_ParAMGData *amg_data = (hypre_ParAMGData*) amg_vdata;
 
-   MPI_Comm comm;
    HYPRE_Solver *smoother;
    /* Data Structure variables */
 
@@ -103,7 +102,7 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
 /*   HYPRE_Int      *smooth_option; */
    HYPRE_Int       smooth_type;
    HYPRE_Int       smooth_num_levels;
-   HYPRE_Int       num_threads;
+   HYPRE_Int       num_threads, my_id;
 
    HYPRE_Real    alpha;
    HYPRE_Real  **l1_norms = NULL;
@@ -111,6 +110,8 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
 
    HYPRE_Int seq_cg = 0;
 
+   MPI_Comm comm;
+
 #if 0
    HYPRE_Real   *D_mat;
    HYPRE_Real   *S_vec;
@@ -168,6 +169,7 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
    num_coeffs = hypre_CTAlloc(HYPRE_Real, num_levels);
    num_coeffs[0]    = hypre_ParCSRMatrixDNumNonzeros(A_array[0]);
    comm = hypre_ParCSRMatrixComm(A_array[0]);
+   hypre_MPI_Comm_rank(comm,&my_id);
 
    if (block_mode)
    {
@@ -181,7 +183,6 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
          num_coeffs[j] = hypre_ParCSRMatrixDNumNonzeros(A_array[j]);
    }
    
-   
    /*---------------------------------------------------------------------
     *    Initialize cycling control counter
     *
@@ -219,10 +220,20 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
           || smooth_type == 17 || smooth_type == 18
           || smooth_type == 9 || smooth_type == 19)
       {
+         HYPRE_Int actual_local_size = hypre_ParVectorActualLocalSize(Vtemp);
          Utemp = hypre_ParVectorCreate(comm,hypre_ParVectorGlobalSize(Vtemp),
                         hypre_ParVectorPartitioning(Vtemp));
          hypre_ParVectorOwnsPartitioning(Utemp) = 0;
-         hypre_ParVectorInitialize(Utemp);
+         local_size 
+            = hypre_VectorSize(hypre_ParVectorLocalVector(Vtemp));
+         if (local_size < actual_local_size)
+         {
+            hypre_VectorData(hypre_ParVectorLocalVector(Utemp)) =
+	 	hypre_CTAlloc(HYPRE_Complex, actual_local_size);
+            hypre_ParVectorActualLocalSize(Utemp) = actual_local_size;
+         }
+         else
+	     hypre_ParVectorInitialize(Utemp);
       }
    }
    
@@ -253,11 +264,10 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
            Ztemp_data = hypre_VectorData(hypre_ParVectorLocalVector(Ztemp));
            Ptemp_data = hypre_VectorData(hypre_ParVectorLocalVector(Ptemp));
            hypre_ParVectorSetConstantValues(Ztemp,0);
-           hypre_ParVectorCopy(F_array[level],Rtemp);
            alpha = -1.0;
            beta = 1.0;
-           hypre_ParCSRMatrixMatvec(alpha, A_array[level], 
-                                U_array[level], beta, Rtemp);
+           hypre_ParCSRMatrixMatvecOutOfPlace(alpha, A_array[level], 
+                                U_array[level], beta, F_array[level], Rtemp);
 	   cg_num_sweep = hypre_ParAMGDataSmoothNumSweeps(amg_data);
            num_sweep = num_grid_sweeps[cycle_param];
            Aux_U = Ztemp;
@@ -347,11 +357,10 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
 			smooth_type == 17 || smooth_type == 18))
               {
                  hypre_VectorSize(hypre_ParVectorLocalVector(Utemp)) = local_size;
-                 hypre_ParVectorCopy(Aux_F,Vtemp);
                  alpha = -1.0;
                  beta = 1.0;
-                 hypre_ParCSRMatrixMatvec(alpha, A_array[level], 
-                                U_array[level], beta, Vtemp);
+                 hypre_ParCSRMatrixMatvecOutOfPlace(alpha, A_array[level], 
+                                U_array[level], beta, Aux_F, Vtemp);
                  if (smooth_type == 8 || smooth_type == 18)
                     HYPRE_ParCSRParaSailsSolve(smoother[level],
                                  (HYPRE_ParCSRMatrix) A_array[level],
@@ -555,19 +564,20 @@ hypre_BoomerAMGCycle( void              *amg_vdata,
 
          hypre_ParVectorSetConstantValues(U_array[coarse_grid], 0.0); 
           
-         hypre_ParVectorCopy(F_array[fine_grid],Vtemp);
          alpha = -1.0;
          beta = 1.0;
 
          if (block_mode)
          {
+            hypre_ParVectorCopy(F_array[fine_grid],Vtemp);
             hypre_ParCSRBlockMatrixMatvec(alpha, A_block_array[fine_grid], U_array[fine_grid],
                                           beta, Vtemp);
          }
          else 
          {
-            hypre_ParCSRMatrixMatvec(alpha, A_array[fine_grid], U_array[fine_grid],
-                                     beta, Vtemp);
+            // JSP: avoid unnecessary copy using out-of-place version of SpMV
+            hypre_ParCSRMatrixMatvecOutOfPlace(alpha, A_array[fine_grid], U_array[fine_grid],
+                                               beta, F_array[fine_grid], Vtemp);
          }
 
          alpha = 1.0;
