@@ -31,8 +31,15 @@
 #include <essl.h>
 #else
 #include "fortran.h"
+#ifdef __cplusplus
+extern "C" {
+#endif
 HYPRE_Int hypre_F90_NAME_LAPACK(dgels, DGELS)(char *, HYPRE_Int *, HYPRE_Int *, HYPRE_Int *, HYPRE_Real *, 
   HYPRE_Int *, HYPRE_Real *, HYPRE_Int *, HYPRE_Real *, HYPRE_Int *, HYPRE_Int *);
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
 #ifndef ABS
@@ -457,7 +464,7 @@ hypre_BoomerAMGCreateSmoothVecs(void         *data,
                        HYPRE_Int                    level,
                        HYPRE_Real           **SmoothVecs_p)
 {
-   hypre_ParAMGData  *amg_data = data;
+   hypre_ParAMGData  *amg_data = (hypre_ParAMGData*) data;
 
    MPI_Comm             comm     = hypre_ParCSRMatrixComm(A);
    hypre_ParCSRCommPkg *comm_pkg = hypre_ParCSRMatrixCommPkg(A);
@@ -608,7 +615,7 @@ hypre_BoomerAMGCreateSmoothDirs(void         *data,
                        HYPRE_Int                   *dof_func,
                        hypre_ParCSRMatrix   **S_ptr)
 {
-   hypre_ParAMGData  *amg_data = data;
+   hypre_ParAMGData  *amg_data = (hypre_ParAMGData*) data;
    hypre_ParCSRMatrix *S;
    HYPRE_Real minimax;
    HYPRE_Int debug_flag = hypre_ParAMGDataDebugFlag(amg_data);
@@ -736,7 +743,7 @@ hypre_BoomerAMGFitVectors(HYPRE_Int ip, HYPRE_Int n, HYPRE_Int num, const HYPRE_
       b, &temp, work, &work_size, &info);
 
    if (info != 0)
-      hypre_printf("par_gsmg: dgels returned %d\n", info);
+      hypre_error_w_msg(HYPRE_ERROR_GENERIC,"par_gsmg: dgels returned %d\n");
 
    /* copy solution into output vector */
    for (j=0; j<nc; j++)
@@ -1249,7 +1256,7 @@ hypre_BoomerAMGBuildInterpLS( hypre_ParCSRMatrix   *A,
       for (i=0; i < P_offd_size; i++)
 	 P_marker[i] = P_offd_j[i];
 
-      qsort0(P_marker, 0, P_offd_size-1);
+      hypre_qsort0(P_marker, 0, P_offd_size-1);
 
       num_cols_P_offd = 1;
       index = P_marker[0];
@@ -2108,7 +2115,7 @@ hypre_BoomerAMGBuildInterpGSMG( hypre_ParCSRMatrix   *A,
       for (i=0; i < P_offd_size; i++)
 	 P_marker[i] = P_offd_j[i];
 
-      qsort0(P_marker, 0, P_offd_size-1);
+      hypre_qsort0(P_marker, 0, P_offd_size-1);
 
       num_cols_P_offd = 1;
       index = P_marker[0];
