@@ -355,7 +355,7 @@ GenerateRotate7pt( MPI_Comm comm,
       for (i=0; i < o_cnt; i++)
          work[i] = offd_j[i];
 
-      qsort0(work, 0, o_cnt-1);
+      hypre_qsort0(work, 0, o_cnt-1);
 
       col_map_offd[0] = work[0];
       cnt = 0;
@@ -382,6 +382,19 @@ GenerateRotate7pt( MPI_Comm comm,
 
       hypre_TFree(work);
    }
+#ifdef HYPRE_NO_GLOBAL_PARTITION
+/* ideally we would use less storage earlier in this function, but this is fine
+   for testing */
+   {
+      HYPRE_Int tmp1, tmp2;
+      tmp1 = global_part[my_id];
+      tmp2 = global_part[my_id + 1];
+      hypre_TFree(global_part);
+      global_part = hypre_CTAlloc(HYPRE_Int, 2);
+      global_part[0] = tmp1;
+      global_part[1] = tmp2;
+   }
+#endif
 
    A = hypre_ParCSRMatrixCreate(comm, grid_size, grid_size,
                                 global_part, global_part, num_cols_offd,
