@@ -36,23 +36,50 @@ extern "C" {
  *   Structure containing information for doing communications
  *--------------------------------------------------------------------------*/
 
+/*#define HYPRE_USING_PERSISTENT_COMM*/ // JSP: can be defined by configure
+#ifdef HYPRE_USING_PERSISTENT_COMM
+typedef enum CommPkgJobType
+{
+   HYPRE_COMM_PKG_JOB_COMPLEX = 0,
+   HYPRE_COMM_PKG_JOB_COMPLEX_TRANSPOSE,
+   HYPRE_COMM_PKG_JOB_INT,
+   HYPRE_COMM_PKG_JOB_INT_TRANSPOSE,
+   NUM_OF_COMM_PKG_JOB_TYPE,
+} CommPkgJobType;
+
+typedef struct
+{
+   void     *send_data;
+   void     *recv_data;
+
+   HYPRE_Int             num_requests;
+   hypre_MPI_Request    *requests;
+
+   HYPRE_Int own_send_data, own_recv_data;
+
+} hypre_ParCSRPersistentCommHandle;
+#endif
+
 typedef struct
 {
    MPI_Comm               comm;
-   
-   HYPRE_Int              num_sends;
-   HYPRE_Int             *send_procs;
-   HYPRE_Int             *send_map_starts;
-   HYPRE_Int             *send_map_elmts;
-   
-   HYPRE_Int              num_recvs;
-   HYPRE_Int             *recv_procs;
-   HYPRE_Int             *recv_vec_starts;
-   
+
+   HYPRE_Int                    num_sends;
+   HYPRE_Int                   *send_procs;
+   HYPRE_Int			 *send_map_starts;
+   HYPRE_Int			 *send_map_elmts;
+
+   HYPRE_Int                    num_recvs;
+   HYPRE_Int                   *recv_procs;
+   HYPRE_Int                   *recv_vec_starts;
+
    /* remote communication information */
-   hypre_MPI_Datatype    *send_mpi_types;
-   hypre_MPI_Datatype    *recv_mpi_types;
-   
+   hypre_MPI_Datatype          *send_mpi_types;
+   hypre_MPI_Datatype          *recv_mpi_types;
+
+#ifdef HYPRE_USING_PERSISTENT_COMM
+   hypre_ParCSRPersistentCommHandle *persistent_comm_handles[NUM_OF_COMM_PKG_JOB_TYPE];
+#endif
 } hypre_ParCSRCommPkg;
 
 /*--------------------------------------------------------------------------
@@ -62,12 +89,12 @@ typedef struct
 typedef struct
 {
    hypre_ParCSRCommPkg  *comm_pkg;
-   void                 *send_data;
-   void                 *recv_data;
-   
+   void 	  *send_data;
+   void 	  *recv_data;
+
    HYPRE_Int             num_requests;
    hypre_MPI_Request    *requests;
-   
+
 } hypre_ParCSRCommHandle;
 
 /*--------------------------------------------------------------------------
@@ -108,25 +135,50 @@ typedef struct
 #define hypre_ParCSRCommHandleRequest(comm_handle, i)  (comm_handle -> requests[i])
 
 #endif /* HYPRE_PAR_CSR_COMMUNICATION_HEADER */
+/*BHEADER**********************************************************************
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
+ * Produced at the Lawrence Livermore National Laboratory.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
+ *
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
+ *
+ * $Revision$
+ ***********************************************************************EHEADER*/
 
 #ifndef hypre_PARCSR_ASSUMED_PART
 #define  hypre_PARCSR_ASSUMED_PART
 
 typedef struct
 {
-   HYPRE_Int   length;
-   HYPRE_Int   row_start;
-   HYPRE_Int   row_end;
-   HYPRE_Int   storage_length;
-   HYPRE_Int  *proc_list;
-   HYPRE_Int  *row_start_list;
-   HYPRE_Int  *row_end_list;  
-   HYPRE_Int  *sort_index;
-
+   HYPRE_Int                   length;
+   HYPRE_Int                   row_start;
+   HYPRE_Int                   row_end;
+   HYPRE_Int                   storage_length;
+   HYPRE_Int                   *proc_list;
+   HYPRE_Int		         *row_start_list;
+   HYPRE_Int                   *row_end_list;  
+  HYPRE_Int                    *sort_index;
 } hypre_IJAssumedPart;
 
+
+
+
 #endif /* hypre_PARCSR_ASSUMED_PART */
 
+/*BHEADER**********************************************************************
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
+ * Produced at the Lawrence Livermore National Laboratory.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
+ *
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
+ *
+ * $Revision$
+ ***********************************************************************EHEADER*/
+
 #ifndef hypre_NEW_COMMPKG
 #define hypre_NEW_COMMPKG
 
@@ -145,6 +197,22 @@ typedef struct
 
 #endif /* hypre_NEW_COMMPKG */
 
+/*BHEADER**********************************************************************
+ * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
+ * Produced at the Lawrence Livermore National Laboratory.
+ * This file is part of HYPRE.  See file COPYRIGHT for details.
+ *
+ * HYPRE is free software; you can redistribute it and/or modify it under the
+ * terms of the GNU Lesser General Public License (as published by the Free
+ * Software Foundation) version 2.1 dated February 1999.
+ *
+ * $Revision$
+ ***********************************************************************EHEADER*/
+
+
+
+
+
 /******************************************************************************
  *
  * Header info for Parallel Vector data structure
@@ -154,6 +222,7 @@ typedef struct
 #ifndef hypre_PAR_VECTOR_HEADER
 #define hypre_PAR_VECTOR_HEADER
 
+
 /*--------------------------------------------------------------------------
  * hypre_ParVector
  *--------------------------------------------------------------------------*/
@@ -164,23 +233,25 @@ typedef struct
 
 typedef struct hypre_ParVector_struct
 {
-   MPI_Comm      comm;
+   MPI_Comm	 comm;
 
-   HYPRE_Int     global_size;
-   HYPRE_Int     first_index;
-   HYPRE_Int     last_index;
-   HYPRE_Int    *partitioning;
-   hypre_Vector *local_vector; 
+   HYPRE_Int      	 global_size;
+   HYPRE_Int      	 first_index;
+   HYPRE_Int             last_index;
+   HYPRE_Int      	*partitioning;
+   HYPRE_Int      	 actual_local_size; /* stores actual length of data in local vector
+			to allow memory manipulations for temporary vectors*/
+   hypre_Vector	*local_vector; 
 
    /* Does the Vector create/destroy `data'? */
-   HYPRE_Int     owns_data;
-   HYPRE_Int     owns_partitioning;
+   HYPRE_Int      	 owns_data;
+   HYPRE_Int      	 owns_partitioning;
+
+   hypre_IJAssumedPart *assumed_partition; /* only populated if no_global_partition option
+                                              is used (compile-time option) AND this partition
+                                              needed
+                                              (for setting off-proc elements, for example)*/
 
-   hypre_IJAssumedPart *assumed_partition; /* only populated if
-                                              no_global_partition option is used
-                                              (compile-time option) AND this
-                                              partition needed (for setting
-                                              off-proc elements, for example)*/
 
 } hypre_ParVector;
 
@@ -188,19 +259,21 @@ typedef struct hypre_ParVector_struct
  * Accessor functions for the Vector structure
  *--------------------------------------------------------------------------*/
 
-#define hypre_ParVectorComm(vector)             ((vector) -> comm)
+#define hypre_ParVectorComm(vector)  	        ((vector) -> comm)
 #define hypre_ParVectorGlobalSize(vector)       ((vector) -> global_size)
 #define hypre_ParVectorFirstIndex(vector)       ((vector) -> first_index)
 #define hypre_ParVectorLastIndex(vector)        ((vector) -> last_index)
 #define hypre_ParVectorPartitioning(vector)     ((vector) -> partitioning)
+#define hypre_ParVectorActualLocalSize(vector)  ((vector) -> actual_local_size)
 #define hypre_ParVectorLocalVector(vector)      ((vector) -> local_vector)
 #define hypre_ParVectorOwnsData(vector)         ((vector) -> owns_data)
 #define hypre_ParVectorOwnsPartitioning(vector) ((vector) -> owns_partitioning)
-#define hypre_ParVectorNumVectors(vector)                               \
-   (hypre_VectorNumVectors( hypre_ParVectorLocalVector(vector) ))
+#define hypre_ParVectorNumVectors(vector)\
+ (hypre_VectorNumVectors( hypre_ParVectorLocalVector(vector) ))
 
 #define hypre_ParVectorAssumedPartition(vector) ((vector) -> assumed_partition)
 
+
 #endif
 /*BHEADER**********************************************************************
  * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
@@ -236,7 +309,7 @@ typedef struct hypre_ParVector_struct
 typedef struct hypre_ParCSRMatrix_struct
 {
    MPI_Comm              comm;
-   
+
    HYPRE_Int             global_num_rows;
    HYPRE_Int             global_num_cols;
    HYPRE_Int             first_row_index;
@@ -245,22 +318,24 @@ typedef struct hypre_ParCSRMatrix_struct
       are null  (i.e., bgl) AHB 6/05*/
    HYPRE_Int             last_row_index;
    HYPRE_Int             last_col_diag;
-   
+
    hypre_CSRMatrix      *diag;
    hypre_CSRMatrix      *offd;
+   hypre_CSRMatrix      *diagT, *offdT;
+        /* JSP: transposed matrices are created lazily and optional */
    HYPRE_Int            *col_map_offd; 
-   /* maps columns of offd to global columns */
+        /* maps columns of offd to global columns */
    HYPRE_Int            *row_starts; 
-   /* array of length num_procs+1, row_starts[i] contains the 
-      global number of the first row on proc i,  
-      first_row_index = row_starts[my_id],
-      row_starts[num_procs] = global_num_rows */
+        /* array of length num_procs+1, row_starts[i] contains the 
+           global number of the first row on proc i,  
+           first_row_index = row_starts[my_id],
+           row_starts[num_procs] = global_num_rows */
    HYPRE_Int            *col_starts;
-   /* array of length num_procs+1, col_starts[i] contains the 
-      global number of the first column of diag on proc i,  
-      first_col_diag = col_starts[my_id],
-      col_starts[num_procs] = global_num_cols */
-   
+        /* array of length num_procs+1, col_starts[i] contains the 
+           global number of the first column of diag on proc i,  
+           first_col_diag = col_starts[my_id],
+           col_starts[num_procs] = global_num_cols */
+
    hypre_ParCSRCommPkg  *comm_pkg;
    hypre_ParCSRCommPkg  *comm_pkgT;
    
@@ -269,19 +344,19 @@ typedef struct hypre_ParCSRMatrix_struct
    /* Does the ParCSRMatrix create/destroy `row_starts', `col_starts'? */
    HYPRE_Int             owns_row_starts;
    HYPRE_Int             owns_col_starts;
-   
+
    HYPRE_Int             num_nonzeros;
    HYPRE_Real            d_num_nonzeros;
-   
+
    /* Buffers used by GetRow to hold row currently being accessed. AJC, 4/99 */
    HYPRE_Int            *rowindices;
    HYPRE_Complex        *rowvalues;
    HYPRE_Int             getrowactive;
-   
+
    hypre_IJAssumedPart  *assumed_partition; /* only populated if
                                               no_global_partition option is used
-                                              (compile-time option) */
-   
+                                              (compile-time option)*/
+
 } hypre_ParCSRMatrix;
 
 /*--------------------------------------------------------------------------
@@ -297,6 +372,8 @@ typedef struct hypre_ParCSRMatrix_struct
 #define hypre_ParCSRMatrixLastColDiag(matrix)     ((matrix) -> last_col_diag)
 #define hypre_ParCSRMatrixDiag(matrix)            ((matrix) -> diag)
 #define hypre_ParCSRMatrixOffd(matrix)            ((matrix) -> offd)
+#define hypre_ParCSRMatrixDiagT(matrix)            ((matrix) -> diagT)
+#define hypre_ParCSRMatrixOffdT(matrix)            ((matrix) -> offdT)
 #define hypre_ParCSRMatrixColMapOffd(matrix)      ((matrix) -> col_map_offd)
 #define hypre_ParCSRMatrixRowStarts(matrix)       ((matrix) -> row_starts)
 #define hypre_ParCSRMatrixColStarts(matrix)       ((matrix) -> col_starts)
@@ -305,10 +382,10 @@ typedef struct hypre_ParCSRMatrix_struct
 #define hypre_ParCSRMatrixOwnsData(matrix)        ((matrix) -> owns_data)
 #define hypre_ParCSRMatrixOwnsRowStarts(matrix)   ((matrix) -> owns_row_starts)
 #define hypre_ParCSRMatrixOwnsColStarts(matrix)   ((matrix) -> owns_col_starts)
-#define hypre_ParCSRMatrixNumRows(matrix)                       \
-   hypre_CSRMatrixNumRows(hypre_ParCSRMatrixDiag(matrix))
-#define hypre_ParCSRMatrixNumCols(matrix)                       \
-   hypre_CSRMatrixNumCols(hypre_ParCSRMatrixDiag(matrix))
+#define hypre_ParCSRMatrixNumRows(matrix) \
+hypre_CSRMatrixNumRows(hypre_ParCSRMatrixDiag(matrix))
+#define hypre_ParCSRMatrixNumCols(matrix) \
+hypre_CSRMatrixNumCols(hypre_ParCSRMatrixDiag(matrix))
 #define hypre_ParCSRMatrixNumNonzeros(matrix)     ((matrix) -> num_nonzeros)
 #define hypre_ParCSRMatrixDNumNonzeros(matrix)    ((matrix) -> d_num_nonzeros)
 #define hypre_ParCSRMatrixRowindices(matrix)      ((matrix) -> rowindices)
@@ -316,8 +393,6 @@ typedef struct hypre_ParCSRMatrix_struct
 #define hypre_ParCSRMatrixGetrowactive(matrix)    ((matrix) -> getrowactive)
 #define hypre_ParCSRMatrixAssumedPartition(matrix) ((matrix) -> assumed_partition)
 
-
-
 /*--------------------------------------------------------------------------
  * Parallel CSR Boolean Matrix
  *--------------------------------------------------------------------------*/
@@ -344,7 +419,7 @@ typedef struct
    HYPRE_Int               num_nonzeros;
    HYPRE_Int              *rowindices;
    HYPRE_Int               getrowactive;
-   
+
 } hypre_ParCSRBooleanMatrix;
 
 /*--------------------------------------------------------------------------
@@ -388,6 +463,9 @@ typedef struct
  * $Revision$
  ***********************************************************************EHEADER*/
 
+
+
+
 /******************************************************************************
  *
  * Tree structure for keeping track of numbers (e.g. column numbers) -
@@ -420,11 +498,9 @@ typedef struct
 #ifndef hypre_NUMBERS_HEADER
 #define hypre_NUMBERS_HEADER
 
-typedef struct {
-   void * digit[11];
-   /* ... should be   hypre_NumbersNode * digit[11]; */
-} hypre_NumbersNode;
-
+typedef struct hypre_NumbersNode{
+   struct hypre_NumbersNode * digit[11];
+} hypre_NumbersNode;	
 
 hypre_NumbersNode * hypre_NumbersNewNode(void);
 void hypre_NumbersDeleteNode( hypre_NumbersNode * node );
@@ -433,6 +509,7 @@ HYPRE_Int hypre_NumbersNEntered( hypre_NumbersNode * node );
 HYPRE_Int hypre_NumbersQuery( hypre_NumbersNode * node, const HYPRE_Int n );
 HYPRE_Int * hypre_NumbersArray( hypre_NumbersNode * node );
 
+
 #endif
 /*BHEADER**********************************************************************
  * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
@@ -468,37 +545,37 @@ typedef struct
 {
    MPI_Comm comm;
 
-   /*  A structure: -------------------------------------------------------- */
-   HYPRE_Int num_inprocessors;
-   HYPRE_Int *inprocessor;
+  /*  A structure: -------------------------------------------------------- */
+  HYPRE_Int num_inprocessors;
+  HYPRE_Int *inprocessor;
 
-   /* receiving in idof from different (in)processors; --------------------- */
-   HYPRE_Int *num_idofs_inprocessor; 
-   HYPRE_Int **idof_inprocessor; 
+  /* receiving in idof from different (in)processors; ---------------------- */
+  HYPRE_Int *num_idofs_inprocessor; 
+  HYPRE_Int **idof_inprocessor; 
 
-   /* symmetric information: ----------------------------------------------- */
-   /* this can be replaces by CSR format: ---------------------------------- */
-   HYPRE_Int *num_inchords;
-   HYPRE_Int **inchord_idof;
-   HYPRE_Int **inchord_rdof;
-   HYPRE_Complex **inchord_data;
+  /* symmetric information: ----------------------------------------------- */
+  /* this can be replaces by CSR format: ---------------------------------- */
+  HYPRE_Int     *num_inchords;
+  HYPRE_Int     **inchord_idof;
+  HYPRE_Int     **inchord_rdof;
+  HYPRE_Complex **inchord_data;
 
-   HYPRE_Int num_idofs;
-   HYPRE_Int num_rdofs;
+  HYPRE_Int num_idofs;
+  HYPRE_Int num_rdofs;
 
-   HYPRE_Int *firstindex_idof; /* not owned by my_id; ---------------------- */
-   HYPRE_Int *firstindex_rdof; /* not owned by my_id; -----------------------*/
+  HYPRE_Int *firstindex_idof; /* not owned by my_id; ---------------------- */
+  HYPRE_Int *firstindex_rdof; /* not owned by my_id; ---------------------- */
 
-   /* --------------------------- mirror information: ---------------------- */
-   /* participation of rdof in different processors; ----------------------- */
+  /* --------------------------- mirror information: ---------------------- */
+  /* participation of rdof in different processors; ----------------------- */
 
-   HYPRE_Int num_toprocessors;
-   HYPRE_Int *toprocessor;
+  HYPRE_Int num_toprocessors;
+  HYPRE_Int *toprocessor;
 
-   /* rdofs to be sentto toprocessors; -------------------------------------
-      ---------------------------------------------------------------------- */
-   HYPRE_Int *num_rdofs_toprocessor;
-   HYPRE_Int **rdof_toprocessor;
+  /* rdofs to be sentto toprocessors; -------------------------------------
+     ---------------------------------------------------------------------- */
+  HYPRE_Int *num_rdofs_toprocessor;
+  HYPRE_Int **rdof_toprocessor;
 
 } hypre_ParChordMatrix;
 
@@ -515,7 +592,6 @@ typedef struct
 #define hypre_ParChordMatrixNumIdofsInprocessor(matrix) ((matrix) -> num_idofs_inprocessor)
 #define hypre_ParChordMatrixIdofInprocessor(matrix) ((matrix) -> idof_inprocessor)
 
-
 #define hypre_ParChordMatrixNumInchords(matrix) ((matrix) -> num_inchords)
 
 #define hypre_ParChordMatrixInchordIdof(matrix) ((matrix) -> inchord_idof)
@@ -534,6 +610,7 @@ typedef struct
 #define hypre_ParChordMatrixNumRdofsToprocessor(matrix) ((matrix) -> num_rdofs_toprocessor)
 #define hypre_ParChordMatrixRdofToprocessor(matrix) ((matrix) -> rdof_toprocessor)
 
+
 #endif
 /*BHEADER**********************************************************************
  * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
@@ -553,16 +630,16 @@ typedef struct
 typedef struct
 {
    hypre_ParCSRMatrix * A;
-   hypre_ParVector    * x;
-   hypre_ParVector    * b;
-   
+   hypre_ParVector * x;
+   hypre_ParVector * b;
+
 } HYPRE_ParCSR_System_Problem;
 
 #endif /* hypre_PAR_MAKE_SYSTEM */
 
 /* communicationT.c */
-void RowsWithColumn_original ( HYPRE_Int *rowmin , HYPRE_Int *rowmax , HYPRE_Int column , hypre_ParCSRMatrix *A );
-void RowsWithColumn ( HYPRE_Int *rowmin , HYPRE_Int *rowmax , HYPRE_Int column , HYPRE_Int num_rows_diag , HYPRE_Int firstColDiag , HYPRE_Int *colMapOffd , HYPRE_Int *mat_i_diag , HYPRE_Int *mat_j_diag , HYPRE_Int *mat_i_offd , HYPRE_Int *mat_j_offd );
+void hypre_RowsWithColumn_original ( HYPRE_Int *rowmin , HYPRE_Int *rowmax , HYPRE_Int column , hypre_ParCSRMatrix *A );
+void hypre_RowsWithColumn ( HYPRE_Int *rowmin , HYPRE_Int *rowmax , HYPRE_Int column , HYPRE_Int num_rows_diag , HYPRE_Int firstColDiag , HYPRE_Int *colMapOffd , HYPRE_Int *mat_i_diag , HYPRE_Int *mat_j_diag , HYPRE_Int *mat_i_offd , HYPRE_Int *mat_j_offd );
 void hypre_MatTCommPkgCreate_core ( MPI_Comm comm , HYPRE_Int *col_map_offd , HYPRE_Int first_col_diag , HYPRE_Int *col_starts , HYPRE_Int num_rows_diag , HYPRE_Int num_cols_diag , HYPRE_Int num_cols_offd , HYPRE_Int *row_starts , HYPRE_Int firstColDiag , HYPRE_Int *colMapOffd , HYPRE_Int *mat_i_diag , HYPRE_Int *mat_j_diag , HYPRE_Int *mat_i_offd , HYPRE_Int *mat_j_offd , HYPRE_Int data , HYPRE_Int *p_num_recvs , HYPRE_Int **p_recv_procs , HYPRE_Int **p_recv_vec_starts , HYPRE_Int *p_num_sends , HYPRE_Int **p_send_procs , HYPRE_Int **p_send_map_starts , HYPRE_Int **p_send_map_elmts );
 HYPRE_Int hypre_MatTCommPkgCreate ( hypre_ParCSRMatrix *A );
 
@@ -617,7 +694,7 @@ HYPRE_Int HYPRE_ParVectorInnerProd ( HYPRE_ParVector x , HYPRE_ParVector y , HYP
 HYPRE_Int HYPRE_VectorToParVector ( MPI_Comm comm , HYPRE_Vector b , HYPRE_Int *partitioning , HYPRE_ParVector *vector );
 
 /* new_commpkg.c */
-HYPRE_Int PrintCommpkg ( hypre_ParCSRMatrix *A , const char *file_name );
+HYPRE_Int hypre_PrintCommpkg ( hypre_ParCSRMatrix *A , const char *file_name );
 HYPRE_Int hypre_NewCommPkgCreate_core ( MPI_Comm comm , HYPRE_Int *col_map_off_d , HYPRE_Int first_col_diag , HYPRE_Int col_start , HYPRE_Int col_end , HYPRE_Int num_cols_off_d , HYPRE_Int global_num_cols , HYPRE_Int *p_num_recvs , HYPRE_Int **p_recv_procs , HYPRE_Int **p_recv_vec_starts , HYPRE_Int *p_num_sends , HYPRE_Int **p_send_procs , HYPRE_Int **p_send_map_starts , HYPRE_Int **p_send_map_elements , hypre_IJAssumedPart *apart );
 HYPRE_Int hypre_NewCommPkgCreate ( hypre_ParCSRMatrix *parcsr_A );
 HYPRE_Int hypre_NewCommPkgDestroy ( hypre_ParCSRMatrix *parcsr_A );
@@ -643,13 +720,12 @@ hypre_ParCSRMatrix *hypre_ParCSRAAt ( hypre_ParCSRMatrix *A );
 hypre_CSRMatrix *hypre_ParCSRMatrixExtractAExt ( hypre_ParCSRMatrix *A , HYPRE_Int data , HYPRE_Int **pA_ext_row_map );
 
 /* par_csr_assumed_part.c */
-HYPRE_Int hypre_LocateAssummedPartition ( MPI_Comm comm , HYPRE_Int row_start , HYPRE_Int row_end , HYPRE_Int global_num_rows , hypre_IJAssumedPart *part , HYPRE_Int myid );
+HYPRE_Int hypre_LocateAssummedPartition ( MPI_Comm comm , HYPRE_Int row_start , HYPRE_Int row_end , HYPRE_Int global_first_row , HYPRE_Int global_num_rows , hypre_IJAssumedPart *part , HYPRE_Int myid );
 HYPRE_Int hypre_ParCSRMatrixCreateAssumedPartition ( hypre_ParCSRMatrix *matrix );
-HYPRE_Int hypre_ParCSRMatrixDestroyAssumedPartition ( hypre_ParCSRMatrix *matrix );
-HYPRE_Int hypre_GetAssumedPartitionProcFromRow ( MPI_Comm comm , HYPRE_Int row , HYPRE_Int global_num_rows , HYPRE_Int *proc_id );
-HYPRE_Int hypre_GetAssumedPartitionRowRange ( MPI_Comm comm , HYPRE_Int proc_id , HYPRE_Int global_num_rows , HYPRE_Int *row_start , HYPRE_Int *row_end );
+HYPRE_Int hypre_AssumedPartitionDestroy ( hypre_IJAssumedPart *apart );
+HYPRE_Int hypre_GetAssumedPartitionProcFromRow ( MPI_Comm comm , HYPRE_Int row , HYPRE_Int global_first_row , HYPRE_Int global_num_rows , HYPRE_Int *proc_id );
+HYPRE_Int hypre_GetAssumedPartitionRowRange ( MPI_Comm comm , HYPRE_Int proc_id , HYPRE_Int global_first_row , HYPRE_Int global_num_rows , HYPRE_Int *row_start , HYPRE_Int *row_end );
 HYPRE_Int hypre_ParVectorCreateAssumedPartition ( hypre_ParVector *vector );
-HYPRE_Int hypre_ParVectorDestroyAssumedPartition ( hypre_ParVector *vector );
 
 /* par_csr_bool_matop.c */
 hypre_ParCSRBooleanMatrix *hypre_ParBooleanMatmul ( hypre_ParCSRBooleanMatrix *A , hypre_ParCSRBooleanMatrix *B );
@@ -681,7 +757,7 @@ HYPRE_Int hypre_ParCSRBooleanMatrixGetRow ( hypre_ParCSRBooleanMatrix *mat , HYP
 HYPRE_Int hypre_ParCSRBooleanMatrixRestoreRow ( hypre_ParCSRBooleanMatrix *matrix , HYPRE_Int row , HYPRE_Int *size , HYPRE_Int **col_ind );
 HYPRE_Int hypre_BuildCSRBooleanMatrixMPIDataType ( HYPRE_Int num_nonzeros , HYPRE_Int num_rows , HYPRE_Int *a_i , HYPRE_Int *a_j , hypre_MPI_Datatype *csr_matrix_datatype );
 hypre_ParCSRBooleanMatrix *hypre_CSRBooleanMatrixToParCSRBooleanMatrix ( MPI_Comm comm , hypre_CSRBooleanMatrix *A , HYPRE_Int *row_starts , HYPRE_Int *col_starts );
-HYPRE_Int BooleanGenerateDiagAndOffd ( hypre_CSRBooleanMatrix *A , hypre_ParCSRBooleanMatrix *matrix , HYPRE_Int first_col_diag , HYPRE_Int last_col_diag );
+HYPRE_Int hypre_BooleanGenerateDiagAndOffd ( hypre_CSRBooleanMatrix *A , hypre_ParCSRBooleanMatrix *matrix , HYPRE_Int first_col_diag , HYPRE_Int last_col_diag );
 
 /* par_csr_communication.c */
 hypre_ParCSRCommHandle *hypre_ParCSRCommHandleCreate ( HYPRE_Int job , hypre_ParCSRCommPkg *comm_pkg , void *send_data , void *recv_data );
@@ -695,16 +771,32 @@ HYPRE_Int hypre_BuildCSRJDataType ( HYPRE_Int num_nonzeros , HYPRE_Complex *a_da
 /* par_csr_matop.c */
 void hypre_ParMatmul_RowSizes ( HYPRE_Int **C_diag_i , HYPRE_Int **C_offd_i , HYPRE_Int *A_diag_i , HYPRE_Int *A_diag_j , HYPRE_Int *A_offd_i , HYPRE_Int *A_offd_j , HYPRE_Int *B_diag_i , HYPRE_Int *B_diag_j , HYPRE_Int *B_offd_i , HYPRE_Int *B_offd_j , HYPRE_Int *B_ext_diag_i , HYPRE_Int *B_ext_diag_j , HYPRE_Int *B_ext_offd_i , HYPRE_Int *B_ext_offd_j , HYPRE_Int *map_B_to_C , HYPRE_Int *C_diag_size , HYPRE_Int *C_offd_size , HYPRE_Int num_rows_diag_A , HYPRE_Int num_cols_offd_A , HYPRE_Int allsquare , HYPRE_Int num_cols_diag_B , HYPRE_Int num_cols_offd_B , HYPRE_Int num_cols_offd_C );
 hypre_ParCSRMatrix *hypre_ParMatmul ( hypre_ParCSRMatrix *A , hypre_ParCSRMatrix *B );
-void hypre_ParCSRMatrixExtractBExt_Arrays ( HYPRE_Int **pB_ext_i , HYPRE_Int **pB_ext_j , HYPRE_Complex **pB_ext_data , HYPRE_Int **pB_ext_row_map , HYPRE_Int *num_nonzeros , HYPRE_Int data , HYPRE_Int find_row_map , MPI_Comm comm , hypre_ParCSRCommPkg *comm_pkg , HYPRE_Int num_cols_B , HYPRE_Int num_recvs , HYPRE_Int num_sends , HYPRE_Int first_col_diag , HYPRE_Int first_row_index , HYPRE_Int *recv_vec_starts , HYPRE_Int *send_map_starts , HYPRE_Int *send_map_elmts , HYPRE_Int *diag_i , HYPRE_Int *diag_j , HYPRE_Int *offd_i , HYPRE_Int *offd_j , HYPRE_Int *col_map_offd , HYPRE_Complex *diag_data , HYPRE_Complex *offd_data );
+void hypre_ParCSRMatrixExtractBExt_Arrays ( HYPRE_Int **pB_ext_i , HYPRE_Int **pB_ext_j , HYPRE_Complex **pB_ext_data , HYPRE_Int **pB_ext_row_map , HYPRE_Int *num_nonzeros , HYPRE_Int data , HYPRE_Int find_row_map , MPI_Comm comm , hypre_ParCSRCommPkg *comm_pkg , HYPRE_Int num_cols_B , HYPRE_Int num_recvs , HYPRE_Int num_sends , HYPRE_Int first_col_diag , HYPRE_Int *row_starts , HYPRE_Int *recv_vec_starts , HYPRE_Int *send_map_starts , HYPRE_Int *send_map_elmts , HYPRE_Int *diag_i , HYPRE_Int *diag_j , HYPRE_Int *offd_i , HYPRE_Int *offd_j , HYPRE_Int *col_map_offd , HYPRE_Real *diag_data , HYPRE_Real *offd_data );
+void hypre_ParCSRMatrixExtractBExt_Arrays_Overlap ( HYPRE_Int **pB_ext_i , HYPRE_Int **pB_ext_j , HYPRE_Complex **pB_ext_data , HYPRE_Int **pB_ext_row_map , HYPRE_Int *num_nonzeros , HYPRE_Int data , HYPRE_Int find_row_map , MPI_Comm comm , hypre_ParCSRCommPkg *comm_pkg , HYPRE_Int num_cols_B , HYPRE_Int num_recvs , HYPRE_Int num_sends , HYPRE_Int first_col_diag , HYPRE_Int *row_starts , HYPRE_Int *recv_vec_starts , HYPRE_Int *send_map_starts , HYPRE_Int *send_map_elmts , HYPRE_Int *diag_i , HYPRE_Int *diag_j , HYPRE_Int *offd_i , HYPRE_Int *offd_j , HYPRE_Int *col_map_offd , HYPRE_Real *diag_data , HYPRE_Real *offd_data, hypre_ParCSRCommHandle **comm_handle_idx, hypre_ParCSRCommHandle **comm_handle_data, HYPRE_Int *CF_marker, HYPRE_Int *CF_marker_offd, HYPRE_Int skip_fine, HYPRE_Int skip_same_sign );
 hypre_CSRMatrix *hypre_ParCSRMatrixExtractBExt ( hypre_ParCSRMatrix *B , hypre_ParCSRMatrix *A , HYPRE_Int data );
+hypre_CSRMatrix *hypre_ParCSRMatrixExtractBExt_Overlap ( hypre_ParCSRMatrix *B , hypre_ParCSRMatrix *A , HYPRE_Int data, hypre_ParCSRCommHandle **comm_handle_idx, hypre_ParCSRCommHandle **comm_handle_data, HYPRE_Int *CF_marker, HYPRE_Int *CF_marker_offd, HYPRE_Int skip_fine, HYPRE_Int skip_same_sign );
 HYPRE_Int hypre_ParCSRMatrixTranspose ( hypre_ParCSRMatrix *A , hypre_ParCSRMatrix **AT_ptr , HYPRE_Int data );
 void hypre_ParCSRMatrixGenSpanningTree ( hypre_ParCSRMatrix *G_csr , HYPRE_Int **indices , HYPRE_Int G_type );
 void hypre_ParCSRMatrixExtractSubmatrices ( hypre_ParCSRMatrix *A_csr , HYPRE_Int *indices2 , hypre_ParCSRMatrix ***submatrices );
 void hypre_ParCSRMatrixExtractRowSubmatrices ( hypre_ParCSRMatrix *A_csr , HYPRE_Int *indices2 , hypre_ParCSRMatrix ***submatrices );
 HYPRE_Complex hypre_ParCSRMatrixLocalSumElts ( hypre_ParCSRMatrix *A );
 HYPRE_Int hypre_ParCSRMatrixAminvDB ( hypre_ParCSRMatrix *A , hypre_ParCSRMatrix *B , HYPRE_Complex *d , hypre_ParCSRMatrix **C_ptr );
-HYPRE_Int hypre_MergeArrays ( HYPRE_Int size_A , HYPRE_Real *A , HYPRE_Int size_B , HYPRE_Real *B , HYPRE_Int *size_C_ptr , HYPRE_Real **C_ptr );
 hypre_ParCSRMatrix *hypre_ParTMatmul ( hypre_ParCSRMatrix *A , hypre_ParCSRMatrix *B );
+#ifdef HYPRE_USING_PERSISTENT_COMM
+hypre_ParCSRPersistentCommHandle *
+hypre_ParCSRCommPkgGetPersistentCommHandle(HYPRE_Int job,
+             hypre_ParCSRCommPkg *comm_pkg);
+
+hypre_ParCSRPersistentCommHandle *
+hypre_ParCSRPersistentCommHandleCreate(HYPRE_Int job,
+             hypre_ParCSRCommPkg *comm_pkg,
+             void *send_data,
+             void *recv_data);
+void
+hypre_ParCSRPersistentCommHandleDestroy(hypre_ParCSRPersistentCommHandle *comm_handle);
+void hypre_ParCSRPersistentCommHandleStart(hypre_ParCSRPersistentCommHandle *comm_handle);
+void hypre_ParCSRPersistentCommHandleWait(hypre_ParCSRPersistentCommHandle *comm_handle);
+#endif
 
 /* par_csr_matop_marked.c */
 void hypre_ParMatmul_RowSizes_Marked ( HYPRE_Int **C_diag_i , HYPRE_Int **C_offd_i , HYPRE_Int **B_marker , HYPRE_Int *A_diag_i , HYPRE_Int *A_diag_j , HYPRE_Int *A_offd_i , HYPRE_Int *A_offd_j , HYPRE_Int *B_diag_i , HYPRE_Int *B_diag_j , HYPRE_Int *B_offd_i , HYPRE_Int *B_offd_j , HYPRE_Int *B_ext_diag_i , HYPRE_Int *B_ext_diag_j , HYPRE_Int *B_ext_offd_i , HYPRE_Int *B_ext_offd_j , HYPRE_Int *map_B_to_C , HYPRE_Int *C_diag_size , HYPRE_Int *C_offd_size , HYPRE_Int num_rows_diag_A , HYPRE_Int num_cols_offd_A , HYPRE_Int allsquare , HYPRE_Int num_cols_diag_B , HYPRE_Int num_cols_offd_B , HYPRE_Int num_cols_offd_C , HYPRE_Int *CF_marker , HYPRE_Int *dof_func , HYPRE_Int *dof_func_offd );
@@ -740,7 +832,12 @@ HYPRE_Int hypre_FillResponseParToCSRMatrix ( void *p_recv_contact_buf , HYPRE_In
 hypre_ParCSRMatrix *hypre_ParCSRMatrixCompleteClone ( hypre_ParCSRMatrix *A );
 hypre_ParCSRMatrix *hypre_ParCSRMatrixUnion ( hypre_ParCSRMatrix *A , hypre_ParCSRMatrix *B );
 
+/* parcsr_matrix.c */
+
 /* par_csr_matvec.c */
+// y = alpha*A*x + beta*b
+HYPRE_Int hypre_ParCSRMatrixMatvecOutOfPlace ( HYPRE_Complex alpha , hypre_ParCSRMatrix *A , hypre_ParVector *x , HYPRE_Complex beta , hypre_ParVector *b, hypre_ParVector *y );
+// y = alpha*A*x + beta*y
 HYPRE_Int hypre_ParCSRMatrixMatvec ( HYPRE_Complex alpha , hypre_ParCSRMatrix *A , hypre_ParVector *x , HYPRE_Complex beta , hypre_ParVector *y );
 HYPRE_Int hypre_ParCSRMatrixMatvecT ( HYPRE_Complex alpha , hypre_ParCSRMatrix *A , hypre_ParVector *x , HYPRE_Complex beta , hypre_ParVector *y );
 HYPRE_Int hypre_ParCSRMatrixMatvec_FF ( HYPRE_Complex alpha , hypre_ParCSRMatrix *A , hypre_ParVector *x , HYPRE_Complex beta , hypre_ParVector *y , HYPRE_Int *CF_marker , HYPRE_Int fpt );
