@@ -438,7 +438,7 @@ hypre_ParCSRMatrix * hypre_ParMatmul_FC(
    }
    if (cnt)
    {
-      qsort0(temp, 0, cnt-1);
+      hypre_qsort0(temp, 0, cnt-1);
 
       num_cols_offd_C = 1;
       value = temp[0];
