@@ -106,6 +106,8 @@ hypre_ParCSRMatrixCreate( MPI_Comm comm,
       hypre_CSRMatrixCreate(local_num_rows, local_num_cols,num_nonzeros_diag);
    hypre_ParCSRMatrixOffd(matrix) =
       hypre_CSRMatrixCreate(local_num_rows, num_cols_offd,num_nonzeros_offd);
+   hypre_ParCSRMatrixDiagT(matrix) = NULL;
+   hypre_ParCSRMatrixOffdT(matrix) = NULL; // JSP: transposed matrices are optional
    hypre_ParCSRMatrixGlobalNumRows(matrix) = global_num_rows;
    hypre_ParCSRMatrixGlobalNumCols(matrix) = global_num_cols;
    hypre_ParCSRMatrixFirstRowIndex(matrix) = first_row_index;
@@ -155,6 +157,14 @@ hypre_ParCSRMatrixDestroy( hypre_ParCSRMatrix *matrix )
       {
          hypre_CSRMatrixDestroy(hypre_ParCSRMatrixDiag(matrix));
          hypre_CSRMatrixDestroy(hypre_ParCSRMatrixOffd(matrix));
+         if ( hypre_ParCSRMatrixDiagT(matrix) )
+         {
+            hypre_CSRMatrixDestroy(hypre_ParCSRMatrixDiagT(matrix));
+         }
+         if ( hypre_ParCSRMatrixOffdT(matrix) )
+         {
+            hypre_CSRMatrixDestroy(hypre_ParCSRMatrixOffdT(matrix));
+         }
          if (hypre_ParCSRMatrixColMapOffd(matrix))
             hypre_TFree(hypre_ParCSRMatrixColMapOffd(matrix));
          if (hypre_ParCSRMatrixCommPkg(matrix))
@@ -171,7 +181,7 @@ hypre_ParCSRMatrixDestroy( hypre_ParCSRMatrix *matrix )
       hypre_TFree(hypre_ParCSRMatrixRowvalues(matrix));
 
       if (hypre_ParCSRMatrixAssumedPartition(matrix))
-         hypre_ParCSRMatrixDestroyAssumedPartition(matrix);
+         hypre_AssumedPartitionDestroy(hypre_ParCSRMatrixAssumedPartition(matrix));
 
       hypre_TFree(matrix);
    }
@@ -545,8 +555,6 @@ hypre_ParCSRMatrixPrintIJ( const hypre_ParCSRMatrix *matrix,
                            const char               *filename )
 {
    MPI_Comm          comm;
-   HYPRE_Int         global_num_rows;
-   HYPRE_Int         global_num_cols;
    HYPRE_Int         first_row_index;
    HYPRE_Int         first_col_diag;
    hypre_CSRMatrix  *diag;
@@ -564,7 +572,7 @@ hypre_ParCSRMatrixPrintIJ( const hypre_ParCSRMatrix *matrix,
    HYPRE_Int         myid, num_procs, i, j, I, J;
    char              new_filename[255];
    FILE             *file;
-   HYPRE_Int         num_cols, num_cols_offd, num_nonzeros_diag, num_nonzeros_offd;
+   HYPRE_Int         num_nonzeros_offd;
    HYPRE_Int         ilower, iupper, jlower, jupper;
 
    if (!matrix)
@@ -573,8 +581,6 @@ hypre_ParCSRMatrixPrintIJ( const hypre_ParCSRMatrix *matrix,
       return hypre_error_flag;
    }
    comm = hypre_ParCSRMatrixComm(matrix);
-   global_num_rows = hypre_ParCSRMatrixGlobalNumRows(matrix);
-   global_num_cols = hypre_ParCSRMatrixGlobalNumCols(matrix);
    first_row_index = hypre_ParCSRMatrixFirstRowIndex(matrix);
    first_col_diag  = hypre_ParCSRMatrixFirstColDiag(matrix);
    diag            = hypre_ParCSRMatrixDiag(matrix);
@@ -590,15 +596,11 @@ hypre_ParCSRMatrixPrintIJ( const hypre_ParCSRMatrix *matrix,
 
    if ((file = fopen(new_filename, "w")) == NULL)
    {
-      hypre_printf("Error: can't open output file %s\n", new_filename);
-      hypre_error(HYPRE_ERROR_GENERIC);
+      hypre_error_w_msg(HYPRE_ERROR_GENERIC,"Error: can't open output file %s\n");
       return hypre_error_flag;
    }
 
-   num_cols = hypre_CSRMatrixNumCols(diag);
-   num_cols_offd = hypre_CSRMatrixNumCols(offd);
    num_nonzeros_offd = hypre_CSRMatrixNumNonzeros(offd);
-   num_nonzeros_diag = hypre_CSRMatrixNumNonzeros(diag);
 
    diag_data = hypre_CSRMatrixData(diag);
    diag_i    = hypre_CSRMatrixI(diag);
@@ -716,8 +718,7 @@ hypre_ParCSRMatrixReadIJ( MPI_Comm             comm,
 
    if ((file = fopen(new_filename, "r")) == NULL)
    {
-      hypre_printf("Error: can't open output file %s\n", new_filename);
-      hypre_error(HYPRE_ERROR_GENERIC);
+      hypre_error_w_msg(HYPRE_ERROR_GENERIC,"Error: can't open output file %s\n");
       return hypre_error_flag;
    }
 
@@ -807,7 +808,7 @@ hypre_ParCSRMatrixReadIJ( MPI_Comm             comm,
       aux_offd_j = hypre_CTAlloc(HYPRE_Int, num_nonzeros_offd);
       for (i=0; i < num_nonzeros_offd; i++)
          aux_offd_j[i] = offd_j[i];
-      qsort0(aux_offd_j,0,num_nonzeros_offd-1);
+      hypre_qsort0(aux_offd_j,0,num_nonzeros_offd-1);
       col_map_offd = hypre_ParCSRMatrixColMapOffd(matrix);
       col_map_offd[0] = aux_offd_j[0];
       offd_cnt = 0;
@@ -1666,8 +1667,8 @@ hypre_ParCSRMatrixToCSRMatrixAll(hypre_ParCSRMatrix *par_matrix)
          used_procs[i] = send_proc_obj.id[i];
          new_vec_starts[i+1] = send_proc_obj.elements[i]+1;
       }
-      qsort0(used_procs, 0, num_types-1);
-      qsort0(new_vec_starts, 0, num_types);
+      hypre_qsort0(used_procs, 0, num_types-1);
+      hypre_qsort0(new_vec_starts, 0, num_types);
       /*now we need to put into an array to send */
       count =  2*num_types+2;
       send_info = hypre_CTAlloc(HYPRE_Int, count);
@@ -1997,9 +1998,9 @@ hypre_FillResponseParToCSRMatrix( void       *p_recv_contact_buf,
 
    HYPRE_Int    *recv_contact_buf = (HYPRE_Int * ) p_recv_contact_buf;
 
-   hypre_DataExchangeResponse  *response_obj = ro;  
+   hypre_DataExchangeResponse  *response_obj = (hypre_DataExchangeResponse*)ro;  
 
-   hypre_ProcListElements      *send_proc_obj = response_obj->data2;   
+   hypre_ProcListElements      *send_proc_obj = (hypre_ProcListElements*)response_obj->data2;   
 
    hypre_MPI_Comm_rank(comm, &myid );
 
