@@ -79,6 +79,7 @@ hypre_ParVectorCreate( MPI_Comm   comm,
    /* set defaults */
    hypre_ParVectorOwnsData(vector) = 1;
    hypre_ParVectorOwnsPartitioning(vector) = 1;
+   hypre_ParVectorActualLocalSize(vector) = 0;
 
    return vector;
 }
@@ -120,7 +121,7 @@ hypre_ParVectorDestroy( hypre_ParVector *vector )
 
       if (hypre_ParVectorAssumedPartition(vector))
       {
-         hypre_ParVectorDestroyAssumedPartition(vector);
+         hypre_AssumedPartitionDestroy(hypre_ParVectorAssumedPartition(vector));
       }
 
       hypre_TFree(vector);
@@ -142,7 +143,8 @@ hypre_ParVectorInitialize( hypre_ParVector *vector )
       return hypre_error_flag;
    }
    hypre_SeqVectorInitialize(hypre_ParVectorLocalVector(vector));
-
+   hypre_ParVectorActualLocalSize(vector) 
+	= hypre_VectorSize(hypre_ParVectorLocalVector(vector));
    return hypre_error_flag;
 }
 
@@ -419,8 +421,14 @@ hypre_ParVectorInnerProd( hypre_ParVector *x,
    HYPRE_Real result = 0.0;
    HYPRE_Real local_result = hypre_SeqVectorInnerProd(x_local, y_local);
    
+#ifdef HYPRE_PROFILE
+   hypre_profile_times[HYPRE_TIMER_ID_ALL_REDUCE] -= hypre_MPI_Wtime();
+#endif
    hypre_MPI_Allreduce(&local_result, &result, 1, HYPRE_MPI_REAL,
                        hypre_MPI_SUM, comm);
+#ifdef HYPRE_PROFILE
+   hypre_profile_times[HYPRE_TIMER_ID_ALL_REDUCE] += hypre_MPI_Wtime();
+#endif
    
    return result;
 }
@@ -673,8 +681,8 @@ hypre_ParVectorToVectorAll( hypre_ParVector *par_v )
          used_procs[i] = send_proc_obj.id[i];
          new_vec_starts[i+1] = send_proc_obj.elements[i]+1;
       }
-      qsort0(used_procs, 0, num_types-1);
-      qsort0(new_vec_starts, 0, num_types);
+      hypre_qsort0(used_procs, 0, num_types-1);
+      hypre_qsort0(new_vec_starts, 0, num_types);
       /*now we need to put into an array to send */
       count =  2*num_types+2;
       send_info = hypre_CTAlloc(HYPRE_Int, count);
@@ -868,8 +876,7 @@ hypre_ParVectorPrintIJ( hypre_ParVector *vector,
 
    if ((file = fopen(new_filename, "w")) == NULL)
    {
-      hypre_printf("Error: can't open output file %s\n", new_filename);
-      hypre_error_in_arg(3);
+      hypre_error_w_msg(HYPRE_ERROR_GENERIC,"Error: can't open output file %s\n");
       return hypre_error_flag;
    }
 
@@ -935,8 +942,7 @@ hypre_ParVectorReadIJ( MPI_Comm          comm,
 
    if ((file = fopen(new_filename, "r")) == NULL)
    {
-      hypre_printf("Error: can't open output file %s\n", new_filename);
-      hypre_error(HYPRE_ERROR_GENERIC);
+      hypre_error_w_msg(HYPRE_ERROR_GENERIC,"Error: can't open output file %s\n");
       return hypre_error_flag;
    }
 
@@ -1015,11 +1021,10 @@ hypre_FillResponseParToVectorAll( void       *p_recv_contact_buf,
    HYPRE_Int     i, index, count, elength;
 
    HYPRE_Int    *recv_contact_buf = (HYPRE_Int * ) p_recv_contact_buf;
+ 
+   hypre_DataExchangeResponse  *response_obj = (hypre_DataExchangeResponse*)ro;  
 
-   hypre_DataExchangeResponse  *response_obj = ro;  
-
-   hypre_ProcListElements      *send_proc_obj = response_obj->data2;   
-
+   hypre_ProcListElements      *send_proc_obj = (hypre_ProcListElements*)response_obj->data2;
    hypre_MPI_Comm_rank(comm, &myid );
 
    /*check to see if we need to allocate more space in send_proc_obj for ids*/
