@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.13 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 #ifndef hypre_SSTRUCT_LS_HEADER
@@ -41,7 +41,7 @@ extern "C" {
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.13 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -93,7 +93,7 @@ typedef struct
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.13 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -125,7 +125,7 @@ typedef struct
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.13 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -158,7 +158,7 @@ typedef struct
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.13 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -184,7 +184,7 @@ typedef struct
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.13 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -207,7 +207,7 @@ typedef struct
 {
    MPI_Comm                comm;
                       
-   double                  tol;
+   HYPRE_Real              tol;
    HYPRE_Int               max_iter;
    HYPRE_Int               rel_change;
    HYPRE_Int               zero_guess;
@@ -244,8 +244,8 @@ typedef struct
    hypre_ParVector       **nVtemp_l;
    hypre_ParVector       **nVtemp2_l;
    HYPRE_Int             **nCF_marker_l;
-   double                 *nrelax_weight;
-   double                 *nomega;
+   HYPRE_Real             *nrelax_weight;
+   HYPRE_Real             *nomega;
    HYPRE_Int               nrelax_type;
    HYPRE_Int               node_numlevels;
 
@@ -263,8 +263,8 @@ typedef struct
    hypre_ParVector       **eVtemp_l;
    hypre_ParVector       **eVtemp2_l;
    HYPRE_Int             **eCF_marker_l;
-   double                 *erelax_weight;
-   double                 *eomega;
+   HYPRE_Real             *erelax_weight;
+   HYPRE_Real             *eomega;
    HYPRE_Int               erelax_type;
 
    /* edge data structure. These will have no grid. */
@@ -283,8 +283,8 @@ typedef struct
    /* additional log info (logged when `logging' > 0) */
    HYPRE_Int               print_level;
    HYPRE_Int               logging;
-   double                 *norms;
-   double                 *rel_norms;
+   HYPRE_Real             *norms;
+   HYPRE_Real             *rel_norms;
 
 } hypre_MaxwellData;
 
@@ -298,7 +298,7 @@ typedef struct
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.13 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -310,7 +310,7 @@ typedef struct
                                                                                                                                     
    HYPRE_Int ncols;
    HYPRE_Int      *cols;
-   double   *data;
+   HYPRE_Real   *data;
                                                                                                                                     
 } hypre_MaxwellOffProcRow;
 
@@ -334,22 +334,22 @@ HYPRE_Int hypre_ZeroAMRMatrixData ( hypre_SStructMatrix *A , HYPRE_Int part_crse
 /* fac.c */
 void *hypre_FACCreate ( MPI_Comm comm );
 HYPRE_Int hypre_FACDestroy2 ( void *fac_vdata );
-HYPRE_Int hypre_FACSetTol ( void *fac_vdata , double tol );
+HYPRE_Int hypre_FACSetTol ( void *fac_vdata , HYPRE_Real tol );
 HYPRE_Int hypre_FACSetPLevels ( void *fac_vdata , HYPRE_Int nparts , HYPRE_Int *plevels );
-HYPRE_Int hypre_FACSetPRefinements ( void *fac_vdata , HYPRE_Int nparts , HYPRE_Int (*prefinements )[3 ]);
+HYPRE_Int hypre_FACSetPRefinements ( void *fac_vdata , HYPRE_Int nparts , hypre_Index *prefinements);
 HYPRE_Int hypre_FACSetMaxLevels ( void *fac_vdata , HYPRE_Int nparts );
 HYPRE_Int hypre_FACSetMaxIter ( void *fac_vdata , HYPRE_Int max_iter );
 HYPRE_Int hypre_FACSetRelChange ( void *fac_vdata , HYPRE_Int rel_change );
 HYPRE_Int hypre_FACSetZeroGuess ( void *fac_vdata , HYPRE_Int zero_guess );
 HYPRE_Int hypre_FACSetRelaxType ( void *fac_vdata , HYPRE_Int relax_type );
-HYPRE_Int hypre_FACSetJacobiWeight ( void *fac_vdata , double weight );
+HYPRE_Int hypre_FACSetJacobiWeight ( void *fac_vdata , HYPRE_Real weight );
 HYPRE_Int hypre_FACSetNumPreSmooth ( void *fac_vdata , HYPRE_Int num_pre_smooth );
 HYPRE_Int hypre_FACSetNumPostSmooth ( void *fac_vdata , HYPRE_Int num_post_smooth );
 HYPRE_Int hypre_FACSetCoarseSolverType ( void *fac_vdata , HYPRE_Int csolver_type );
 HYPRE_Int hypre_FACSetLogging ( void *fac_vdata , HYPRE_Int logging );
 HYPRE_Int hypre_FACGetNumIterations ( void *fac_vdata , HYPRE_Int *num_iterations );
 HYPRE_Int hypre_FACPrintLogging ( void *fac_vdata , HYPRE_Int myid );
-HYPRE_Int hypre_FACGetFinalRelativeResidualNorm ( void *fac_vdata , double *relative_residual_norm );
+HYPRE_Int hypre_FACGetFinalRelativeResidualNorm ( void *fac_vdata , HYPRE_Real *relative_residual_norm );
 
 /* fac_cf_coarsen.c */
 HYPRE_Int hypre_AMR_CFCoarsen ( hypre_SStructMatrix *A , hypre_SStructMatrix *fac_A , hypre_Index refine_factors , HYPRE_Int level );
@@ -405,8 +405,8 @@ HYPRE_Int HYPRE_SStructBiCGSTABCreate ( MPI_Comm comm , HYPRE_SStructSolver *sol
 HYPRE_Int HYPRE_SStructBiCGSTABDestroy ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructBiCGSTABSetup ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructBiCGSTABSolve ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
-HYPRE_Int HYPRE_SStructBiCGSTABSetTol ( HYPRE_SStructSolver solver , double tol );
-HYPRE_Int HYPRE_SStructBiCGSTABSetAbsoluteTol ( HYPRE_SStructSolver solver , double tol );
+HYPRE_Int HYPRE_SStructBiCGSTABSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
+HYPRE_Int HYPRE_SStructBiCGSTABSetAbsoluteTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
 HYPRE_Int HYPRE_SStructBiCGSTABSetMinIter ( HYPRE_SStructSolver solver , HYPRE_Int min_iter );
 HYPRE_Int HYPRE_SStructBiCGSTABSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructBiCGSTABSetStopCrit ( HYPRE_SStructSolver solver , HYPRE_Int stop_crit );
@@ -414,7 +414,7 @@ HYPRE_Int HYPRE_SStructBiCGSTABSetPrecond ( HYPRE_SStructSolver solver , HYPRE_P
 HYPRE_Int HYPRE_SStructBiCGSTABSetLogging ( HYPRE_SStructSolver solver , HYPRE_Int logging );
 HYPRE_Int HYPRE_SStructBiCGSTABSetPrintLevel ( HYPRE_SStructSolver solver , HYPRE_Int print_level );
 HYPRE_Int HYPRE_SStructBiCGSTABGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructBiCGSTABGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
+HYPRE_Int HYPRE_SStructBiCGSTABGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
 HYPRE_Int HYPRE_SStructBiCGSTABGetResidual ( HYPRE_SStructSolver solver , void **residual );
 
 /* HYPRE_sstruct_flexgmres.c */
@@ -423,15 +423,15 @@ HYPRE_Int HYPRE_SStructFlexGMRESDestroy ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructFlexGMRESSetup ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructFlexGMRESSolve ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructFlexGMRESSetKDim ( HYPRE_SStructSolver solver , HYPRE_Int k_dim );
-HYPRE_Int HYPRE_SStructFlexGMRESSetTol ( HYPRE_SStructSolver solver , double tol );
-HYPRE_Int HYPRE_SStructFlexGMRESSetAbsoluteTol ( HYPRE_SStructSolver solver , double tol );
+HYPRE_Int HYPRE_SStructFlexGMRESSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
+HYPRE_Int HYPRE_SStructFlexGMRESSetAbsoluteTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
 HYPRE_Int HYPRE_SStructFlexGMRESSetMinIter ( HYPRE_SStructSolver solver , HYPRE_Int min_iter );
 HYPRE_Int HYPRE_SStructFlexGMRESSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructFlexGMRESSetPrecond ( HYPRE_SStructSolver solver , HYPRE_PtrToSStructSolverFcn precond , HYPRE_PtrToSStructSolverFcn precond_setup , void *precond_data );
 HYPRE_Int HYPRE_SStructFlexGMRESSetLogging ( HYPRE_SStructSolver solver , HYPRE_Int logging );
 HYPRE_Int HYPRE_SStructFlexGMRESSetPrintLevel ( HYPRE_SStructSolver solver , HYPRE_Int level );
 HYPRE_Int HYPRE_SStructFlexGMRESGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructFlexGMRESGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
+HYPRE_Int HYPRE_SStructFlexGMRESGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
 HYPRE_Int HYPRE_SStructFlexGMRESGetResidual ( HYPRE_SStructSolver solver , void **residual );
 HYPRE_Int HYPRE_SStructFlexGMRESSetModifyPC ( HYPRE_SStructSolver solver , HYPRE_PtrToModifyPCFcn modify_pc );
 
@@ -441,8 +441,8 @@ HYPRE_Int HYPRE_SStructGMRESDestroy ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructGMRESSetup ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructGMRESSolve ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructGMRESSetKDim ( HYPRE_SStructSolver solver , HYPRE_Int k_dim );
-HYPRE_Int HYPRE_SStructGMRESSetTol ( HYPRE_SStructSolver solver , double tol );
-HYPRE_Int HYPRE_SStructGMRESSetAbsoluteTol ( HYPRE_SStructSolver solver , double atol );
+HYPRE_Int HYPRE_SStructGMRESSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
+HYPRE_Int HYPRE_SStructGMRESSetAbsoluteTol ( HYPRE_SStructSolver solver , HYPRE_Real atol );
 HYPRE_Int HYPRE_SStructGMRESSetMinIter ( HYPRE_SStructSolver solver , HYPRE_Int min_iter );
 HYPRE_Int HYPRE_SStructGMRESSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructGMRESSetStopCrit ( HYPRE_SStructSolver solver , HYPRE_Int stop_crit );
@@ -450,7 +450,7 @@ HYPRE_Int HYPRE_SStructGMRESSetPrecond ( HYPRE_SStructSolver solver , HYPRE_PtrT
 HYPRE_Int HYPRE_SStructGMRESSetLogging ( HYPRE_SStructSolver solver , HYPRE_Int logging );
 HYPRE_Int HYPRE_SStructGMRESSetPrintLevel ( HYPRE_SStructSolver solver , HYPRE_Int level );
 HYPRE_Int HYPRE_SStructGMRESGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructGMRESGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
+HYPRE_Int HYPRE_SStructGMRESGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
 HYPRE_Int HYPRE_SStructGMRESGetResidual ( HYPRE_SStructSolver solver , void **residual );
 
 /* HYPRE_sstruct_int.c */
@@ -463,29 +463,29 @@ HYPRE_Int HYPRE_SStructSetupMatvec ( HYPRE_MatvecFunctions *mv );
 /* HYPRE_sstruct_InterFAC.c */
 HYPRE_Int HYPRE_SStructFACCreate ( MPI_Comm comm , HYPRE_SStructSolver *solver );
 HYPRE_Int HYPRE_SStructFACDestroy2 ( HYPRE_SStructSolver solver );
-HYPRE_Int HYPRE_SStructFACAMR_RAP ( HYPRE_SStructMatrix A , HYPRE_Int (*rfactors )[3 ], HYPRE_SStructMatrix *fac_A );
+HYPRE_Int HYPRE_SStructFACAMR_RAP ( HYPRE_SStructMatrix A , HYPRE_Int (*rfactors )[HYPRE_MAXDIM] , HYPRE_SStructMatrix *fac_A );
 HYPRE_Int HYPRE_SStructFACSetup2 ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructFACSolve3 ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
-HYPRE_Int HYPRE_SStructFACSetTol ( HYPRE_SStructSolver solver , double tol );
+HYPRE_Int HYPRE_SStructFACSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
 HYPRE_Int HYPRE_SStructFACSetPLevels ( HYPRE_SStructSolver solver , HYPRE_Int nparts , HYPRE_Int *plevels );
-HYPRE_Int HYPRE_SStructFACZeroCFSten ( HYPRE_SStructMatrix A , HYPRE_SStructGrid grid , HYPRE_Int part , HYPRE_Int rfactors [3 ]);
+HYPRE_Int HYPRE_SStructFACZeroCFSten ( HYPRE_SStructMatrix A , HYPRE_SStructGrid grid , HYPRE_Int part , HYPRE_Int rfactors [HYPRE_MAXDIM]);
 HYPRE_Int HYPRE_SStructFACZeroFCSten ( HYPRE_SStructMatrix A , HYPRE_SStructGrid grid , HYPRE_Int part );
-HYPRE_Int HYPRE_SStructFACZeroAMRMatrixData ( HYPRE_SStructMatrix A , HYPRE_Int part_crse , HYPRE_Int rfactors [3 ]);
-HYPRE_Int HYPRE_SStructFACZeroAMRVectorData ( HYPRE_SStructVector b , HYPRE_Int *plevels , HYPRE_Int (*rfactors )[3 ]);
-HYPRE_Int HYPRE_SStructFACSetPRefinements ( HYPRE_SStructSolver solver , HYPRE_Int nparts , HYPRE_Int (*rfactors )[3 ]);
+HYPRE_Int HYPRE_SStructFACZeroAMRMatrixData ( HYPRE_SStructMatrix A , HYPRE_Int part_crse , HYPRE_Int rfactors [HYPRE_MAXDIM]);
+HYPRE_Int HYPRE_SStructFACZeroAMRVectorData ( HYPRE_SStructVector b , HYPRE_Int *plevels , HYPRE_Int (*rfactors )[HYPRE_MAXDIM]);
+HYPRE_Int HYPRE_SStructFACSetPRefinements ( HYPRE_SStructSolver solver , HYPRE_Int nparts , HYPRE_Int (*rfactors )[HYPRE_MAXDIM]);
 HYPRE_Int HYPRE_SStructFACSetMaxLevels ( HYPRE_SStructSolver solver , HYPRE_Int max_levels );
 HYPRE_Int HYPRE_SStructFACSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructFACSetRelChange ( HYPRE_SStructSolver solver , HYPRE_Int rel_change );
 HYPRE_Int HYPRE_SStructFACSetZeroGuess ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructFACSetNonZeroGuess ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructFACSetRelaxType ( HYPRE_SStructSolver solver , HYPRE_Int relax_type );
-HYPRE_Int HYPRE_SStructFACSetJacobiWeight ( HYPRE_SStructSolver solver , double weight );
+HYPRE_Int HYPRE_SStructFACSetJacobiWeight ( HYPRE_SStructSolver solver , HYPRE_Real weight );
 HYPRE_Int HYPRE_SStructFACSetNumPreRelax ( HYPRE_SStructSolver solver , HYPRE_Int num_pre_relax );
 HYPRE_Int HYPRE_SStructFACSetNumPostRelax ( HYPRE_SStructSolver solver , HYPRE_Int num_post_relax );
 HYPRE_Int HYPRE_SStructFACSetCoarseSolverType ( HYPRE_SStructSolver solver , HYPRE_Int csolver_type );
 HYPRE_Int HYPRE_SStructFACSetLogging ( HYPRE_SStructSolver solver , HYPRE_Int logging );
 HYPRE_Int HYPRE_SStructFACGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructFACGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
+HYPRE_Int HYPRE_SStructFACGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
 
 /* HYPRE_sstruct_lgmres.c */
 HYPRE_Int HYPRE_SStructLGMRESCreate ( MPI_Comm comm , HYPRE_SStructSolver *solver );
@@ -494,15 +494,15 @@ HYPRE_Int HYPRE_SStructLGMRESSetup ( HYPRE_SStructSolver solver , HYPRE_SStructM
 HYPRE_Int HYPRE_SStructLGMRESSolve ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructLGMRESSetKDim ( HYPRE_SStructSolver solver , HYPRE_Int k_dim );
 HYPRE_Int HYPRE_SStructLGMRESSetAugDim ( HYPRE_SStructSolver solver , HYPRE_Int aug_dim );
-HYPRE_Int HYPRE_SStructLGMRESSetTol ( HYPRE_SStructSolver solver , double tol );
-HYPRE_Int HYPRE_SStructLGMRESSetAbsoluteTol ( HYPRE_SStructSolver solver , double atol );
+HYPRE_Int HYPRE_SStructLGMRESSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
+HYPRE_Int HYPRE_SStructLGMRESSetAbsoluteTol ( HYPRE_SStructSolver solver , HYPRE_Real atol );
 HYPRE_Int HYPRE_SStructLGMRESSetMinIter ( HYPRE_SStructSolver solver , HYPRE_Int min_iter );
 HYPRE_Int HYPRE_SStructLGMRESSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructLGMRESSetPrecond ( HYPRE_SStructSolver solver , HYPRE_PtrToSStructSolverFcn precond , HYPRE_PtrToSStructSolverFcn precond_setup , void *precond_data );
 HYPRE_Int HYPRE_SStructLGMRESSetLogging ( HYPRE_SStructSolver solver , HYPRE_Int logging );
 HYPRE_Int HYPRE_SStructLGMRESSetPrintLevel ( HYPRE_SStructSolver solver , HYPRE_Int level );
 HYPRE_Int HYPRE_SStructLGMRESGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructLGMRESGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
+HYPRE_Int HYPRE_SStructLGMRESGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
 HYPRE_Int HYPRE_SStructLGMRESGetResidual ( HYPRE_SStructSolver solver , void **residual );
 
 /* HYPRE_sstruct_maxwell.c */
@@ -513,8 +513,8 @@ HYPRE_Int HYPRE_SStructMaxwellSolve ( HYPRE_SStructSolver solver , HYPRE_SStruct
 HYPRE_Int HYPRE_SStructMaxwellSolve2 ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_MaxwellGrad ( HYPRE_SStructGrid grid , HYPRE_ParCSRMatrix *T );
 HYPRE_Int HYPRE_SStructMaxwellSetGrad ( HYPRE_SStructSolver solver , HYPRE_ParCSRMatrix T );
-HYPRE_Int HYPRE_SStructMaxwellSetRfactors ( HYPRE_SStructSolver solver , HYPRE_Int rfactors [3 ]);
-HYPRE_Int HYPRE_SStructMaxwellSetTol ( HYPRE_SStructSolver solver , double tol );
+HYPRE_Int HYPRE_SStructMaxwellSetRfactors ( HYPRE_SStructSolver solver , HYPRE_Int rfactors [HYPRE_MAXDIM]);
+HYPRE_Int HYPRE_SStructMaxwellSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
 HYPRE_Int HYPRE_SStructMaxwellSetConstantCoef ( HYPRE_SStructSolver solver , HYPRE_Int constant_coef );
 HYPRE_Int HYPRE_SStructMaxwellSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructMaxwellSetRelChange ( HYPRE_SStructSolver solver , HYPRE_Int rel_change );
@@ -524,8 +524,8 @@ HYPRE_Int HYPRE_SStructMaxwellSetLogging ( HYPRE_SStructSolver solver , HYPRE_In
 HYPRE_Int HYPRE_SStructMaxwellSetPrintLevel ( HYPRE_SStructSolver solver , HYPRE_Int print_level );
 HYPRE_Int HYPRE_SStructMaxwellPrintLogging ( HYPRE_SStructSolver solver , HYPRE_Int myid );
 HYPRE_Int HYPRE_SStructMaxwellGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructMaxwellGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
-HYPRE_Int HYPRE_SStructMaxwellPhysBdy ( HYPRE_SStructGrid *grid_l , HYPRE_Int num_levels , HYPRE_Int rfactors [3 ], HYPRE_Int ***BdryRanks_ptr , HYPRE_Int **BdryRanksCnt_ptr );
+HYPRE_Int HYPRE_SStructMaxwellGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
+HYPRE_Int HYPRE_SStructMaxwellPhysBdy ( HYPRE_SStructGrid *grid_l , HYPRE_Int num_levels , HYPRE_Int rfactors [HYPRE_MAXDIM], HYPRE_Int ***BdryRanks_ptr , HYPRE_Int **BdryRanksCnt_ptr );
 HYPRE_Int HYPRE_SStructMaxwellEliminateRowsCols ( HYPRE_ParCSRMatrix parA , HYPRE_Int nrows , HYPRE_Int *rows );
 HYPRE_Int HYPRE_SStructMaxwellZeroVector ( HYPRE_ParVector v , HYPRE_Int *rows , HYPRE_Int nrows );
 
@@ -534,8 +534,8 @@ HYPRE_Int HYPRE_SStructPCGCreate ( MPI_Comm comm , HYPRE_SStructSolver *solver )
 HYPRE_Int HYPRE_SStructPCGDestroy ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructPCGSetup ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructPCGSolve ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
-HYPRE_Int HYPRE_SStructPCGSetTol ( HYPRE_SStructSolver solver , double tol );
-HYPRE_Int HYPRE_SStructPCGSetAbsoluteTol ( HYPRE_SStructSolver solver , double tol );
+HYPRE_Int HYPRE_SStructPCGSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
+HYPRE_Int HYPRE_SStructPCGSetAbsoluteTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
 HYPRE_Int HYPRE_SStructPCGSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructPCGSetTwoNorm ( HYPRE_SStructSolver solver , HYPRE_Int two_norm );
 HYPRE_Int HYPRE_SStructPCGSetRelChange ( HYPRE_SStructSolver solver , HYPRE_Int rel_change );
@@ -543,7 +543,7 @@ HYPRE_Int HYPRE_SStructPCGSetPrecond ( HYPRE_SStructSolver solver , HYPRE_PtrToS
 HYPRE_Int HYPRE_SStructPCGSetLogging ( HYPRE_SStructSolver solver , HYPRE_Int logging );
 HYPRE_Int HYPRE_SStructPCGSetPrintLevel ( HYPRE_SStructSolver solver , HYPRE_Int level );
 HYPRE_Int HYPRE_SStructPCGGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructPCGGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
+HYPRE_Int HYPRE_SStructPCGGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
 HYPRE_Int HYPRE_SStructPCGGetResidual ( HYPRE_SStructSolver solver , void **residual );
 HYPRE_Int HYPRE_SStructDiagScaleSetup ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector y , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructDiagScale ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector y , HYPRE_SStructVector x );
@@ -553,34 +553,34 @@ HYPRE_Int HYPRE_SStructSplitCreate ( MPI_Comm comm , HYPRE_SStructSolver *solver
 HYPRE_Int HYPRE_SStructSplitDestroy ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructSplitSetup ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructSplitSolve ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
-HYPRE_Int HYPRE_SStructSplitSetTol ( HYPRE_SStructSolver solver , double tol );
+HYPRE_Int HYPRE_SStructSplitSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
 HYPRE_Int HYPRE_SStructSplitSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructSplitSetZeroGuess ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructSplitSetNonZeroGuess ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructSplitSetStructSolver ( HYPRE_SStructSolver solver , HYPRE_Int ssolver );
 HYPRE_Int HYPRE_SStructSplitGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructSplitGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
+HYPRE_Int HYPRE_SStructSplitGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
 
 /* HYPRE_sstruct_sys_pfmg.c */
 HYPRE_Int HYPRE_SStructSysPFMGCreate ( MPI_Comm comm , HYPRE_SStructSolver *solver );
 HYPRE_Int HYPRE_SStructSysPFMGDestroy ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructSysPFMGSetup ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
 HYPRE_Int HYPRE_SStructSysPFMGSolve ( HYPRE_SStructSolver solver , HYPRE_SStructMatrix A , HYPRE_SStructVector b , HYPRE_SStructVector x );
-HYPRE_Int HYPRE_SStructSysPFMGSetTol ( HYPRE_SStructSolver solver , double tol );
+HYPRE_Int HYPRE_SStructSysPFMGSetTol ( HYPRE_SStructSolver solver , HYPRE_Real tol );
 HYPRE_Int HYPRE_SStructSysPFMGSetMaxIter ( HYPRE_SStructSolver solver , HYPRE_Int max_iter );
 HYPRE_Int HYPRE_SStructSysPFMGSetRelChange ( HYPRE_SStructSolver solver , HYPRE_Int rel_change );
 HYPRE_Int HYPRE_SStructSysPFMGSetZeroGuess ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructSysPFMGSetNonZeroGuess ( HYPRE_SStructSolver solver );
 HYPRE_Int HYPRE_SStructSysPFMGSetRelaxType ( HYPRE_SStructSolver solver , HYPRE_Int relax_type );
-HYPRE_Int HYPRE_SStructSysPFMGSetJacobiWeight ( HYPRE_SStructSolver solver , double weight );
+HYPRE_Int HYPRE_SStructSysPFMGSetJacobiWeight ( HYPRE_SStructSolver solver , HYPRE_Real weight );
 HYPRE_Int HYPRE_SStructSysPFMGSetNumPreRelax ( HYPRE_SStructSolver solver , HYPRE_Int num_pre_relax );
 HYPRE_Int HYPRE_SStructSysPFMGSetNumPostRelax ( HYPRE_SStructSolver solver , HYPRE_Int num_post_relax );
 HYPRE_Int HYPRE_SStructSysPFMGSetSkipRelax ( HYPRE_SStructSolver solver , HYPRE_Int skip_relax );
-HYPRE_Int HYPRE_SStructSysPFMGSetDxyz ( HYPRE_SStructSolver solver , double *dxyz );
+HYPRE_Int HYPRE_SStructSysPFMGSetDxyz ( HYPRE_SStructSolver solver , HYPRE_Real *dxyz );
 HYPRE_Int HYPRE_SStructSysPFMGSetLogging ( HYPRE_SStructSolver solver , HYPRE_Int logging );
 HYPRE_Int HYPRE_SStructSysPFMGSetPrintLevel ( HYPRE_SStructSolver solver , HYPRE_Int print_level );
 HYPRE_Int HYPRE_SStructSysPFMGGetNumIterations ( HYPRE_SStructSolver solver , HYPRE_Int *num_iterations );
-HYPRE_Int HYPRE_SStructSysPFMGGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , double *norm );
+HYPRE_Int HYPRE_SStructSysPFMGGetFinalRelativeResidualNorm ( HYPRE_SStructSolver solver , HYPRE_Real *norm );
 
 /* krylov.c */
 HYPRE_Int hypre_SStructKrylovIdentitySetup ( void *vdata , void *A , void *b , void *x );
@@ -593,13 +593,13 @@ void *hypre_SStructKrylovCreateVector ( void *vvector );
 void *hypre_SStructKrylovCreateVectorArray ( HYPRE_Int n , void *vvector );
 HYPRE_Int hypre_SStructKrylovDestroyVector ( void *vvector );
 void *hypre_SStructKrylovMatvecCreate ( void *A , void *x );
-HYPRE_Int hypre_SStructKrylovMatvec ( void *matvec_data , double alpha , void *A , void *x , double beta , void *y );
+HYPRE_Int hypre_SStructKrylovMatvec ( void *matvec_data , HYPRE_Complex alpha , void *A , void *x , HYPRE_Complex beta , void *y );
 HYPRE_Int hypre_SStructKrylovMatvecDestroy ( void *matvec_data );
-double hypre_SStructKrylovInnerProd ( void *x , void *y );
+HYPRE_Real hypre_SStructKrylovInnerProd ( void *x , void *y );
 HYPRE_Int hypre_SStructKrylovCopyVector ( void *x , void *y );
 HYPRE_Int hypre_SStructKrylovClearVector ( void *x );
-HYPRE_Int hypre_SStructKrylovScaleVector ( double alpha , void *x );
-HYPRE_Int hypre_SStructKrylovAxpy ( double alpha , void *x , void *y );
+HYPRE_Int hypre_SStructKrylovScaleVector ( HYPRE_Complex alpha , void *x );
+HYPRE_Int hypre_SStructKrylovAxpy ( HYPRE_Complex alpha , void *x , void *y );
 HYPRE_Int hypre_SStructKrylovCommInfo ( void *A , HYPRE_Int *my_id , HYPRE_Int *num_procs );
 
 /* maxwell_grad.c */
@@ -619,16 +619,16 @@ hypre_IJMatrix *hypre_Maxwell_PNedelec ( hypre_SStructGrid *fgrid_edge , hypre_S
 HYPRE_Int hypre_CreatePTopology ( void **PTopology_vdata_ptr );
 HYPRE_Int hypre_DestroyPTopology ( void *PTopology_vdata );
 hypre_IJMatrix *hypre_Maxwell_PTopology ( hypre_SStructGrid *fgrid_edge , hypre_SStructGrid *cgrid_edge , hypre_SStructGrid *fgrid_face , hypre_SStructGrid *cgrid_face , hypre_SStructGrid *fgrid_element , hypre_SStructGrid *cgrid_element , hypre_ParCSRMatrix *Aee , hypre_Index rfactor , void *PTopology_vdata );
-HYPRE_Int hypre_CollapseStencilToStencil ( hypre_ParCSRMatrix *Aee , hypre_SStructGrid *grid , HYPRE_Int part , HYPRE_Int var , hypre_Index pt_location , HYPRE_Int collapse_dir , HYPRE_Int new_stencil_dir , double **collapsed_vals_ptr );
-HYPRE_Int hypre_TriDiagSolve ( double *diag , double *upper , double *lower , double *rhs , HYPRE_Int size );
+HYPRE_Int hypre_CollapseStencilToStencil ( hypre_ParCSRMatrix *Aee , hypre_SStructGrid *grid , HYPRE_Int part , HYPRE_Int var , hypre_Index pt_location , HYPRE_Int collapse_dir , HYPRE_Int new_stencil_dir , HYPRE_Real **collapsed_vals_ptr );
+HYPRE_Int hypre_TriDiagSolve ( HYPRE_Real *diag , HYPRE_Real *upper , HYPRE_Real *lower , HYPRE_Real *rhs , HYPRE_Int size );
 
 /* maxwell_TV.c */
 void *hypre_MaxwellTVCreate ( MPI_Comm comm );
 HYPRE_Int hypre_MaxwellTVDestroy ( void *maxwell_vdata );
-HYPRE_Int hypre_MaxwellSetRfactors ( void *maxwell_vdata , HYPRE_Int rfactor [3 ]);
+HYPRE_Int hypre_MaxwellSetRfactors ( void *maxwell_vdata , HYPRE_Int rfactor [HYPRE_MAXDIM]);
 HYPRE_Int hypre_MaxwellSetGrad ( void *maxwell_vdata , hypre_ParCSRMatrix *T );
 HYPRE_Int hypre_MaxwellSetConstantCoef ( void *maxwell_vdata , HYPRE_Int constant_coef );
-HYPRE_Int hypre_MaxwellSetTol ( void *maxwell_vdata , double tol );
+HYPRE_Int hypre_MaxwellSetTol ( void *maxwell_vdata , HYPRE_Real tol );
 HYPRE_Int hypre_MaxwellSetMaxIter ( void *maxwell_vdata , HYPRE_Int max_iter );
 HYPRE_Int hypre_MaxwellSetRelChange ( void *maxwell_vdata , HYPRE_Int rel_change );
 HYPRE_Int hypre_MaxwellSetNumPreRelax ( void *maxwell_vdata , HYPRE_Int num_pre_relax );
@@ -637,7 +637,7 @@ HYPRE_Int hypre_MaxwellGetNumIterations ( void *maxwell_vdata , HYPRE_Int *num_i
 HYPRE_Int hypre_MaxwellSetPrintLevel ( void *maxwell_vdata , HYPRE_Int print_level );
 HYPRE_Int hypre_MaxwellSetLogging ( void *maxwell_vdata , HYPRE_Int logging );
 HYPRE_Int hypre_MaxwellPrintLogging ( void *maxwell_vdata , HYPRE_Int myid );
-HYPRE_Int hypre_MaxwellGetFinalRelativeResidualNorm ( void *maxwell_vdata , double *relative_residual_norm );
+HYPRE_Int hypre_MaxwellGetFinalRelativeResidualNorm ( void *maxwell_vdata , HYPRE_Real *relative_residual_norm );
 
 /* maxwell_TV_setup.c */
 HYPRE_Int hypre_MaxwellTV_Setup ( void *maxwell_vdata , hypre_SStructMatrix *Aee_in , hypre_SStructVector *b_in , hypre_SStructVector *x_in );
@@ -657,10 +657,10 @@ void *hypre_NodeRelaxCreate ( MPI_Comm comm );
 HYPRE_Int hypre_NodeRelaxDestroy ( void *relax_vdata );
 HYPRE_Int hypre_NodeRelaxSetup ( void *relax_vdata , hypre_SStructPMatrix *A , hypre_SStructPVector *b , hypre_SStructPVector *x );
 HYPRE_Int hypre_NodeRelax ( void *relax_vdata , hypre_SStructPMatrix *A , hypre_SStructPVector *b , hypre_SStructPVector *x );
-HYPRE_Int hypre_NodeRelaxSetTol ( void *relax_vdata , double tol );
+HYPRE_Int hypre_NodeRelaxSetTol ( void *relax_vdata , HYPRE_Real tol );
 HYPRE_Int hypre_NodeRelaxSetMaxIter ( void *relax_vdata , HYPRE_Int max_iter );
 HYPRE_Int hypre_NodeRelaxSetZeroGuess ( void *relax_vdata , HYPRE_Int zero_guess );
-HYPRE_Int hypre_NodeRelaxSetWeight ( void *relax_vdata , double weight );
+HYPRE_Int hypre_NodeRelaxSetWeight ( void *relax_vdata , HYPRE_Real weight );
 HYPRE_Int hypre_NodeRelaxSetNumNodesets ( void *relax_vdata , HYPRE_Int num_nodesets );
 HYPRE_Int hypre_NodeRelaxSetNodeset ( void *relax_vdata , HYPRE_Int nodeset , HYPRE_Int nodeset_size , hypre_Index nodeset_stride , hypre_Index *nodeset_indices );
 HYPRE_Int hypre_NodeRelaxSetNodesetRank ( void *relax_vdata , HYPRE_Int nodeset , HYPRE_Int nodeset_rank );
@@ -691,21 +691,21 @@ HYPRE_Int hypre_SStructSharedDOF_ParcsrMatRowsComm ( hypre_SStructGrid *grid , h
 /* sys_pfmg.c */
 void *hypre_SysPFMGCreate ( MPI_Comm comm );
 HYPRE_Int hypre_SysPFMGDestroy ( void *sys_pfmg_vdata );
-HYPRE_Int hypre_SysPFMGSetTol ( void *sys_pfmg_vdata , double tol );
+HYPRE_Int hypre_SysPFMGSetTol ( void *sys_pfmg_vdata , HYPRE_Real tol );
 HYPRE_Int hypre_SysPFMGSetMaxIter ( void *sys_pfmg_vdata , HYPRE_Int max_iter );
 HYPRE_Int hypre_SysPFMGSetRelChange ( void *sys_pfmg_vdata , HYPRE_Int rel_change );
 HYPRE_Int hypre_SysPFMGSetZeroGuess ( void *sys_pfmg_vdata , HYPRE_Int zero_guess );
 HYPRE_Int hypre_SysPFMGSetRelaxType ( void *sys_pfmg_vdata , HYPRE_Int relax_type );
-HYPRE_Int hypre_SysPFMGSetJacobiWeight ( void *sys_pfmg_vdata , double weight );
+HYPRE_Int hypre_SysPFMGSetJacobiWeight ( void *sys_pfmg_vdata , HYPRE_Real weight );
 HYPRE_Int hypre_SysPFMGSetNumPreRelax ( void *sys_pfmg_vdata , HYPRE_Int num_pre_relax );
 HYPRE_Int hypre_SysPFMGSetNumPostRelax ( void *sys_pfmg_vdata , HYPRE_Int num_post_relax );
 HYPRE_Int hypre_SysPFMGSetSkipRelax ( void *sys_pfmg_vdata , HYPRE_Int skip_relax );
-HYPRE_Int hypre_SysPFMGSetDxyz ( void *sys_pfmg_vdata , double *dxyz );
+HYPRE_Int hypre_SysPFMGSetDxyz ( void *sys_pfmg_vdata , HYPRE_Real *dxyz );
 HYPRE_Int hypre_SysPFMGSetLogging ( void *sys_pfmg_vdata , HYPRE_Int logging );
 HYPRE_Int hypre_SysPFMGSetPrintLevel ( void *sys_pfmg_vdata , HYPRE_Int print_level );
 HYPRE_Int hypre_SysPFMGGetNumIterations ( void *sys_pfmg_vdata , HYPRE_Int *num_iterations );
 HYPRE_Int hypre_SysPFMGPrintLogging ( void *sys_pfmg_vdata , HYPRE_Int myid );
-HYPRE_Int hypre_SysPFMGGetFinalRelativeResidualNorm ( void *sys_pfmg_vdata , double *relative_residual_norm );
+HYPRE_Int hypre_SysPFMGGetFinalRelativeResidualNorm ( void *sys_pfmg_vdata , HYPRE_Real *relative_residual_norm );
 
 /* sys_pfmg_relax.c */
 void *hypre_SysPFMGRelaxCreate ( MPI_Comm comm );
@@ -713,10 +713,10 @@ HYPRE_Int hypre_SysPFMGRelaxDestroy ( void *sys_pfmg_relax_vdata );
 HYPRE_Int hypre_SysPFMGRelax ( void *sys_pfmg_relax_vdata , hypre_SStructPMatrix *A , hypre_SStructPVector *b , hypre_SStructPVector *x );
 HYPRE_Int hypre_SysPFMGRelaxSetup ( void *sys_pfmg_relax_vdata , hypre_SStructPMatrix *A , hypre_SStructPVector *b , hypre_SStructPVector *x );
 HYPRE_Int hypre_SysPFMGRelaxSetType ( void *sys_pfmg_relax_vdata , HYPRE_Int relax_type );
-HYPRE_Int hypre_SysPFMGRelaxSetJacobiWeight ( void *sys_pfmg_relax_vdata , double weight );
+HYPRE_Int hypre_SysPFMGRelaxSetJacobiWeight ( void *sys_pfmg_relax_vdata , HYPRE_Real weight );
 HYPRE_Int hypre_SysPFMGRelaxSetPreRelax ( void *sys_pfmg_relax_vdata );
 HYPRE_Int hypre_SysPFMGRelaxSetPostRelax ( void *sys_pfmg_relax_vdata );
-HYPRE_Int hypre_SysPFMGRelaxSetTol ( void *sys_pfmg_relax_vdata , double tol );
+HYPRE_Int hypre_SysPFMGRelaxSetTol ( void *sys_pfmg_relax_vdata , HYPRE_Real tol );
 HYPRE_Int hypre_SysPFMGRelaxSetMaxIter ( void *sys_pfmg_relax_vdata , HYPRE_Int max_iter );
 HYPRE_Int hypre_SysPFMGRelaxSetZeroGuess ( void *sys_pfmg_relax_vdata , HYPRE_Int zero_guess );
 HYPRE_Int hypre_SysPFMGRelaxSetTempVec ( void *sys_pfmg_relax_vdata , hypre_SStructPVector *t );
