@@ -109,7 +109,7 @@ hypre_FacSemiRestrictSetup2( void                 *fac_restrict_vdata,
 {
    HYPRE_Int                 ierr = 0;
 
-   hypre_FacSemiRestrictData2 *fac_restrict_data = fac_restrict_vdata;
+   hypre_FacSemiRestrictData2 *fac_restrict_data = (hypre_FacSemiRestrictData2 *)fac_restrict_vdata;
    MPI_Comm                    comm= hypre_SStructPVectorComm(rc);
    hypre_CommInfo             *comm_info;
    hypre_CommPkg             **interlevel_comm;
@@ -487,7 +487,7 @@ hypre_FACRestrict2( void                 *  fac_restrict_vdata,
 {
    HYPRE_Int ierr = 0;
 
-   hypre_FacSemiRestrictData2 *restrict_data = fac_restrict_vdata;
+   hypre_FacSemiRestrictData2 *restrict_data = (hypre_FacSemiRestrictData2 *)fac_restrict_vdata;
 
    hypre_SStructPVector   *fgrid_cvectors     = restrict_data->fgrid_cvectors;
    hypre_BoxArrayArray   **identity_arrayboxes= restrict_data->identity_arrayboxes;
@@ -507,7 +507,6 @@ hypre_FACRestrict2( void                 *  fac_restrict_vdata,
    hypre_Box              *fgrid_box;
    hypre_StructGrid       *cgrid;
    hypre_BoxArray         *cgrid_boxes;
-   hypre_Box              *cgrid_box;
    hypre_BoxArray         *own_boxes;
    hypre_Box              *own_box;
    HYPRE_Int              *boxnums;
@@ -842,7 +841,6 @@ hypre_FACRestrict2( void                 *  fac_restrict_vdata,
       arrayarray_ownboxes= fullwgt_ownboxes[var];
       hypre_ForBoxI(ci, cgrid_boxes)
       {
-         cgrid_box= hypre_BoxArrayBox(cgrid_boxes, ci);
          xc_temp_dbox= hypre_BoxArrayBox(hypre_StructVectorDataSpace(xc_temp), ci);
          xcp_temp[0][0]= hypre_StructVectorBoxData(xc_temp, ci);
 
@@ -910,7 +908,7 @@ HYPRE_Int
 hypre_FacSemiRestrictDestroy2( void *fac_restrict_vdata )
 {
    HYPRE_Int                   ierr = 0;
-   hypre_FacSemiRestrictData2 *fac_restrict_data = fac_restrict_vdata;
+   hypre_FacSemiRestrictData2 *fac_restrict_data = (hypre_FacSemiRestrictData2 *)fac_restrict_vdata;
    HYPRE_Int                   nvars;
    HYPRE_Int                   i, j;
 
