@@ -32,7 +32,7 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
                       hypre_SStructVector  *b_in,
                       hypre_SStructVector  *x_in)
 {
-   hypre_MaxwellData     *maxwell_TV_data = maxwell_vdata;
+	hypre_MaxwellData     *maxwell_TV_data = (hypre_MaxwellData     *)maxwell_vdata;
 
    MPI_Comm               comm = hypre_SStructMatrixComm(Aee_in);
 
@@ -89,15 +89,16 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
    HYPRE_Int            **eCF_marker_l;
    HYPRE_Int              erelax_type;
 
+#if 0
    /* objects needed to fine the edge relaxation parameters */
    HYPRE_Int              relax_type;
-   /*HYPRE_Int             *relax_types;
-     void                  *e_amg_vdata;
-     hypre_ParAMGData      *e_amgData;
-     HYPRE_Int              numCGSweeps= 10;
-     HYPRE_Int            **amg_CF_marker;
-     hypre_ParCSRMatrix   **A_array;*/
-
+   HYPRE_Int             *relax_types;
+   void                  *e_amg_vdata;
+   hypre_ParAMGData      *e_amgData;
+   HYPRE_Int              numCGSweeps= 10;
+   HYPRE_Int            **amg_CF_marker;
+   hypre_ParCSRMatrix   **A_array;
+#endif
 
    hypre_SStructGrid     *node_grid;
    hypre_SStructGraph    *node_graph;
@@ -150,8 +151,8 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
    HYPRE_Int              edge_maxlevels, edge_numlevels, en_numlevels;
 
    HYPRE_Int              constant_coef=  maxwell_TV_data -> constant_coef;
-   HYPRE_Int              true = 1;
-   HYPRE_Int              false= 0;
+   HYPRE_Int              trueV = 1;
+   HYPRE_Int              falseV= 0;
 
    HYPRE_Int              ierr = 0;
 #if DEBUG
@@ -489,7 +490,7 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
                         hypre_SStructVectorParVector(bn),
                         hypre_SStructVectorParVector(xn));
    {
-      amg_data = amg_vdata;
+	   amg_data = (hypre_ParAMGData*) amg_vdata;
 
       node_numlevels= hypre_ParAMGDataNumLevels(amg_data);
 
@@ -594,7 +595,7 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
       hypre_BoxDestroy(box);
       /* the following allows some of the parts to have volume zero grids */
       edge_maxlevels= hypre_max(edge_maxlevels, i);
-      coarsen[part] = true;
+      coarsen[part] = trueV;
    }
 
    if ((maxwell_TV_data-> edge_maxlevels) > 0)
@@ -751,12 +752,12 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
             if (coarsen[part])
             {
                box= hypre_BoxArrayBox(cboxes, part);
-               m= true;
+               m= trueV;
                for (i= 0; i< ndim; i++)
                {
                   if ( hypre_BoxIMaxD(box, i) < hypre_BoxIMinD(box, i) )
                   {
-                     m= false;
+                     m= falseV;
                      break;
                   }
                }
@@ -805,7 +806,7 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
                else 
                {
                   /* record empty, coarsened-away part */
-                  coarsen[part]= false;
+                  coarsen[part]= falseV;
                   /* set up a dummy box so this grid can be destroyed */
                   HYPRE_SStructGridSetExtents(egrid_l[l+1], part,
                                               hypre_BoxIMin(box), hypre_BoxIMin(box));
@@ -1005,7 +1006,7 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
                                                 PTopology_vdata);
             }
 
-            PTopology= PTopology_vdata;
+            PTopology= (hypre_PTopology*)PTopology_vdata;
 
             /* extract off-processors rows of Pe_l[l]. Needed for amge.*/
             hypre_SStructSharedDOF_ParcsrMatRowsComm(egrid_l[l],
@@ -1074,7 +1075,8 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
             &transpose, 1);
          parcsr_mat= hypre_ParMatmul(transpose, Aen_l[l]);
          Aen_l[l+1]= hypre_ParMatmul(parcsr_mat, Pn_l[l]);
-
+         hypre_ParCSRMatrixSetRowStartsOwner(transpose,0);
+         hypre_ParCSRMatrixSetRowStartsOwner(Aen_l[l+1],1);
          hypre_ParCSRMatrixDestroy(parcsr_mat);
          hypre_ParCSRMatrixDestroy(transpose);
 
@@ -1157,7 +1159,7 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
                                              PTopology_vdata);
          }
 
-         PTopology= PTopology_vdata;
+         PTopology= (hypre_PTopology*)PTopology_vdata;
 
          /* extract off-processors rows of Pe_l[l]. Needed for amge.*/
          hypre_SStructSharedDOF_ParcsrMatRowsComm(egrid_l[l],
@@ -1299,42 +1301,44 @@ hypre_MaxwellTV_Setup(void                 *maxwell_vdata,
    eomega       = hypre_TAlloc(HYPRE_Real, edge_numlevels);
    eCF_marker_l = hypre_TAlloc(HYPRE_Int *, edge_numlevels);
 
+#if 0
    relax_type= 6; /* SSOR */
-   /*for (l= 0; l< 1; l++)
-     {
-     erelax_weight[l]= 1.0;
-     eCF_marker_l[l]= NULL;
+   for (l= 0; l< 1; l++)
+   {
+      erelax_weight[l]= 1.0;
+      eCF_marker_l[l]= NULL;
 
-     e_amg_vdata= (void *) hypre_BoomerAMGCreate();
-     e_amgData= e_amg_vdata;
+      e_amg_vdata= (void *) hypre_BoomerAMGCreate();
+      e_amgData= e_amg_vdata;
 
-     relax_types= hypre_CTAlloc(HYPRE_Int, 2);
-     relax_types[1]= relax_type;
+      relax_types= hypre_CTAlloc(HYPRE_Int, 2);
+      relax_types[1]= relax_type;
 
-     amg_CF_marker= hypre_TAlloc(HYPRE_Int *, 1);
-     A_array      = hypre_TAlloc(hypre_ParCSRMatrix *, 1);
+      amg_CF_marker= hypre_TAlloc(HYPRE_Int *, 1);
+      A_array      = hypre_TAlloc(hypre_ParCSRMatrix *, 1);
 
-     amg_CF_marker[0]= NULL;
-     A_array[0]      = Aee_l[l];
+      amg_CF_marker[0]= NULL;
+      A_array[0]      = Aee_l[l];
 
-     (e_amgData -> CF_marker_array)   = amg_CF_marker;
-     (e_amgData -> A_array)           = A_array;
-     (e_amgData -> Vtemp )            = eVtemp_l[l];
-     (e_amgData -> grid_relax_type)   = relax_types;
-     (e_amgData -> smooth_num_levels) = 0;
-     (e_amgData -> smooth_type)       = 0;
-     hypre_BoomerAMGCGRelaxWt((void *) e_amgData, 0, numCGSweeps, &eomega[l]);
+      (e_amgData -> CF_marker_array)   = amg_CF_marker;
+      (e_amgData -> A_array)           = A_array;
+      (e_amgData -> Vtemp )            = eVtemp_l[l];
+      (e_amgData -> grid_relax_type)   = relax_types;
+      (e_amgData -> smooth_num_levels) = 0;
+      (e_amgData -> smooth_type)       = 0;
+      hypre_BoomerAMGCGRelaxWt((void *) e_amgData, 0, numCGSweeps, &eomega[l]);
 
-     hypre_TFree((e_amgData -> A_array));
-     hypre_TFree((e_amgData -> CF_marker_array));
-     hypre_TFree((e_amgData -> grid_relax_type));
-     (e_amgData -> A_array)= NULL;
-     (e_amgData -> Vtemp ) = NULL;
-     (e_amgData -> CF_marker_array)= NULL;
-     (e_amgData -> grid_relax_type)= NULL;
-     hypre_TFree(e_amg_vdata);
-     eomega[l]= 1.0;
-     }*/
+      hypre_TFree((e_amgData -> A_array));
+      hypre_TFree((e_amgData -> CF_marker_array));
+      hypre_TFree((e_amgData -> grid_relax_type));
+      (e_amgData -> A_array)= NULL;
+      (e_amgData -> Vtemp ) = NULL;
+      (e_amgData -> CF_marker_array)= NULL;
+      (e_amgData -> grid_relax_type)= NULL;
+      hypre_TFree(e_amg_vdata);
+      eomega[l]= 1.0;
+   }
+#endif
 
    for (l= 0; l< edge_numlevels; l++)
    {
