@@ -19,6 +19,10 @@
 #include "_hypre_sstruct_mv.h"
 #include "fortran.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+	
 /*--------------------------------------------------------------------------
  * HYPRE_SStructGridCreate
  *--------------------------------------------------------------------------*/
@@ -255,51 +259,6 @@ hypre_F90_IFACE(hypre_sstructgridsetnumghost, HYPRE_SSTRUCTGRIDSETNUMGHOST)
       hypre_F90_PassIntArray (num_ghost) );
 }
 
-/******************************************************************************
- *****************************************************************************/
-
-/*--------------------------------------------------------------------------
- *  HYPRE_SStructGridSetVariable
- *     Like HYPRE_SStructGridSetVariables; except only one variable is done
- *     at a time; nvars is needed for memory allocation.
- *--------------------------------------------------------------------------*/
-
-void
-hypre_F90_IFACE(hypre_sstructgridsetvariable, HYPRE_SSTRUCTGRIDSETVARIABLE)
-   (hypre_F90_Obj *grid,
-    hypre_F90_Int *part,
-    hypre_F90_Int *var,
-    hypre_F90_Int *nvars,
-    hypre_F90_Int *vartype,
-    hypre_F90_Int *ierr)
-{
-   *ierr = (hypre_F90_Int) HYPRE_SStructGridSetVariable(
-      hypre_F90_PassObj (HYPRE_SStructGrid, grid),
-      hypre_F90_PassInt (part),
-      hypre_F90_PassInt (var),
-      hypre_F90_PassInt (nvars),
-      hypre_F90_PassObj (HYPRE_SStructVariable, vartype) );
-}
-
-/*--------------------------------------------------------------------------
- *  HYPRE_SStructGridAddVariable
- *     Like HYPRE_SStructGridAddVariables; except only one variable is done
- *     at a time.
- *--------------------------------------------------------------------------*/
-
-void
-hypre_F90_IFACE(hypre_sstructgridaddvariable, HYPRE_SSTRUCTGRIDADDVARIABLE)
-   (hypre_F90_Obj      *grid,
-    hypre_F90_Int      *part,
-    hypre_F90_IntArray *index,
-    hypre_F90_Int      *var,
-    hypre_F90_Int      *vartype,
-    hypre_F90_Int      *ierr)
-{
-   *ierr = (hypre_F90_Int) HYPRE_SStructGridAddVariable(
-      hypre_F90_PassObj      (HYPRE_SStructGrid, grid),
-      hypre_F90_PassInt      (part),
-      hypre_F90_PassIntArray (index),
-      hypre_F90_PassInt      (var),
-      hypre_F90_PassObj      (HYPRE_SStructVariable, vartype) );
+#ifdef __cplusplus
 }
+#endif
