@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.5 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -21,24 +21,24 @@ typedef struct
 {
    MPI_Comm                comm;
 
-   double                  tol;                /* not yet used */
-   int                     max_iter;
-   int                     rel_change;         /* not yet used */
-   int                     zero_guess;
-   int                     rb_start;
+   HYPRE_Real              tol;                /* not yet used */
+   HYPRE_Int               max_iter;
+   HYPRE_Int               rel_change;         /* not yet used */
+   HYPRE_Int               zero_guess;
+   HYPRE_Int               rb_start;
 
    hypre_StructMatrix     *A;
    hypre_StructVector     *b;
    hypre_StructVector     *x;
 
-   int                     diag_rank;
+   HYPRE_Int               diag_rank;
 
    hypre_ComputePkg       *compute_pkg;
 
    /* log info (always logged) */
-   int                     num_iterations;
-   int                     time_index;
-   int                     flops;
+   HYPRE_Int               num_iterations;
+   HYPRE_Int               time_index;
+   HYPRE_Int               flops;
 
 } hypre_RedBlackGSData;
 
