@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.10 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 #include "_hypre_struct_ls.h"
@@ -74,7 +74,7 @@ hypre_SMG3CreateRAPOp( hypre_StructMatrix *R,
                    *--------------------------------------------------------*/
                   if( i*j == 0 )
                   {
-                     hypre_SetIndex(RAP_stencil_shape[stencil_rank],i,j,k);
+                     hypre_SetIndex3(RAP_stencil_shape[stencil_rank],i,j,k);
                      stencil_rank++;
                   }
                }
@@ -100,7 +100,7 @@ hypre_SMG3CreateRAPOp( hypre_StructMatrix *R,
                    * Storage for 9 elements (c,w,e,n,s,sw,se,nw,se) in
                    * each plane
                    *--------------------------------------------------------*/
-                  hypre_SetIndex(RAP_stencil_shape[stencil_rank],i,j,k);
+                  hypre_SetIndex3(RAP_stencil_shape[stencil_rank],i,j,k);
                   stencil_rank++;
                }
             }
@@ -138,7 +138,7 @@ hypre_SMG3CreateRAPOp( hypre_StructMatrix *R,
                    *--------------------------------------------------------*/
                   if( i*j == 0 && i+j+k <= 0)
                   {
-                     hypre_SetIndex(RAP_stencil_shape[stencil_rank],i,j,k);
+                     hypre_SetIndex3(RAP_stencil_shape[stencil_rank],i,j,k);
                      stencil_rank++;
                   }
                }
@@ -169,7 +169,7 @@ hypre_SMG3CreateRAPOp( hypre_StructMatrix *R,
                    *--------------------------------------------------------*/
                   if( k < 0 || (i+j+k <=0 && j < 1) )
                   {
-                     hypre_SetIndex(RAP_stencil_shape[stencil_rank],i,j,k);
+                     hypre_SetIndex3(RAP_stencil_shape[stencil_rank],i,j,k);
                      stencil_rank++;
                   }
                }
@@ -254,20 +254,20 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
    hypre_Box            *R_dbox;
    hypre_Box            *RAP_dbox;
 
-   double               *pa, *pb;
-   double               *ra, *rb;
+   HYPRE_Real           *pa, *pb;
+   HYPRE_Real           *ra, *rb;
 
-   double               *a_cc, *a_cw, *a_ce, *a_cs, *a_cn;
-   double               *a_ac, *a_aw, *a_as;
-   double               *a_bc, *a_bw, *a_be, *a_bs, *a_bn;
-   double               *a_csw, *a_cse, *a_cnw, *a_cne;
-   double               *a_asw, *a_ase;
-   double               *a_bsw, *a_bse, *a_bnw, *a_bne;
+   HYPRE_Real           *a_cc, *a_cw, *a_ce, *a_cs, *a_cn;
+   HYPRE_Real           *a_ac, *a_aw, *a_as;
+   HYPRE_Real           *a_bc, *a_bw, *a_be, *a_bs, *a_bn;
+   HYPRE_Real           *a_csw, *a_cse, *a_cnw, *a_cne;
+   HYPRE_Real           *a_asw, *a_ase;
+   HYPRE_Real           *a_bsw, *a_bse, *a_bnw, *a_bne;
 
-   double               *rap_cc, *rap_cw, *rap_cs;
-   double               *rap_bc, *rap_bw, *rap_be, *rap_bs, *rap_bn;
-   double               *rap_csw, *rap_cse;
-   double               *rap_bsw, *rap_bse, *rap_bnw, *rap_bne;
+   HYPRE_Real           *rap_cc, *rap_cw, *rap_cs;
+   HYPRE_Real           *rap_bc, *rap_bw, *rap_be, *rap_bs, *rap_bn;
+   HYPRE_Real           *rap_csw, *rap_cse;
+   HYPRE_Real           *rap_bsw, *rap_bse, *rap_bnw, *rap_bne;
 
    HYPRE_Int             iA, iAm1, iAp1;
    HYPRE_Int             iAc;
@@ -283,7 +283,7 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
    fine_stencil_size = hypre_StructStencilSize(fine_stencil);
 
    stridef = cstride;
-   hypre_SetIndex(stridec, 1, 1, 1);
+   hypre_SetIndex3(stridec, 1, 1, 1);
 
    fgrid = hypre_StructMatrixGrid(A);
    fgrid_ids = hypre_StructGridIDs(fgrid);
@@ -316,10 +316,10 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
        * pb is pointer for weight for f-point below c-point 
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       pa = hypre_StructMatrixExtractPointerByIndex(PT, fi, index);
 
-      hypre_SetIndex(index,0,0,-1);
+      hypre_SetIndex3(index,0,0,-1);
       pb = hypre_StructMatrixExtractPointerByIndex(PT, fi, index);
  
       /*-----------------------------------------------------------------
@@ -328,10 +328,10 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
        * rb is pointer for weight for f-point below c-point 
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       ra = hypre_StructMatrixExtractPointerByIndex(R, fi, index);
 
-      hypre_SetIndex(index,0,0,-1);
+      hypre_SetIndex3(index,0,0,-1);
       rb = hypre_StructMatrixExtractPointerByIndex(R, fi, index);
  
       /*-----------------------------------------------------------------
@@ -346,25 +346,25 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
        * a_bc is pointer for center coefficient in plane below
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,0);
+      hypre_SetIndex3(index,0,0,0);
       a_cc = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,-1,0,0);
+      hypre_SetIndex3(index,-1,0,0);
       a_cw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,1,0,0);
+      hypre_SetIndex3(index,1,0,0);
       a_ce = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,0,-1,0);
+      hypre_SetIndex3(index,0,-1,0);
       a_cs = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,0,1,0);
+      hypre_SetIndex3(index,0,1,0);
       a_cn = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       a_ac = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,0,0,-1);
+      hypre_SetIndex3(index,0,0,-1);
       a_bc = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
       /*-----------------------------------------------------------------
@@ -382,22 +382,22 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
 
       if(fine_stencil_size > 7)
       {
-         hypre_SetIndex(index,-1,0,1);
+         hypre_SetIndex3(index,-1,0,1);
          a_aw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,0,-1,1);
+         hypre_SetIndex3(index,0,-1,1);
          a_as = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,-1,0,-1);
+         hypre_SetIndex3(index,-1,0,-1);
          a_bw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,0,-1);
+         hypre_SetIndex3(index,1,0,-1);
          a_be = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,0,-1,-1);
+         hypre_SetIndex3(index,0,-1,-1);
          a_bs = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,0,1,-1);
+         hypre_SetIndex3(index,0,1,-1);
          a_bn = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
       }
@@ -413,16 +413,16 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
 
       if(fine_stencil_size > 15)
       {
-         hypre_SetIndex(index,-1,-1,0);
+         hypre_SetIndex3(index,-1,-1,0);
          a_csw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,-1,0);
+         hypre_SetIndex3(index,1,-1,0);
          a_cse = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,-1,1,0);
+         hypre_SetIndex3(index,-1,1,0);
          a_cnw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,1,0);
+         hypre_SetIndex3(index,1,1,0);
          a_cne = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
       }
@@ -442,22 +442,22 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
 
       if(fine_stencil_size > 19)
       {
-         hypre_SetIndex(index,-1,-1,1);
+         hypre_SetIndex3(index,-1,-1,1);
          a_asw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,-1,1);
+         hypre_SetIndex3(index,1,-1,1);
          a_ase = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,-1,-1,-1);
+         hypre_SetIndex3(index,-1,-1,-1);
          a_bsw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,-1,-1);
+         hypre_SetIndex3(index,1,-1,-1);
          a_bse = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,-1,1,-1);
+         hypre_SetIndex3(index,-1,1,-1);
          a_bnw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,1,-1);
+         hypre_SetIndex3(index,1,1,-1);
          a_bne = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
       }
@@ -470,28 +470,28 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
        * rap_cc is pointer for center coefficient (etc.)
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,0);
+      hypre_SetIndex3(index,0,0,0);
       rap_cc = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,-1,0,0);
+      hypre_SetIndex3(index,-1,0,0);
       rap_cw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,0,-1,0);
+      hypre_SetIndex3(index,0,-1,0);
       rap_cs = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,0,0,-1);
+      hypre_SetIndex3(index,0,0,-1);
       rap_bc = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,-1,0,-1);
+      hypre_SetIndex3(index,-1,0,-1);
       rap_bw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,1,0,-1);
+      hypre_SetIndex3(index,1,0,-1);
       rap_be = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,0,-1,-1);
+      hypre_SetIndex3(index,0,-1,-1);
       rap_bs = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,0,1,-1);
+      hypre_SetIndex3(index,0,1,-1);
       rap_bn = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
       /*-----------------------------------------------------------------
@@ -507,27 +507,27 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
 
       if(fine_stencil_size > 15)
       {
-         hypre_SetIndex(index,-1,-1,0);
+         hypre_SetIndex3(index,-1,-1,0);
          rap_csw =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,-1,0);
+         hypre_SetIndex3(index,1,-1,0);
          rap_cse =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,-1,-1);
+         hypre_SetIndex3(index,-1,-1,-1);
          rap_bsw =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,-1,-1);
+         hypre_SetIndex3(index,1,-1,-1);
          rap_bse =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,1,-1);
+         hypre_SetIndex3(index,-1,1,-1);
          rap_bnw =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,1,-1);
+         hypre_SetIndex3(index,1,1,-1);
          rap_bne =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
@@ -541,12 +541,12 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
        * Offsets are used in refering to data associated with other points. 
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       zOffsetA = hypre_BoxOffsetDistance(A_dbox,index); 
       zOffsetP = hypre_BoxOffsetDistance(PT_dbox,index); 
-      hypre_SetIndex(index,0,1,0);
+      hypre_SetIndex3(index,0,1,0);
       yOffsetP = hypre_BoxOffsetDistance(PT_dbox,index); 
-      hypre_SetIndex(index,1,0,0);
+      hypre_SetIndex3(index,1,0,0);
       xOffsetP = hypre_BoxOffsetDistance(PT_dbox,index); 
 
       /*--------------------------------------------------------------------
@@ -568,7 +568,7 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
          case 7:
 
             hypre_BoxGetSize(cgrid_box, loop_size);
-            hypre_BoxLoop4Begin(hypre_StructMatrixDim(A), loop_size,
+            hypre_BoxLoop4Begin(hypre_StructMatrixNDim(A), loop_size,
                                 PT_dbox,  cstart, stridec, iP,
                                 R_dbox,   cstart, stridec, iR,
                                 A_dbox,   fstart, stridef, iA,
@@ -632,7 +632,7 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
          case 15:
 
             hypre_BoxGetSize(cgrid_box, loop_size);
-            hypre_BoxLoop4Begin(hypre_StructMatrixDim(A), loop_size,
+            hypre_BoxLoop4Begin(hypre_StructMatrixNDim(A), loop_size,
                                 PT_dbox,  cstart, stridec, iP,
                                 R_dbox,   cstart, stridec, iR,
                                 A_dbox,   fstart, stridef, iA,
@@ -713,7 +713,7 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
          case 19:
 
             hypre_BoxGetSize(cgrid_box, loop_size);
-            hypre_BoxLoop4Begin(hypre_StructMatrixDim(A), loop_size,
+            hypre_BoxLoop4Begin(hypre_StructMatrixNDim(A), loop_size,
                                 PT_dbox,  cstart, stridec, iP,
                                 R_dbox,   cstart, stridec, iR,
                                 A_dbox,   fstart, stridef, iA,
@@ -816,7 +816,7 @@ hypre_SMG3BuildRAPSym( hypre_StructMatrix *A,
          default:
 
             hypre_BoxGetSize(cgrid_box, loop_size);
-            hypre_BoxLoop4Begin(hypre_StructMatrixDim(A), loop_size,
+            hypre_BoxLoop4Begin(hypre_StructMatrixNDim(A), loop_size,
                                 PT_dbox,  cstart, stridec, iP,
                                 R_dbox,   cstart, stridec, iR,
                                 A_dbox,   fstart, stridef, iA,
@@ -967,20 +967,20 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
    hypre_Box            *R_dbox;
    hypre_Box            *RAP_dbox;
 
-   double               *pa, *pb;
-   double               *ra, *rb;
+   HYPRE_Real           *pa, *pb;
+   HYPRE_Real           *ra, *rb;
 
-   double               *a_cc, *a_cw, *a_ce, *a_cs, *a_cn;
-   double               *a_ac, *a_aw, *a_ae, *a_as, *a_an;
-   double               *a_be, *a_bn;
-   double               *a_csw, *a_cse, *a_cnw, *a_cne;
-   double               *a_asw, *a_ase, *a_anw, *a_ane;
-   double               *a_bnw, *a_bne;
+   HYPRE_Real           *a_cc, *a_cw, *a_ce, *a_cs, *a_cn;
+   HYPRE_Real           *a_ac, *a_aw, *a_ae, *a_as, *a_an;
+   HYPRE_Real           *a_be, *a_bn;
+   HYPRE_Real           *a_csw, *a_cse, *a_cnw, *a_cne;
+   HYPRE_Real           *a_asw, *a_ase, *a_anw, *a_ane;
+   HYPRE_Real           *a_bnw, *a_bne;
 
-   double               *rap_ce, *rap_cn;
-   double               *rap_ac, *rap_aw, *rap_ae, *rap_as, *rap_an;
-   double               *rap_cnw, *rap_cne;
-   double               *rap_asw, *rap_ase, *rap_anw, *rap_ane;
+   HYPRE_Real           *rap_ce, *rap_cn;
+   HYPRE_Real           *rap_ac, *rap_aw, *rap_ae, *rap_as, *rap_an;
+   HYPRE_Real           *rap_cnw, *rap_cne;
+   HYPRE_Real           *rap_asw, *rap_ase, *rap_anw, *rap_ane;
 
    HYPRE_Int            iA, iAm1, iAp1;
    HYPRE_Int            iAc;
@@ -996,7 +996,7 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
    fine_stencil_size = hypre_StructStencilSize(fine_stencil);
 
    stridef = cstride;
-   hypre_SetIndex(stridec, 1, 1, 1);
+   hypre_SetIndex3(stridec, 1, 1, 1);
 
    fgrid = hypre_StructMatrixGrid(A);
    fgrid_ids = hypre_StructGridIDs(fgrid);
@@ -1029,10 +1029,10 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
        * pb is pointer for weight for f-point below c-point 
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       pa = hypre_StructMatrixExtractPointerByIndex(PT, fi, index);
 
-      hypre_SetIndex(index,0,0,-1);
+      hypre_SetIndex3(index,0,0,-1);
       pb = hypre_StructMatrixExtractPointerByIndex(PT, fi, index);
 
  
@@ -1042,10 +1042,10 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
        * rb is pointer for weight for f-point below c-point 
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       ra = hypre_StructMatrixExtractPointerByIndex(R, fi, index);
 
-      hypre_SetIndex(index,0,0,-1);
+      hypre_SetIndex3(index,0,0,-1);
       rb = hypre_StructMatrixExtractPointerByIndex(R, fi, index);
 
  
@@ -1061,22 +1061,22 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
        * a_bc is pointer for center coefficient in plane below
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,0);
+      hypre_SetIndex3(index,0,0,0);
       a_cc = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,-1,0,0);
+      hypre_SetIndex3(index,-1,0,0);
       a_cw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,1,0,0);
+      hypre_SetIndex3(index,1,0,0);
       a_ce = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,0,-1,0);
+      hypre_SetIndex3(index,0,-1,0);
       a_cs = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,0,1,0);
+      hypre_SetIndex3(index,0,1,0);
       a_cn = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       a_ac = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
       /*-----------------------------------------------------------------
@@ -1094,22 +1094,22 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
 
       if(fine_stencil_size > 7)
       {
-         hypre_SetIndex(index,-1,0,1);
+         hypre_SetIndex3(index,-1,0,1);
          a_aw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,0,1);
+         hypre_SetIndex3(index,1,0,1);
          a_ae = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,0,-1,1);
+         hypre_SetIndex3(index,0,-1,1);
          a_as = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,0,1,1);
+         hypre_SetIndex3(index,0,1,1);
          a_an = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,0,-1);
+         hypre_SetIndex3(index,1,0,-1);
          a_be = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,0,1,-1);
+         hypre_SetIndex3(index,0,1,-1);
          a_bn = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
       }
@@ -1125,16 +1125,16 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
 
       if(fine_stencil_size > 15)
       {
-         hypre_SetIndex(index,-1,-1,0);
+         hypre_SetIndex3(index,-1,-1,0);
          a_csw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,-1,0);
+         hypre_SetIndex3(index,1,-1,0);
          a_cse = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,-1,1,0);
+         hypre_SetIndex3(index,-1,1,0);
          a_cnw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,1,0);
+         hypre_SetIndex3(index,1,1,0);
          a_cne = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
       }
@@ -1154,22 +1154,22 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
 
       if(fine_stencil_size > 19)
       {
-         hypre_SetIndex(index,-1,-1,1);
+         hypre_SetIndex3(index,-1,-1,1);
          a_asw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,-1,1);
+         hypre_SetIndex3(index,1,-1,1);
          a_ase = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,-1,1,1);
+         hypre_SetIndex3(index,-1,1,1);
          a_anw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,1,1);
+         hypre_SetIndex3(index,1,1,1);
          a_ane = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,-1,1,-1);
+         hypre_SetIndex3(index,-1,1,-1);
          a_bnw = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
-         hypre_SetIndex(index,1,1,-1);
+         hypre_SetIndex3(index,1,1,-1);
          a_bne = hypre_StructMatrixExtractPointerByIndex(A, fi, index);
 
       }
@@ -1182,25 +1182,25 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
        * rap_ce is pointer for east coefficient in same plane (etc.)
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,1,0,0);
+      hypre_SetIndex3(index,1,0,0);
       rap_ce = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,0,1,0);
+      hypre_SetIndex3(index,0,1,0);
       rap_cn = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       rap_ac = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,-1,0,1);
+      hypre_SetIndex3(index,-1,0,1);
       rap_aw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,1,0,1);
+      hypre_SetIndex3(index,1,0,1);
       rap_ae = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,0,-1,1);
+      hypre_SetIndex3(index,0,-1,1);
       rap_as = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-      hypre_SetIndex(index,0,1,1);
+      hypre_SetIndex3(index,0,1,1);
       rap_an = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
       /*-----------------------------------------------------------------
@@ -1216,27 +1216,27 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
 
       if(fine_stencil_size > 15)
       {
-         hypre_SetIndex(index,-1,1,0);
+         hypre_SetIndex3(index,-1,1,0);
          rap_cnw =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,1,0);
+         hypre_SetIndex3(index,1,1,0);
          rap_cne =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,-1,1);
+         hypre_SetIndex3(index,-1,-1,1);
          rap_asw =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,-1,1);
+         hypre_SetIndex3(index,1,-1,1);
          rap_ase =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,1,1);
+         hypre_SetIndex3(index,-1,1,1);
          rap_anw =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,1,1);
+         hypre_SetIndex3(index,1,1,1);
          rap_ane =
             hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
@@ -1250,12 +1250,12 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
        * Offsets are used in refering to data associated with other points. 
        *-----------------------------------------------------------------*/
 
-      hypre_SetIndex(index,0,0,1);
+      hypre_SetIndex3(index,0,0,1);
       zOffsetA = hypre_BoxOffsetDistance(A_dbox,index); 
       zOffsetP = hypre_BoxOffsetDistance(PT_dbox,index); 
-      hypre_SetIndex(index,0,1,0);
+      hypre_SetIndex3(index,0,1,0);
       yOffsetP = hypre_BoxOffsetDistance(PT_dbox,index); 
-      hypre_SetIndex(index,1,0,0);
+      hypre_SetIndex3(index,1,0,0);
       xOffsetP = hypre_BoxOffsetDistance(PT_dbox,index); 
 
       /*-----------------------------------------------------------------
@@ -1276,7 +1276,7 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
          case 7:
 
             hypre_BoxGetSize(cgrid_box, loop_size);
-            hypre_BoxLoop4Begin(hypre_StructMatrixDim(A), loop_size,
+            hypre_BoxLoop4Begin(hypre_StructMatrixNDim(A), loop_size,
                                 PT_dbox,  cstart, stridec, iP,
                                 R_dbox,   cstart, stridec, iR,
                                 A_dbox,   fstart, stridef, iA,
@@ -1331,7 +1331,7 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
          case 15:
 
             hypre_BoxGetSize(cgrid_box, loop_size);
-            hypre_BoxLoop4Begin(hypre_StructMatrixDim(A), loop_size,
+            hypre_BoxLoop4Begin(hypre_StructMatrixNDim(A), loop_size,
                                 PT_dbox,  cstart, stridec, iP,
                                 R_dbox,   cstart, stridec, iR,
                                 A_dbox,   fstart, stridef, iA,
@@ -1405,7 +1405,7 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
          case 19:
 
             hypre_BoxGetSize(cgrid_box, loop_size);
-            hypre_BoxLoop4Begin(hypre_StructMatrixDim(A), loop_size,
+            hypre_BoxLoop4Begin(hypre_StructMatrixNDim(A), loop_size,
                                 PT_dbox,  cstart, stridec, iP,
                                 R_dbox,   cstart, stridec, iR,
                                 A_dbox,   fstart, stridef, iA,
@@ -1500,7 +1500,7 @@ hypre_SMG3BuildRAPNoSym( hypre_StructMatrix *A,
          default:
 
             hypre_BoxGetSize(cgrid_box, loop_size);
-            hypre_BoxLoop4Begin(hypre_StructMatrixDim(A), loop_size,
+            hypre_BoxLoop4Begin(hypre_StructMatrixNDim(A), loop_size,
                                 PT_dbox,  cstart, stridec, iP,
                                 R_dbox,   cstart, stridec, iR,
                                 A_dbox,   fstart, stridef, iA,
@@ -1632,10 +1632,10 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
 
    hypre_Box           *RAP_dbox;
 
-   double               *rap_bc, *rap_bw, *rap_be, *rap_bs, *rap_bn;
-   double               *rap_cc, *rap_cw,  *rap_cs;
-   double               *rap_bsw, *rap_bse, *rap_bnw, *rap_bne;
-   double               *rap_csw, *rap_cse;
+   HYPRE_Real           *rap_bc, *rap_bw, *rap_be, *rap_bs, *rap_bn;
+   HYPRE_Real           *rap_cc, *rap_cw,  *rap_cs;
+   HYPRE_Real           *rap_bsw, *rap_bse, *rap_bnw, *rap_bne;
+   HYPRE_Real           *rap_csw, *rap_cse;
 
    HYPRE_Int            iAc;
    HYPRE_Int            iAcmx;
@@ -1646,7 +1646,7 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
    HYPRE_Int            xOffset;
    HYPRE_Int            yOffset;
 
-   double               zero = 0.0;
+   HYPRE_Real           zero = 0.0;
 
    hypre_StructStencil *stencil;
    HYPRE_Int            stencil_size;
@@ -1654,7 +1654,7 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
    stencil = hypre_StructMatrixStencil(RAP);
    stencil_size = hypre_StructStencilSize(stencil);
 
-   hypre_SetIndex(stridec, 1, 1, 1);
+   hypre_SetIndex3(stridec, 1, 1, 1);
 
    cgrid = hypre_StructMatrixGrid(RAP);
    cgrid_boxes = hypre_StructGridBoxes(cgrid);
@@ -1671,9 +1671,9 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
 
          RAP_dbox = hypre_BoxArrayBox(hypre_StructMatrixDataSpace(RAP), ci);
 
-         hypre_SetIndex(index,1,0,0);
+         hypre_SetIndex3(index,1,0,0);
          xOffset = hypre_BoxOffsetDistance(RAP_dbox,index);
-         hypre_SetIndex(index,0,1,0);
+         hypre_SetIndex3(index,0,1,0);
          yOffset = hypre_BoxOffsetDistance(RAP_dbox,index);
 
 
@@ -1681,28 +1681,28 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
           * Extract pointers for 15-point coarse grid operator:
           *-----------------------------------------------------------------*/
 
-         hypre_SetIndex(index,0,0,-1);
+         hypre_SetIndex3(index,0,0,-1);
          rap_bc = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,0,-1);
+         hypre_SetIndex3(index,-1,0,-1);
          rap_bw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,0,-1);
+         hypre_SetIndex3(index,1,0,-1);
          rap_be = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,-1,-1);
+         hypre_SetIndex3(index,0,-1,-1);
          rap_bs = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,1,-1);
+         hypre_SetIndex3(index,0,1,-1);
          rap_bn = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,0,0);
+         hypre_SetIndex3(index,0,0,0);
          rap_cc = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,0,0);
+         hypre_SetIndex3(index,-1,0,0);
          rap_cw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,-1,0);
+         hypre_SetIndex3(index,0,-1,0);
          rap_cs = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
          /*-----------------------------------------------------------------
@@ -1711,22 +1711,22 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
 
          if(stencil_size == 27)
          {
-            hypre_SetIndex(index,-1,-1,-1);
+            hypre_SetIndex3(index,-1,-1,-1);
             rap_bsw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,-1,-1);
+            hypre_SetIndex3(index,1,-1,-1);
             rap_bse = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,-1,1,-1);
+            hypre_SetIndex3(index,-1,1,-1);
             rap_bnw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,1,-1);
+            hypre_SetIndex3(index,1,1,-1);
             rap_bne = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,-1,-1,0);
+            hypre_SetIndex3(index,-1,-1,0);
             rap_csw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,-1,0);
+            hypre_SetIndex3(index,1,-1,0);
             rap_cse = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
          }
 
@@ -1736,7 +1736,7 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
 
          hypre_BoxGetSize(cgrid_box, loop_size);
 
-         hypre_BoxLoop1Begin(hypre_StructMatrixDim(RAP), loop_size,
+         hypre_BoxLoop1Begin(hypre_StructMatrixNDim(RAP), loop_size,
                              RAP_dbox,  cstart, stridec, iAc);
 #ifdef HYPRE_USING_OPENMP
 #pragma omp parallel for private(HYPRE_BOX_PRIVATE,iAc,iAcmx,iAcmy) HYPRE_SMP_SCHEDULE
@@ -1752,7 +1752,7 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
          }
          hypre_BoxLoop1End(iAc);
 
-         hypre_BoxLoop1Begin(hypre_StructMatrixDim(RAP), loop_size,
+         hypre_BoxLoop1Begin(hypre_StructMatrixNDim(RAP), loop_size,
                              RAP_dbox,  cstart, stridec, iAc);
 #ifdef HYPRE_USING_OPENMP
 #pragma omp parallel for private(HYPRE_BOX_PRIVATE,iAc) HYPRE_SMP_SCHEDULE
@@ -1775,7 +1775,7 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
          {
             hypre_BoxGetSize(cgrid_box, loop_size);
 
-            hypre_BoxLoop1Begin(hypre_StructMatrixDim(RAP), loop_size,
+            hypre_BoxLoop1Begin(hypre_StructMatrixNDim(RAP), loop_size,
                                 RAP_dbox,  cstart, stridec, iAc);
 #ifdef HYPRE_USING_OPENMP
 #pragma omp parallel for private(HYPRE_BOX_PRIVATE,iAc,iAcmxmy,iAcpxmy) HYPRE_SMP_SCHEDULE
@@ -1792,7 +1792,7 @@ hypre_SMG3RAPPeriodicSym( hypre_StructMatrix *RAP,
             }
             hypre_BoxLoop1End(iAc);
 
-            hypre_BoxLoop1Begin(hypre_StructMatrixDim(RAP), loop_size,
+            hypre_BoxLoop1Begin(hypre_StructMatrixNDim(RAP), loop_size,
                                 RAP_dbox,  cstart, stridec, iAc);
 #ifdef HYPRE_USING_OPENMP
 #pragma omp parallel for private(HYPRE_BOX_PRIVATE,iAc) HYPRE_SMP_SCHEDULE
@@ -1838,16 +1838,16 @@ hypre_SMG3RAPPeriodicNoSym( hypre_StructMatrix *RAP,
 
    hypre_Box           *RAP_dbox;
 
-   double               *rap_bc, *rap_bw, *rap_be, *rap_bs, *rap_bn;
-   double               *rap_cc, *rap_cw, *rap_ce, *rap_cs, *rap_cn;
-   double               *rap_ac, *rap_aw, *rap_ae, *rap_as, *rap_an;
-   double               *rap_bsw, *rap_bse, *rap_bnw, *rap_bne;
-   double               *rap_csw, *rap_cse, *rap_cnw, *rap_cne;
-   double               *rap_asw, *rap_ase, *rap_anw, *rap_ane;
+   HYPRE_Real           *rap_bc, *rap_bw, *rap_be, *rap_bs, *rap_bn;
+   HYPRE_Real           *rap_cc, *rap_cw, *rap_ce, *rap_cs, *rap_cn;
+   HYPRE_Real           *rap_ac, *rap_aw, *rap_ae, *rap_as, *rap_an;
+   HYPRE_Real           *rap_bsw, *rap_bse, *rap_bnw, *rap_bne;
+   HYPRE_Real           *rap_csw, *rap_cse, *rap_cnw, *rap_cne;
+   HYPRE_Real           *rap_asw, *rap_ase, *rap_anw, *rap_ane;
 
    HYPRE_Int            iAc;
 
-   double               zero = 0.0;
+   HYPRE_Real           zero = 0.0;
 
    hypre_StructStencil *stencil;
    HYPRE_Int            stencil_size;
@@ -1855,7 +1855,7 @@ hypre_SMG3RAPPeriodicNoSym( hypre_StructMatrix *RAP,
    stencil = hypre_StructMatrixStencil(RAP);
    stencil_size = hypre_StructStencilSize(stencil);
 
-   hypre_SetIndex(stridec, 1, 1, 1);
+   hypre_SetIndex3(stridec, 1, 1, 1);
 
    cgrid = hypre_StructMatrixGrid(RAP);
    cgrid_boxes = hypre_StructGridBoxes(cgrid);
@@ -1874,49 +1874,49 @@ hypre_SMG3RAPPeriodicNoSym( hypre_StructMatrix *RAP,
           * Extract pointers for 15-point coarse grid operator:
           *-----------------------------------------------------------------*/
 
-         hypre_SetIndex(index,0,0,-1);
+         hypre_SetIndex3(index,0,0,-1);
          rap_bc = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,0,-1);
+         hypre_SetIndex3(index,-1,0,-1);
          rap_bw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,0,-1);
+         hypre_SetIndex3(index,1,0,-1);
          rap_be = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,-1,-1);
+         hypre_SetIndex3(index,0,-1,-1);
          rap_bs = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,1,-1);
+         hypre_SetIndex3(index,0,1,-1);
          rap_bn = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,0,0);
+         hypre_SetIndex3(index,0,0,0);
          rap_cc = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,0,0);
+         hypre_SetIndex3(index,-1,0,0);
          rap_cw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,0,0);
+         hypre_SetIndex3(index,1,0,0);
          rap_ce = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,-1,0);
+         hypre_SetIndex3(index,0,-1,0);
          rap_cs = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,1,0);
+         hypre_SetIndex3(index,0,1,0);
          rap_cn = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,0,1);
+         hypre_SetIndex3(index,0,0,1);
          rap_ac = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,-1,0,1);
+         hypre_SetIndex3(index,-1,0,1);
          rap_aw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,1,0,1);
+         hypre_SetIndex3(index,1,0,1);
          rap_ae = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,-1,1);
+         hypre_SetIndex3(index,0,-1,1);
          rap_as = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-         hypre_SetIndex(index,0,1,1);
+         hypre_SetIndex3(index,0,1,1);
          rap_an = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
          /*-----------------------------------------------------------------
@@ -1926,40 +1926,40 @@ hypre_SMG3RAPPeriodicNoSym( hypre_StructMatrix *RAP,
          if(stencil_size == 27)
          {
 
-            hypre_SetIndex(index,-1,-1,-1);
+            hypre_SetIndex3(index,-1,-1,-1);
             rap_bsw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,-1,-1);
+            hypre_SetIndex3(index,1,-1,-1);
             rap_bse = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,-1,1,-1);
+            hypre_SetIndex3(index,-1,1,-1);
             rap_bnw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,1,-1);
+            hypre_SetIndex3(index,1,1,-1);
             rap_bne = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,-1,-1,0);
+            hypre_SetIndex3(index,-1,-1,0);
             rap_csw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,-1,0);
+            hypre_SetIndex3(index,1,-1,0);
             rap_cse = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,-1,1,0);
+            hypre_SetIndex3(index,-1,1,0);
             rap_cnw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,1,0);
+            hypre_SetIndex3(index,1,1,0);
             rap_cne = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,-1,-1,1);
+            hypre_SetIndex3(index,-1,-1,1);
             rap_asw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,-1,1);
+            hypre_SetIndex3(index,1,-1,1);
             rap_ase = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,-1,1,1);
+            hypre_SetIndex3(index,-1,1,1);
             rap_anw = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
-            hypre_SetIndex(index,1,1,1);
+            hypre_SetIndex3(index,1,1,1);
             rap_ane = hypre_StructMatrixExtractPointerByIndex(RAP, ci, index);
 
          }
@@ -1970,7 +1970,7 @@ hypre_SMG3RAPPeriodicNoSym( hypre_StructMatrix *RAP,
 
          hypre_BoxGetSize(cgrid_box, loop_size);
 
-         hypre_BoxLoop1Begin(hypre_StructMatrixDim(RAP), loop_size,
+         hypre_BoxLoop1Begin(hypre_StructMatrixNDim(RAP), loop_size,
                              RAP_dbox,  cstart, stridec, iAc);
 
 #ifdef HYPRE_USING_OPENMP
@@ -2009,7 +2009,7 @@ hypre_SMG3RAPPeriodicNoSym( hypre_StructMatrix *RAP,
          {
             hypre_BoxGetSize(cgrid_box, loop_size);
 
-            hypre_BoxLoop1Begin(hypre_StructMatrixDim(RAP), loop_size,
+            hypre_BoxLoop1Begin(hypre_StructMatrixNDim(RAP), loop_size,
                                 RAP_dbox,  cstart, stridec, iAc);
 #ifdef HYPRE_USING_OPENMP
 #pragma omp parallel for private(HYPRE_BOX_PRIVATE,iAc) HYPRE_SMP_SCHEDULE
