@@ -579,7 +579,7 @@ hypre_APRefineRegionsByVol( hypre_BoxArray *region_array,
    HYPRE_Real        *fraction_full;
    HYPRE_Int         *order;
    HYPRE_Int          myid, num_procs, est_size;
-   HYPRE_Int          new;
+   HYPRE_Int          new1;
       
    hypre_BoxArray    *tmp_array;
    hypre_Box         *box;
@@ -651,11 +651,11 @@ hypre_APRefineRegionsByVol( hypre_BoxArray *region_array,
       }
       
       box = hypre_BoxArrayBox(region_array, order[loop]);
-      hypre_APSubdivideRegion(box, ndim, 1, tmp_array, &new);
+      hypre_APSubdivideRegion(box, ndim, 1, tmp_array, &new1);
 
-      if (new > 1) /* If new = 1, then no subdividing occured */
+      if (new1 > 1) /* If new = 1, then no subdividing occured */
       {
-         num_regions = num_regions + new - 1; /* The orginal will be deleted */
+         num_regions = num_regions + new1 - 1; /* The orginal will be deleted */
          
          delete_indices[count] = order[loop];
          count++; /* Number of regions subdivided */
@@ -703,7 +703,7 @@ hypre_APRefineRegionsByVol( hypre_BoxArray *region_array,
    {
       /* We subdivided count regions */
       /* Delete the old regions */
-      qsort0(delete_indices, 0, count-1); /* Put deleted indices in asc order */
+      hypre_qsort0(delete_indices, 0, count-1); /* Put deleted indices in asc order */
       hypre_DeleteMultipleBoxes( region_array, delete_indices, count );
    }
 
@@ -759,7 +759,7 @@ hypre_StructAssumedPartitionCreate(
    HYPRE_Int          total_boxes, proc_count, max_position;
    HYPRE_Int         *proc_array=NULL;
    HYPRE_Int          initial_level;
-   HYPRE_Int          dmin, dmax;
+   HYPRE_Int          dmax;
    HYPRE_Real         width, wmin, wmax;
    HYPRE_Real         rn_cubes, rn_cube_procs, rn_cube_divs, rdiv;
 
@@ -1142,14 +1142,13 @@ hypre_StructAssumedPartitionCreate(
       box = hypre_BoxArrayBox(region_array, i);
 
       /* Find min width and max width dimensions */
-      dmin = dmax = 0;
+      dmax = 0;
       wmin = wmax = hypre_BoxSizeD(box, 0);
       for (d = 1; d < ndim; d++)
       {
          width = hypre_BoxSizeD(box, d);
          if (width < wmin)
          {
-            dmin = d;
             wmin = width;
          }
          else if (width > wmax)
@@ -1435,8 +1434,8 @@ hypre_APFillResponseStructAssumedPart(
    hypre_Box   *box;
      
    hypre_BoxArray              *part_boxes;
-   hypre_DataExchangeResponse  *response_obj = ro;  
-   hypre_StructAssumedPart     *assumed_part = response_obj->data1;  
+   hypre_DataExchangeResponse  *response_obj = (hypre_DataExchangeResponse  *)ro;  
+   hypre_StructAssumedPart     *assumed_part = (hypre_StructAssumedPart     *)response_obj->data1;  
 
    /* Initialize stuff */
    hypre_MPI_Comm_rank(comm, &myid );
@@ -1799,7 +1798,7 @@ hypre_StructAssumedPartitionGetProcsFromBox(
    {
       /* Determine unique proc_ids (could be duplicates due to a processor
          owning more than one partiton in a region).  Sort the array. */
-      qsort0(proc_ids, 0, num_proc_ids-1);
+      hypre_qsort0(proc_ids, 0, num_proc_ids-1);
       
       /* Make sure we have enough space from proc_array */
       if (*size_alloc_proc_array < num_proc_ids)
