@@ -534,7 +534,7 @@ hypre_BoxManIncSize ( hypre_BoxManager *manager,
    entries = hypre_TReAlloc(entries, hypre_BoxManEntry, max_nentries);
    ids = hypre_TReAlloc(ids, HYPRE_Int, max_nentries);
    procs =  hypre_TReAlloc(procs, HYPRE_Int, max_nentries);
-   info = hypre_ReAlloc(info, max_nentries*info_size);
+   info = (void *)hypre_ReAlloc((char *)info, max_nentries*info_size);
 
    /* update manager */
    hypre_BoxManMaxNEntries(manager) = max_nentries;
@@ -578,7 +578,7 @@ hypre_BoxManDestroy( hypre_BoxManager *manager )
 
       hypre_TFree(hypre_BoxManEntries(manager));
 
-      hypre_Free(hypre_BoxManInfoObjects(manager));
+      hypre_Free((char *)hypre_BoxManInfoObjects(manager));
       
       hypre_TFree(hypre_BoxManIndexTable(manager));
       
@@ -1140,7 +1140,7 @@ hypre_BoxManAssemble( hypre_BoxManager *manager )
    HYPRE_Int  i, j, k;
 
    HYPRE_Int need_to_sort = 1; /* default it to sort */
-   HYPRE_Int short_sort = 0; /*do abreviated sort */
+   //HYPRE_Int short_sort = 0; /*do abreviated sort */
    
    HYPRE_Int  non_ap_gather = 1; /* default to gather w/out ap*/
 
@@ -1235,7 +1235,8 @@ hypre_BoxManAssemble( hypre_BoxManager *manager )
       {
          HYPRE_Int  size;
          HYPRE_Int *tmp_proc_ids;
-         HYPRE_Int  proc_count, proc_alloc, max_proc_count;
+         HYPRE_Int  proc_count, proc_alloc;
+         //HYPRE_Int  max_proc_count;
          HYPRE_Int *proc_array;
          HYPRE_Int *ap_proc_ids;
          HYPRE_Int  count;
@@ -1399,7 +1400,7 @@ hypre_BoxManAssemble( hypre_BoxManager *manager )
             
             /* now get rid of redundencies in tmp_proc_ids (since a box can lie
                in more than one AP - put in ap_proc_ids*/      
-            qsort0(tmp_proc_ids, 0, count-1);
+            hypre_qsort0(tmp_proc_ids, 0, count-1);
             proc_count = 0;
             ap_proc_ids = hypre_CTAlloc(HYPRE_Int, count);
             
@@ -1433,7 +1434,7 @@ hypre_BoxManAssemble( hypre_BoxManager *manager )
             hypre_MPI_Allreduce(send_statbuf, statbuf, 3, HYPRE_MPI_INT,
                                 hypre_MPI_MAX, comm);   
 
-            max_proc_count = statbuf[0];
+            //max_proc_count = statbuf[0];
             
             /* we do not want a single processor to do a ton of point to point
                communications (relative to the number of total processors - how
@@ -1531,7 +1532,7 @@ hypre_BoxManAssemble( hypre_BoxManager *manager )
                 * procs and also my id ) */
                
                /*first sort on proc_id  */
-               qsort0(neighbor_proc_ids, 0, size-1);
+               hypre_qsort0(neighbor_proc_ids, 0, size-1);
                
                /* new contact list: */
                contact_proc_ids = hypre_CTAlloc(HYPRE_Int, size);
@@ -1570,7 +1571,7 @@ hypre_BoxManAssemble( hypre_BoxManager *manager )
 
                   /* in this case, we can do the "short sort" because we will
                      not have any duplicate proc ids */
-                  short_sort = 1;
+                  //short_sort = 1;
 
                   for (i=0; i< proc_count; i++)
                   {
@@ -1608,12 +1609,14 @@ hypre_BoxManAssemble( hypre_BoxManager *manager )
                   
                   proc_count = new_count;
                }
+#if 0
                /* also can do the short sort if we just have boxes that are
                   ours....here we also don't need to check for duplicates */
                if (nentries == num_my_entries)
                {
                   short_sort = 1;
                }
+#endif
 
                send_buf_starts = hypre_CTAlloc(HYPRE_Int, proc_count + 1);
                for (i=0; i< proc_count+1; i++)
@@ -2111,7 +2114,7 @@ hypre_BoxManAssemble( hypre_BoxManager *manager )
                
             }
             hypre_TFree(entries);
-            hypre_Free(hypre_BoxManInfoObjects(manager));
+            hypre_Free((char*)hypre_BoxManInfoObjects(manager));
 
             hypre_BoxManEntries(manager) = new_entries;
             hypre_BoxManMaxNEntries(manager) = size;
@@ -2638,8 +2641,8 @@ hypre_FillResponseBoxManAssemble1( void *p_recv_contact_buf,
    HYPRE_Int   *proc_ids;
    HYPRE_Int   *send_response_buf = (HYPRE_Int *) *p_send_response_buf;
  
-   hypre_DataExchangeResponse  *response_obj = ro;  
-   hypre_StructAssumedPart     *ap = response_obj->data1;  
+   hypre_DataExchangeResponse  *response_obj = (hypre_DataExchangeResponse  *)ro;  
+   hypre_StructAssumedPart     *ap = (hypre_StructAssumedPart     *)response_obj->data1;  
 
    HYPRE_Int overhead = response_obj->send_response_overhead;
 
@@ -2712,8 +2715,8 @@ hypre_FillResponseBoxManAssemble2( void *p_recv_contact_buf,
    void              *info, *index_ptr;
   
    void                       *send_response_buf = (void *) *p_send_response_buf;
-   hypre_DataExchangeResponse *response_obj = ro;  
-   hypre_BoxManager           *manager = response_obj->data1;  
+   hypre_DataExchangeResponse *response_obj = (hypre_DataExchangeResponse *)ro;  
+   hypre_BoxManager           *manager = (hypre_BoxManager           *)response_obj->data1;  
    HYPRE_Int                   overhead = response_obj->send_response_overhead;
 
    HYPRE_Int           ndim = hypre_BoxManNDim(manager);
@@ -2732,7 +2735,7 @@ hypre_FillResponseBoxManAssemble2( void *p_recv_contact_buf,
    {
       response_obj->send_response_storage =  num_my_entries; 
       size =  entry_size_bytes*(response_obj->send_response_storage + overhead);
-      send_response_buf = hypre_ReAlloc( send_response_buf, size);
+      send_response_buf = hypre_ReAlloc( (char*)send_response_buf, size);
       *p_send_response_buf = send_response_buf;  
    }
 
