@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.10 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 /******************************************************************************
@@ -23,7 +23,7 @@
  *--------------------------------------------------------------------------*/
 
 HYPRE_Int
-hypre_StructAxpy( double              alpha,
+hypre_StructAxpy( HYPRE_Complex       alpha,
                   hypre_StructVector *x,
                   hypre_StructVector *y     )
 {
@@ -33,8 +33,8 @@ hypre_StructAxpy( double              alpha,
    HYPRE_Int         xi;
    HYPRE_Int         yi;
                     
-   double           *xp;
-   double           *yp;
+   HYPRE_Complex    *xp;
+   HYPRE_Complex    *yp;
                     
    hypre_BoxArray   *boxes;
    hypre_Box        *box;
@@ -44,7 +44,7 @@ hypre_StructAxpy( double              alpha,
                     
    HYPRE_Int         i;
 
-   hypre_SetIndex(unit_stride, 1, 1, 1);
+   hypre_SetIndex(unit_stride, 1);
 
    boxes = hypre_StructGridBoxes(hypre_StructVectorGrid(y));
    hypre_ForBoxI(i, boxes)
@@ -60,7 +60,7 @@ hypre_StructAxpy( double              alpha,
 
       hypre_BoxGetSize(box, loop_size);
 
-      hypre_BoxLoop2Begin(hypre_StructVectorDim(x), loop_size,
+      hypre_BoxLoop2Begin(hypre_StructVectorNDim(x), loop_size,
                           x_data_box, start, unit_stride, xi,
                           y_data_box, start, unit_stride, yi);
 #ifdef HYPRE_USING_OPENMP
