@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.11 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 /******************************************************************************
@@ -32,8 +32,8 @@ hypre_StructCopy( hypre_StructVector *x,
    HYPRE_Int        xi;
    HYPRE_Int        yi;
                    
-   double          *xp;
-   double          *yp;
+   HYPRE_Complex   *xp;
+   HYPRE_Complex   *yp;
                    
    hypre_BoxArray  *boxes;
    hypre_Box       *box;
@@ -43,7 +43,7 @@ hypre_StructCopy( hypre_StructVector *x,
                    
    HYPRE_Int        i;
 
-   hypre_SetIndex(unit_stride, 1, 1, 1);
+   hypre_SetIndex(unit_stride, 1);
 
    boxes = hypre_StructGridBoxes(hypre_StructVectorGrid(y));
    hypre_ForBoxI(i, boxes)
@@ -59,7 +59,7 @@ hypre_StructCopy( hypre_StructVector *x,
 
       hypre_BoxGetSize(box, loop_size);
 
-      hypre_BoxLoop2Begin(hypre_StructVectorDim(x), loop_size,
+      hypre_BoxLoop2Begin(hypre_StructVectorNDim(x), loop_size,
                           x_data_box, start, unit_stride, xi,
                           y_data_box, start, unit_stride, yi);
 #ifdef HYPRE_USING_OPENMP
@@ -92,8 +92,8 @@ hypre_StructPartialCopy( hypre_StructVector  *x,
    HYPRE_Int        xi;
    HYPRE_Int        yi;
 
-   double          *xp;
-   double          *yp;
+   HYPRE_Complex   *xp;
+   HYPRE_Complex   *yp;
 
    hypre_BoxArray  *boxes;
    hypre_Box       *box;
@@ -103,7 +103,7 @@ hypre_StructPartialCopy( hypre_StructVector  *x,
 
    HYPRE_Int        i, j ;
 
-   hypre_SetIndex(unit_stride, 1, 1, 1);
+   hypre_SetIndex(unit_stride, 1);
 
    hypre_ForBoxArrayI(i, array_boxes)
    {
@@ -123,7 +123,7 @@ hypre_StructPartialCopy( hypre_StructVector  *x,
          start = hypre_BoxIMin(box);
          hypre_BoxGetSize(box, loop_size);
 
-         hypre_BoxLoop2Begin(hypre_StructVectorDim(x), loop_size,
+         hypre_BoxLoop2Begin(hypre_StructVectorNDim(x), loop_size,
                              x_data_box, start, unit_stride, xi,
                              y_data_box, start, unit_stride, yi);
 #ifdef HYPRE_USING_OPENMP
