@@ -59,7 +59,7 @@ hypre_StructMatvecSetup( void               *matvec_vdata,
                          hypre_StructMatrix *A,
                          hypre_StructVector *x            )
 {
-   hypre_StructMatvecData  *matvec_data = matvec_vdata;
+	hypre_StructMatvecData  *matvec_data = (hypre_StructMatvecData  *)matvec_vdata;
                           
    hypre_StructGrid        *grid;
    hypre_StructStencil     *stencil;
@@ -100,7 +100,7 @@ hypre_StructMatvecCompute( void               *matvec_vdata,
                            HYPRE_Complex       beta,
                            hypre_StructVector *y            )
 {
-   hypre_StructMatvecData  *matvec_data = matvec_vdata;
+	hypre_StructMatvecData  *matvec_data = (hypre_StructMatvecData  *)matvec_vdata;
                           
    hypre_ComputePkg        *compute_pkg;
                           
@@ -125,6 +125,8 @@ hypre_StructMatvecCompute( void               *matvec_vdata,
    HYPRE_Complex            temp;
    HYPRE_Int                compute_i, i;
 
+   hypre_StructVector      *x_tmp = NULL;
+
    /*-----------------------------------------------------------------------
     * Initialize some things
     *-----------------------------------------------------------------------*/
@@ -168,6 +170,11 @@ hypre_StructMatvecCompute( void               *matvec_vdata,
       return hypre_error_flag;
    }
 
+   if (x == y)
+   {
+      x_tmp = hypre_StructVectorClone(y);
+      x = x_tmp;
+   }
    /*-----------------------------------------------------------------------
     * Do (alpha != 0.0) computation
     *-----------------------------------------------------------------------*/
@@ -275,6 +282,12 @@ hypre_StructMatvecCompute( void               *matvec_vdata,
       }
 
    }
+
+   if (x_tmp)
+   {
+      hypre_StructVectorDestroy(x_tmp);
+      x = y;
+   }
    
    return hypre_error_flag;
 }
@@ -657,7 +670,6 @@ HYPRE_Int hypre_StructMatvecCC1( HYPRE_Complex       alpha,
    hypre_BoxArray          *compute_box_a;
    hypre_Box               *compute_box;
                           
-   hypre_Box               *A_data_box;
    hypre_Box               *x_data_box;
    hypre_StructStencil     *stencil;
    hypre_Index             *stencil_shape;
@@ -681,7 +693,6 @@ HYPRE_Int hypre_StructMatvecCC1( HYPRE_Complex       alpha,
    {
       compute_box_a = hypre_BoxArrayArrayBoxArray(compute_box_aa, i);
 
-      A_data_box = hypre_BoxArrayBox(hypre_StructMatrixDataSpace(A), i);
       x_data_box = hypre_BoxArrayBox(hypre_StructVectorDataSpace(x), i);
       y_data_box = hypre_BoxArrayBox(hypre_StructVectorDataSpace(y), i);
 
@@ -695,7 +706,7 @@ HYPRE_Int hypre_StructMatvecCC1( HYPRE_Complex       alpha,
          hypre_BoxGetSize(compute_box, loop_size);
          start  = hypre_BoxIMin(compute_box);
 
-         Ai = hypre_CCBoxIndexRank( A_data_box, start );
+         Ai = 0;
 
          /* unroll up to depth MAX_DEPTH */
          for (si = 0; si < stencil_size; si+= MAX_DEPTH)
@@ -1434,7 +1445,7 @@ HYPRE_Int hypre_StructMatvecCC2( HYPRE_Complex       alpha,
 HYPRE_Int
 hypre_StructMatvecDestroy( void *matvec_vdata )
 {
-   hypre_StructMatvecData *matvec_data = matvec_vdata;
+	hypre_StructMatvecData *matvec_data = (hypre_StructMatvecData *)matvec_vdata;
 
    if (matvec_data)
    {
