@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.4 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 
@@ -28,12 +28,11 @@
 typedef struct hypre_StructStencil_struct
 {
    hypre_Index   *shape;   /* Description of a stencil's shape */
-   int            size;    /* Number of stencil coefficients */
-   int            max_offset;
+   HYPRE_Int      size;    /* Number of stencil coefficients */
                 
-   int            dim;     /* Number of dimensions */
+   HYPRE_Int      ndim;    /* Number of dimensions */
 
-   int            ref_count;
+   HYPRE_Int      ref_count;
 
 } hypre_StructStencil;
 
@@ -43,8 +42,7 @@ typedef struct hypre_StructStencil_struct
 
 #define hypre_StructStencilShape(stencil)      ((stencil) -> shape)
 #define hypre_StructStencilSize(stencil)       ((stencil) -> size)
-#define hypre_StructStencilMaxOffset(stencil)  ((stencil) -> max_offset)
-#define hypre_StructStencilDim(stencil)        ((stencil) -> dim)
+#define hypre_StructStencilNDim(stencil)       ((stencil) -> ndim)
 #define hypre_StructStencilRefCount(stencil)   ((stencil) -> ref_count)
 
 #define hypre_StructStencilElement(stencil, i) \
