@@ -1,30 +1,20 @@
 #!/bin/sh
 #BHEADER**********************************************************************
-# Copyright (c) 2006   The Regents of the University of California.
+# Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
 # Produced at the Lawrence Livermore National Laboratory.
-# Written by the HYPRE team. UCRL-CODE-222953.
-# All rights reserved.
-#
-# This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
-# Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
-# disclaimer, contact information and the GNU Lesser General Public License.
+# This file is part of HYPRE.  See file COPYRIGHT for details.
 #
 # HYPRE is free software; you can redistribute it and/or modify it under the
-# terms of the GNU General Public License (as published by the Free Software 
-# Foundation) version 2.1 dated February 1999.
+# terms of the GNU Lesser General Public License (as published by the Free
+# Software Foundation) version 2.1 dated February 1999.
 #
-# HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
-# WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
-# FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
-# Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program; if not, write to the Free Software Foundation,
-# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-#
-# $Revision: 1.9 $
+# $Revision$
 #EHEADER**********************************************************************
 
+
+
+
+
 TNAME=`basename $0 .sh`
 
 #=============================================================================
@@ -48,6 +38,11 @@ FILES="\
  ${TNAME}.out.13\
  ${TNAME}.out.14\
  ${TNAME}.out.15\
+ ${TNAME}.out.16\
+ ${TNAME}.out.17\
+ ${TNAME}.out.18\
+ ${TNAME}.out.19\
+ ${TNAME}.out.20\
 "
 
 for i in $FILES
@@ -69,10 +64,18 @@ do
   tail -3 $i
   echo "# Output file: $i.1"
   tail -13 $i.1 | head -3
-  echo "# Output file: $i.5"
-  tail -21 $i.5 | head -11
+  echo "# Output file: $i.4"
+  tail -19 $i.4 | head -9
 done >> ${TNAME}.out
 
+# Make sure that the output files are reasonable
+CHECK_LINE="Iterations"
+OUT_COUNT=`grep "$CHECK_LINE" ${TNAME}.out | wc -l`
+SAVED_COUNT=`grep "$CHECK_LINE" ${TNAME}.saved | wc -l`
+if [ "$OUT_COUNT" != "$SAVED_COUNT" ]; then
+   echo "Incorrect number of \"$CHECK_LINE\" lines in ${TNAME}.out" >&2
+fi
+
 if [ -z $HYPRE_NO_SAVED ]; then
    diff -U3 -bI"time" ${TNAME}.saved ${TNAME}.out >&2
 fi
