@@ -7,7 +7,7 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 1.3 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
 #include <stdlib.h>
@@ -39,7 +39,7 @@ main( hypre_int argc,
    HYPRE_Int         size;
    hypre_Box        *x1_data_box, *x2_data_box, *x3_data_box, *x4_data_box;
    HYPRE_Int         xi1, xi2, xi3, xi4;
-   double           *xp1, *xp2, *xp3, *xp4;
+   HYPRE_Real       *xp1, *xp2, *xp3, *xp4;
    hypre_Index       loop_size, start, unit_stride, index;
    
    /*-----------------------------------------------------------
@@ -148,25 +148,25 @@ main( hypre_int argc,
     * Initialize some stuff
     *-----------------------------------------------------------*/
 
-   hypre_SetIndex(start, 1, 1, 1);
-   hypre_SetIndex(loop_size, nx, ny, nz);
-   hypre_SetIndex(unit_stride, 1, 1, 1);
+   hypre_SetIndex3(start, 1, 1, 1);
+   hypre_SetIndex3(loop_size, nx, ny, nz);
+   hypre_SetIndex3(unit_stride, 1, 1, 1);
 
-   x1_data_box = hypre_BoxCreate();
-   x2_data_box = hypre_BoxCreate();
-   x3_data_box = hypre_BoxCreate();
-   x4_data_box = hypre_BoxCreate();
-   hypre_SetIndex(hypre_BoxIMin(x1_data_box), 0, 0, 0);
-   hypre_SetIndex(hypre_BoxIMax(x1_data_box), nx+1, ny+1, nz+1);
+   x1_data_box = hypre_BoxCreate(dim);
+   x2_data_box = hypre_BoxCreate(dim);
+   x3_data_box = hypre_BoxCreate(dim);
+   x4_data_box = hypre_BoxCreate(dim);
+   hypre_SetIndex3(hypre_BoxIMin(x1_data_box), 0, 0, 0);
+   hypre_SetIndex3(hypre_BoxIMax(x1_data_box), nx+1, ny+1, nz+1);
    hypre_CopyBox(x1_data_box, x2_data_box);
    hypre_CopyBox(x1_data_box, x3_data_box);
    hypre_CopyBox(x1_data_box, x4_data_box);
 
    size = (nx+2)*(ny+2)*(nz+2);
-   xp1 = hypre_CTAlloc(double, size);
-   xp2 = hypre_CTAlloc(double, size);
-   xp3 = hypre_CTAlloc(double, size);
-   xp4 = hypre_CTAlloc(double, size);
+   xp1 = hypre_CTAlloc(HYPRE_Real, size);
+   xp2 = hypre_CTAlloc(HYPRE_Real, size);
+   xp3 = hypre_CTAlloc(HYPRE_Real, size);
+   xp4 = hypre_CTAlloc(HYPRE_Real, size);
 
    reps = 1000000000/(nx*ny*nz+1000);
 
