@@ -7,11 +7,9 @@
  * terms of the GNU Lesser General Public License (as published by the Free
  * Software Foundation) version 2.1 dated February 1999.
  *
- * $Revision: 2.5 $
+ * $Revision$
  ***********************************************************************EHEADER*/
 
-
-
 /******************************************************************************
  *
  * This file contains routines that implement a pseudo-random number generator
@@ -38,11 +36,13 @@
  *
  *****************************************************************************/
 
+#include "_hypre_utilities.h"
+
 /*--------------------------------------------------------------------------
  * Static variables
  *--------------------------------------------------------------------------*/
 
-static int Seed = 13579;
+static HYPRE_Int Seed = 13579;
 
 #define a  16807
 #define m  2147483647
@@ -52,10 +52,10 @@ static int Seed = 13579;
 /*--------------------------------------------------------------------------
  * Initializes the pseudo-random number generator to a place in the sequence.
  *
- * @param seed an int containing the seed for the RNG.
+ * @param seed an HYPRE_Int containing the seed for the RNG.
  *--------------------------------------------------------------------------*/
 
-void  hypre_SeedRand( int seed )
+void  hypre_SeedRand( HYPRE_Int seed )
 {
    Seed = seed;
 }
@@ -64,13 +64,13 @@ void  hypre_SeedRand( int seed )
  * Computes the next pseudo-random number in the sequence using the global
  * variable Seed.
  *
- * @return a double containing the next number in the sequence divided by
+ * @return a HYPRE_Real containing the next number in the sequence divided by
  * 2147483647 so that the numbers are in (0, 1].
  *--------------------------------------------------------------------------*/
 
-double  hypre_Rand()
+HYPRE_Real  hypre_Rand()
 {
-   int  low, high, test;
+   HYPRE_Int  low, high, test;
 
    high = Seed / q;
    low = Seed % q;
@@ -84,5 +84,5 @@ double  hypre_Rand()
       Seed = test + m;
    }
 
-   return ((double)(Seed) / m);
+   return ((HYPRE_Real)(Seed) / m);
 }
